<?php
// Start output buffering at the beginning of the script
ob_start();

// Start the session
session_start();
// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Include the database connection file
include('../includes/dbcon.php');

if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'admin') {
    echo "User  is not logged in or not an admin.";
    header("Location: ../login.php");
    exit();
}

// Include PhpSpreadsheet classes
require '../vendor/autoload.php'; // Autoload all Composer dependencies

// Use statements for PhpSpreadsheet classes
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

// Pagination settings
$records_per_page_options = ['All', 10, 25, 50, 100, 150, 200, 250, 500, 1000];
$records_per_page = isset($_GET['records_per_page']) ? $_GET['records_per_page'] : 10; // Default to 10
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Default to page 1

// Get total records for pagination
$total_query = "SELECT COUNT(*) as total FROM activity_logs";
$total_result = mysqli_query($conn, $total_query);
$total_row = mysqli_fetch_assoc($total_result);
$total_records = $total_row['total'];
$total_pages = ceil($total_records / ($records_per_page === 'All' ? $total_records : $records_per_page));

// Calculate offset
$offset = ($current_page - 1) * ($records_per_page === 'All' ? $total_records : $records_per_page);

// SQL query to retrieve activity logs with usernames ordered by created_at
$querys = "
    SELECT al.*, u.username
    FROM activity_logs al
    LEFT JOIN users u ON al.user_id = u.id
    ORDER BY al.created_at DESC
";

// If not "All", apply LIMIT
if ($records_per_page !== 'All') {
    $querys .= " LIMIT $offset, $records_per_page";
}

$results = mysqli_query($conn, $querys);

// Check if the query was successful
if (!$results) {
    die("Query Failed: " . mysqli_error($conn));
}

// Check if the export button is clicked
if (isset($_POST['export_excel'])) {
    // Use the same query that retrieves all activity logs
    $query = $querys;

    // Execute the query
    $result = mysqli_query($conn, $query);
    if (!$result) {
        die("Export query failed: " . mysqli_error($conn));
    }

    // Check if there are any results
    if (mysqli_num_rows($result) == 0) {
        die("No data found for export.");
    }

    // Create a new Spreadsheet object
    $spreadsheet = new Spreadsheet();
    $sheet = $spreadsheet->getActiveSheet();

    // Set the header row
    $rowNumber = 1; // Start from the first row
    $columnIndex = 'A'; // Start from column A

    // Check and set headers based on user selection
    if (isset($_POST['include_serial_no'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'Serial No');
    }
    if (isset($_POST['include_user_id'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'User  ID');
    }
    if (isset($_POST['include_username'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'Username');
    }
    if (isset($_POST['include_action'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'Action');
    }
    if (isset($_POST['include_description'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'Description');
    }
    if (isset($_POST['include_ip'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'IP Address');
    }
    if (isset($_POST['include_user_agent'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'User  Agent');
    }
    if (isset($_POST['include_created_at'])) {
        $sheet->setCellValue($columnIndex++ . $rowNumber, 'Created at');
    }

    // Populate the spreadsheet with data
    $rowNumber++; // Move to the next row for data
    $serialNo = 1; // Initialize serial number
    while ($row = mysqli_fetch_assoc($result)) {
        $columnIndex = 'A'; // Reset column index for each row
        if (isset($_POST['include_serial_no'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $serialNo++);
        }
        if (isset($_POST['include_user_id'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['user_id']);
        }
        if (isset($_POST['include_username'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['username']);
        }
        if (isset($_POST['include_action'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['action']);
        }
        if (isset($_POST['include_description'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['description']);
        }
        if (isset($_POST['include_ip'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['ip_address']);
        }
        if (isset($_POST['include_user_agent'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['user_agent']);
        }
        if (isset($_POST['include_created_at'])) {
            $sheet->setCellValue($columnIndex++ . $rowNumber, $row['created_at']);
        }
        $rowNumber++;
    }

    // Create an Excel file
    $writer = new Xlsx($spreadsheet);
    $filename = 'activity_logs.xlsx';

    // Clear output buffer
    ob_end_clean(); // Clear any previous output

    // Set headers to download the file
    header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
    header('Content-Disposition: attachment; filename="' . $filename . '"');
    header('Cache-Control: max-age=0');

    // Save the file to output
    $writer->save('php://output');
    exit();
}

// Check if the export PDF button is clicked
if (isset($_POST['export_pdf'])) {
    // Include the TCPDF class file
    require '../vendor/tecnickcom/tcpdf/tcpdf.php'; // Adjust the path as necessary

    // Use the same query that retrieves all activity logs
    $query = $querys;

    // Execute the query
    $result = mysqli_query($conn, $query);
    if (!$result) {
        die("Export query failed: " . mysqli_error($conn));
    }

    // Check if there are any results
    if (mysqli_num_rows($result) == 0) {
        die("No data found for export.");
    }

    // Clear output buffer
    ob_end_clean(); // Clear any previous output

    // Create new PDF document
    $pdf = new TCPDF();
    $pdf->SetCreator(PDF_CREATOR);
    $pdf->SetAuthor('AcademyClan - Think Beyond, Learn Beyond.');
    $pdf->SetTitle('AcademyClan - Activity Logs based on all users.');
    $pdf->SetHeaderData('', 0, 'AcademyClan - Think Beyond, Learn Beyond.', 'Generated on ' . date('Y-m-d H:i:s'));
    $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
    $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
    $pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
    $pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
    $pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
    $pdf->AddPage();

    // Set font
    $pdf->SetFont('helvetica', '', 12);

    // Create HTML table
    $html = '<h1>AcademyClan - Activity Logs based on all users.</h1>';
    $html .= '<table border="1" cellpadding="4"><thead><tr>';

    // Check and set headers based on user selection
    if (isset($_POST['include_serial_no'])) {
        $html .= '<th>Serial No</th>';
    }
    if (isset($_POST['include_user_id'])) {
        $html .= '<th>User ID</th>';
    }
    if (isset($_POST['include_username'])) {
        $html .= '<th>Username</th>';
    }
    if (isset($_POST['include_action'])) {
        $html .= '<th>Action</th>';
    }
    if (isset($_POST['include_description'])) {
        $html .= '<th>Description</th>';
    }
    if (isset($_POST['include_ip'])) {
        $html .= '<th>IP Address</th>';
    }
    if (isset($_POST['include_user_agent'])) {
        $html .= '<th>User Agent</th>';
    }
    if (isset($_POST['include_created_at'])) {
        $html .= '<th>Created At</th>';
    }

    $html .= '</tr></thead><tbody>';

    // Populate the table with data
    $serialNo = 1; // Initialize serial number
    while ($row = mysqli_fetch_assoc($result)) {
        $html .= '<tr>';
        if (isset($_POST['include_serial_no'])) {
            $html .= '<td>' . htmlspecialchars($serialNo++) . '</td>';
        }
        if (isset($_POST['include_user_id'])) {
            $html .= '<td>' . htmlspecialchars($row['user_id'] ?? 'None') . '</td>';
        }
        if (isset($_POST['include_username'])) {
            $html .= '<td>' . htmlspecialchars($row['username'] ?? 'None') . '</td>';
        }
        if (isset($_POST['include_action'])) {
            $html .= '<td>' . htmlspecialchars($row['action']) . '</td>';
        }
        if (isset($_POST['include_description'])) {
            $html .= '<td>' . htmlspecialchars($row['description']) . '</td>';
        }
        if (isset($_POST['include_ip'])) {
            $html .= '<td>' . htmlspecialchars($row['ip_address'] ?? 'None') . '</td>';
        }
        if (isset($_POST['include_user_agent'])) {
            $html .= '<td>' . htmlspecialchars($row['user_agent'] ?? 'None') . '</td>';
        }
        if (isset($_POST['include_created_at'])) {
            $html .= '<td>' . htmlspecialchars($row['created_at']) . '</td>';
        }
        $html .= '</tr>';
    }
    $html .= '</tbody></table>';

    // Output the HTML content
    $pdf->writeHTML($html, true, false, true, false, '');

    // Close and output PDF document
    $pdf->Output('activity_logs.pdf', 'D');
    exit();
}

// Start HTML output
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Activity Logs</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 40px;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #a777e3;
            border-color: #a777e3;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/header.php'; ?>
    <?php include '../includes/admin_sidebar.php'; ?>

    <div class="container">
        <h1>Activity Logs</h1>

        <!-- Records per page selection -->
        <form method="get" class="mb-3">
            <label for="records_per_page">Records per page:</label>
            <select name="records_per_page" id="records_per_page" onchange="this.form.submit()">
                <?php foreach ($records_per_page_options as $option): ?>
                    <option value="<?php echo $option; ?>" <?php echo $option == $records_per_page ? 'selected' : ''; ?>>
                        <?php echo $option; ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </form>
        <!-- Button to trigger Export Modal -->
        <button type="button" class="btn btn-danger mb-3" data-bs-toggle="modal" data-bs-target="#exportModal">
            <i class="fas fa-file-export"></i> Export
        </button>

        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S. No.</th> <!-- Add Serial No header -->
                    <th>User ID</th>
                    <th>Username</th>
                    <th>Action</th>
                    <th>Description</th>
                    <th>IP Address</th>
                    <th>User Agent</th>
                    <th>Created At</th>
                </tr>
            </thead>
            <tbody>
                <?php
                // Fetch and display each row of data
                $serialNo = 1; // Initialize serial number
                while ($row = mysqli_fetch_assoc($results)) {
                    echo "<tr>";
                    echo "<td>" . htmlspecialchars($serialNo++) . "</td>"; // Display Serial No
                    echo "<td>" . htmlspecialchars($row['user_id'] ?? 'None') . "</td>";
                    echo "<td>" . htmlspecialchars($row['username'] ?? 'None') . "</td>";
                    echo "<td>" . htmlspecialchars($row['action']) . "</td>";
                    echo "<td>" . htmlspecialchars($row['description']) . "</td>";
                    echo "<td>" . htmlspecialchars($row['ip_address'] ?? 'None') . "</td>";
                    echo "<td>" . htmlspecialchars($row['user_agent'] ?? 'None') . "</td>";
                    echo "<td>" . htmlspecialchars($row['created_at']) . " UTC</td>";
                    echo "</tr>";
                }
                ?>
            </tbody>
        </table>
        <!-- Pagination controls -->
        <nav aria-label="Page navigation">
            <ul class="pagination justify-content-left">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=1&records_per_page=<?php echo $records_per_page; ?>" aria-label="First">
                            <span aria-hidden="true">&laquo;&laquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page - 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Previous">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>
                <?php endif; ?>

                <?php
                $max_displayed_pages = 17; // Total number of pages to display
                $start_page = max(1, $current_page - floor($max_displayed_pages / 2));
                $end_page = min($total_pages, $start_page + $max_displayed_pages - 1);

                // Adjust start page if there are not enough pages before the current page
                if ($end_page - $start_page < $max_displayed_pages - 1) {
                    $start_page = max(1, $end_page - $max_displayed_pages + 1);
                }

                // Ensure we do not exceed the total number of pages
                if ($end_page > $total_pages) {
                    $end_page = $total_pages;
                }

                // Display pages
                for ($i = $start_page; $i <= $end_page; $i++): ?>
                    <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?php echo $i; ?>&records_per_page=<?php echo $records_per_page; ?>"><?php echo $i; ?></a>
                    </li>
                <?php endfor; ?>

                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page + 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Next">
                            <span aria-hidden="true">&raquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $total_pages; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Last">
                            <span aria-hidden="true">&raquo;&raquo;</span>
                        </a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>
    </div>

    <!-- Export Modal -->
    <div class="modal fade" id="exportModal" tabindex="-1" aria-labelledby="exportModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exportModalLabel">Export Options</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="post">
                    <div class="modal-body">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="select_all_columns" onclick="toggleColumnCheckboxes(this)">
                            <label class="form-check-label" for="select_all_columns">Select All Columns</label>
                        </div>
                        
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_serial_no" name="include_serial_no" value="1" checked>
                            <label class="form-check-label" for="include_serial_no">Include Serial No</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_user_id" name="include_user_id" value="1" checked>
                            <label class="form-check-label" for="include_user_id">Include User ID</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_username" name="include_username" value="1" checked>
                            <label class="form-check-label" for="include_username">Include Username</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_action" name="include_action" value="1" checked>
                            <label class="form-check-label" for="include_action">Include Action</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_description" name="include_description" value="1" checked>
                            <label class="form-check-label" for="include_description">Include Description</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_ip" name="include_ip" value="1" checked>
                            <label class="form-check-label" for="include_ip">Include IP Address</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_user_agent" name="include_user_agent" value="1" checked>
                            <label class="form-check-label" for="include_user_agent">Include User Agent</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_created_at" name="include_created_at" value="1" checked>
                            <label class="form-check-label" for="include_created_at">Include Created At</label>
                        </div>
                        <div class="modal-footer">
                            <button type="submit" name="export_excel" class="btn btn-success"><i class="fas fa-file-excel"></i> Export to Excel</button>
                            <button type="submit" name="export_pdf" class="btn btn-danger"><i class="fas fa-file-pdf"></i> Export to PDF</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function toggleColumnCheckboxes(source) {
            const checkboxes = document.querySelectorAll('.form-check-input[type="checkbox"]');
            checkboxes.forEach(checkbox => {
                if (checkbox !== source) {
                    checkbox.checked = source.checked;
                }
            });
        }
    </script>
</body>
</html>

<?php
// Close the database connection
mysqli_close($conn);
?>