<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection
include '../activity_log.php'; // Include activity log script

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Trim and sanitize inputs
    $first_name = $conn->real_escape_string(trim($_POST['first_name']));
    $last_name = $conn->real_escape_string(trim($_POST['last_name']));
    $username = $conn->real_escape_string(trim($_POST['username']));
    $email = $conn->real_escape_string(trim($_POST['email']));
    $mobile_number = $conn->real_escape_string(trim($_POST['mobile_number']));
    $register_number = $conn->real_escape_string(trim($_POST['register_number']));
    $gender = $conn->real_escape_string(trim($_POST['gender']));
    $department_id = !empty($_POST['department_id']) ? $conn->real_escape_string(trim($_POST['department_id'])) : null;
    $year_level_id = !empty($_POST['year_level_id']) ? $conn->real_escape_string(trim($_POST['year_level_id'])) : null;

    // Check for duplicate username
    $username_check_query = "SELECT id FROM users WHERE username = ?";
    $stmt = $conn->prepare($username_check_query);
    $stmt->bind_param("s", $username);
    $stmt->execute();
    $username_check_result = $stmt->get_result();

    // Check for duplicate email
    $email_check_query = "SELECT id FROM users WHERE email = ?";
    $stmt = $conn->prepare($email_check_query);
    $stmt->bind_param("s", $email);
    $stmt->execute();
    $email_check_result = $stmt->get_result();

    if ($username_check_result->num_rows > 0) {
        $_SESSION['error_message'] = "Username already exists.";
        
        // Log activity for duplicate username
        $admin_id = $_SESSION['user_id'];
        $action = "Admin user failed to add student user";
        $description = "Attempted to add user '$username' but the username already exists.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $admin_id, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();

        header("Location: manage_students.php");
        exit();
    }

    if ($email_check_result->num_rows > 0) {
        $_SESSION['error_message'] = "Email already exists.";
        
        // Log activity for duplicate email
        $admin_id = $_SESSION['user_id'];
        $action = "Admin user failed to add student user";
        $description = "Attempted to add user '$username' but the email already exists.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $admin_id, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();

        header("Location: manage_students.php");
        exit();
    }

    // Fetch avatar_id based on role and gender
    $stmt = $conn->prepare("SELECT id FROM avatars WHERE role = 'student' AND gender = ?");
    $stmt->bind_param("s", $gender);
    $stmt->execute();
    $avatar_result = $stmt->get_result();
    $avatar_id = ($avatar_result->num_rows > 0) ? $avatar_result->fetch_assoc()['id'] : null;

    // Default password (hashed)
    $default_password = password_hash('1234', PASSWORD_DEFAULT);

    // Insert new student user with status as 'pending'
    $stmt = $conn->prepare("INSERT INTO users (username, email, password, first_name, last_name, role, mobile_number, register_number, gender, department_id, year_level_id, avatar_id, approval_status, created_at, updated_at) VALUES (?, ?, ?, ?, ?, 'student', ?, ?, ?, ?, ?, ?, 'pending', NOW(), NOW())");
    $stmt->bind_param("ssssssssssi", $username, $email, $default_password, $first_name, $last_name, $mobile_number, $register_number, $gender, $department_id, $year_level_id, $avatar_id);

    if ($stmt->execute()) {
        // Log activity
        $newUserId = $stmt->insert_id; // Get the newly created user ID
        $action = "Admin user added a new student user";
        $description = "User  '$username' added with pending status.";
        $ip_address = $_SERVER['REMOTE_ADDR']; // Fetch the IP address
        $user_agent = $_SERVER['HTTP_USER_AGENT']; // Fetch the user agent

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $newUserId, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();

        $_SESSION['success_message'] = "Student user($username) added successfully with pending status.";
    } else {
        $_SESSION['error_message'] = "Error adding student user: " . $conn->error;
        
        // Log activity for error
        $admin_id = $_SESSION['user_id'];
        $action = "Error adding student user by Admin user";
        $description = "Failed to add user '$username': " . $stmt->error;
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $admin_id, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();
    }

    $stmt->close();
    header("Location: manage_students.php");
    exit();
}
?>