<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php';

// Fetch admin details using 'user_id' stored in the session
$user_id = $_SESSION['user_id'];
$sql = "SELECT * FROM users WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$admin = $stmt->get_result()->fetch_assoc();

if (!$admin || $admin['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Admin Dashboard</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }

        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }

        .dashboard-content {
            margin-left: 250px;
            padding: 95px 30px;
            transition: margin-left 0.3s ease;
        }

        .card-header {
            background-color: #6e8efb;
            color: white;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #a777e3;
            border-color: #a777e3;
        }

        @media (max-width: 1200px) {
            .sidebar {
                width: 200px;
            }

            .dashboard-content {
                margin-left: 200px;
                padding-top: 95px;
            }
        }

        @media (max-width: 992px) {
            .sidebar {
                width: 180px;
            }

            .dashboard-content {
                margin-left: 180px;
                padding-top: 95px;
            }
        }

        @media (max-width: 768px) {
            .sidebar {
                width: 0;
                display: none;
            }

            .dashboard-content {
                margin-left: 0;
                padding-top: 95px;
            }

            .mobile-sidebar {
                display: block;
                padding: 10px 0;
            }

            .mobile-sidebar a {
                display: block;
                padding: 10px;
                margin: 5px 0;
                background-color: #a777e3;
                color: white;
                text-align: center;
                text-decoration: none;
                border-radius: 5px;
            }

            .mobile-sidebar a:hover {
                background-color: #6e8efb;
            }

            .sidebar-toggle {
                display: block;
                background-color: #a777e3;
                color: white;
                border: none;
                padding: 10px;
                font-size: 18px;
                position: fixed;
                top: 10px;
                left: 10px;
                z-index: 1000;
            }

            .sidebar-open .sidebar {
                width: 250px;
                display: block;
            }

            .sidebar-open .dashboard-content {
                margin-left: 250px;
            }
        }
    </style>
</head>

<body>
    <!-- Include Header -->
    <?php include('../includes/header.php'); ?>

    <!-- Sidebar Toggle Button -->
    <button class="sidebar-toggle d-md-none" onclick="toggleSidebar()">☰</button>

    <!-- Desktop Sidebar -->
    <div id="sidebar" class="sidebar text-white position-fixed vh-100 d-none d-md-block">
        <h4 class="text-center py-3">Admin Panel</h4>
        <nav class="d-flex flex-column">
            <a href="dashboard.php"><i class="fas fa-tachometer-alt"></i> Dashboard</a>
            <a href="manage_admin_users.php"><i class="fas fa-user-shield"></i> Manage Admin Users</a>
            <a href="manage_faculty.php"><i class="fas fa-chalkboard-teacher"></i> Manage Faculties</a>
            <a href="manage_students.php"><i class="fas fa-user-graduate"></i> Manage Students</a>
            <a href="manage_year_levels.php"><i class="fas fa-calendar-alt"></i> Manage Academic Years</a>
            <a href="manage_departments.php"><i class="fas fa-building"></i> Manage Departments</a>
            <a href="manage_classes.php"><i class="fas fa-school"></i> Manage Classes</a>
            <!-- <a href="downloadable_materials.php"><i class="fas fa-download"></i> Downloadable Materials</a>
            <a href="uploaded_assignments.php"><i class="fas fa-upload"></i> Uploaded Assignments</a> -->
            <a href="activity_log.php"><i class="fas fa-history"></i> Activity Logs</a>
            <a href="calendar_of_events.php"><i class="fas fa-calendar"></i> Calendar of Events</a>
        </nav>
    </div>

    <!-- Dashboard Content -->
    <div class="dashboard-content">
        <div class="dashboard-header">
            <h1>Welcome to Admin Dashboard</h1>
            <p class="welcome-message">Hello, <?php echo htmlspecialchars($admin['first_name']) . ' ' . htmlspecialchars($admin['last_name']); ?>! You're logged in as an Admin.</p>
        </div>

        <!-- Mobile Sidebar -->
        <div class="mobile-sidebar d-md-none">
            <a href="dashboard.php"><i class="fas fa-tachometer-alt"></i> Dashboard</a>
            <a href="manage_admin_users.php"><i class="fas fa-user-shield"></i> Manage Admin Users</a>
            <a href="manage_faculty.php"><i class="fas fa-chalkboard-teacher"></i> Manage Faculties</a>
            <a href="manage_students.php"><i class="fas fa-user-graduate"></i> Manage Students</a>
            <a href="manage_year_levels.php"><i class="fas fa-calendar-alt"></i> Manage Academic Years</a>
            <a href="manage_departments.php"><i class="fas fa-building"></i> Manage Departments</a>
            <a href="manage_classes.php"><i class="fas fa-school"></i> Manage Classes</a>
            <!-- <a href="downloadable_materials.php"><i class="fas fa-download"></i> Downloadable Materials</a>
            <a href="uploaded_assignments.php"><i class="fas fa-upload"></i> Uploaded Assignments</a> -->
            <a href="activity_log.php"><i class="fas fa-history"></i> Activity Logs</a>
            <a href="calendar_of_events.php"><i class="fas fa-calendar"></i> Calendar of Events</a>
        </div>

        <!-- Example Dashboard Cards -->
        <div class="row">

            <!-- Admin Management Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>Manage Admin</h4>
                    </div>
                    <div class="card-body">
                        <p>View and manage admin members.</p>
                        <a href="manage_admin_users.php" class="btn btn-primary btn-block"><i class="fas fa-user-shield"></i> Go to Admin Management</a>
                    </div>
                </div>
            </div>

            <!-- Faculty Management Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>Manage Faculty</h4>
                    </div>
                    <div class="card-body">
                        <p>View and manage faculty members.</p>
                        <a href="manage_faculty.php" class="btn btn-primary btn-block"><i class="fas fa-chalkboard-teacher"></i> Go to Faculty Management</a>
                    </div>
                </div>
            </div>

            <!-- Student Management Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>Manage Students</h4>
                    </div>
                    <div class="card-body">
                        <p>View and manage student data.</p>
                        <a href="manage_students.php" class="btn btn-primary btn-block"><i class="fas fa-users"></i> Go to Student Management</a>
                    </div>
                </div>
            </div>

            <!-- Manage Classes Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>Manage Classes</h4>
                    </div>
                    <div class="card-body">
                        <p>View and manage classes.</p>
                        <a href="manage_classes.php" class="btn btn-primary btn-block"><i class="fas fa-users-cog"></i> Go to Classes Management</a>
                    </div>
                </div>
            </div>

            <!-- Activity Logs Management Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>Manage Activity Logs</h4>
                    </div>
                    <div class="card-body">
                        <p>View and export the logs and activity of admin, faculty and students.</p>
                        <a href="activity_log.php" class="btn btn-primary btn-block"><i class="fas fa-history"></i> Go to Activity Logs Management</a>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Toggle sidebar on mobile
        function toggleSidebar() {
            document.body.classList.toggle('sidebar-open');
        }
    </script>
</body>

</html>
