<?php
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the user ID from the POST request
    $id = $_POST['id'];

    // Fetch the user details before deletion
    $current_query = "SELECT * FROM users WHERE id = ?";
    $current_stmt = $conn->prepare($current_query);
    if (!$current_stmt) {
        die("Prepared statement failed: " . $conn->error);
    }
    $current_stmt->bind_param("i", $id);
    $current_stmt->execute();
    $current_result = $current_stmt->get_result();
    $current_user = $current_result->fetch_assoc();

    // Check if user exists
    if (!$current_user) {
        $_SESSION['error_message'] = "User  not found.";
        header("Location: manage_admin_users.php");
        exit();
    }

    // Prepare the SQL delete statement
    $stmt = $conn->prepare("DELETE FROM users WHERE id = ? AND role = 'admin'");
    $stmt->bind_param("i", $id);

    // Execute the statement
    if ($stmt->execute()) {
        // Log activity with user details
        $action = "Admin user deleted admin user with ID: $id";
        $description = "Admin user details: First Name: {$current_user['first_name']}, Last Name: {$current_user['last_name']}, Username: {$current_user['username']}, Email: {$current_user['email']}, Mobile Number: {$current_user['mobile_number']}, Register Number: {$current_user['register_number']}, Gender: {$current_user['gender']}, Department ID: {$current_user['department_id']}, Year Level ID: {$current_user['year_level_id']}, Approval Status: {$current_user['approval_status']}.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];
        $_SESSION['success_message'] = "Admin user deleted successfully." . $description;

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $_SESSION['user_id'], $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();
    } else {
        $_SESSION['error_message'] = "Error deleting admin user: " . $stmt->error;
    }

    // Close the statement and connection
    $stmt->close();
    $current_stmt->close();
    $conn->close();

    // Redirect back to the manage admin users page
    header("Location: manage_admin_users.php");
    exit();
}
?>