<?php
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch all materials uploaded 
$query = "SELECT m.*, u.username, c.class_name, yl.year_level, d.department_name 
          FROM materials m 
          LEFT JOIN users u ON m.faculty_id = u.id 
          LEFT JOIN classes c ON m.class_id = c.id 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          ORDER BY m.uploaded_at DESC";

$stmt = $conn->prepare($query);

if ($stmt) {
    $stmt->execute(); // Execute the prepared statement
    $results = $stmt->get_result(); // Get the result set from the executed statement

    if (!$results) {
        die("Query failed: " . $conn->error);
    }
} else {
    die("Prepare failed: " . $conn->error);
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Downloadable Materials</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
        .container {
            margin-left: 250px;
            padding: 95px 30px;
            transition: margin-left 0.3s ease;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/header.php'; ?>
    <?php include '../includes/admin_sidebar.php'; ?>
    <div class="container">
        <h1>Manage Downloadable Materials</h1>

        <?php
        if (isset($_SESSION['success_message'])) {
            echo "<div class='alert alert-success'>{$_SESSION['success_message']}</div>";
            unset($_SESSION['success_message']);
        }
        if (isset($_SESSION['error_message'])) {
            echo "<div class='alert alert-danger'>{$_SESSION['error_message']}</div>";
            unset($_SESSION['error_message']);
        }
        ?>

        <h2>All Uploaded Materials</h2>
        <table class="table">
            <thead>
                <tr>
                    <th>File Name</th>
                    <th>Uploaded By</th>
                    <th>Class</th>
                    <th>Year Level</th>
                    <th>Department</th>
                    <th>Uploaded At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($results->num_rows > 0): ?>
                    <?php while ($material = $results->fetch_assoc()): ?>
                        <tr>
                            <td><?= htmlspecialchars(basename($material['file_path'])); ?></td>
                            <td><?= htmlspecialchars($material['username']); ?></td>
                            <td><?= htmlspecialchars($material['class_name']); ?></td>
                            <td><?= htmlspecialchars($material['year_level']); ?></td>
                            <td><?= htmlspecialchars($material['department_name']); ?></td>
                            <td><?= htmlspecialchars($material['uploaded_at']); ?></td>
                            <td>
                                <a href="download.php?id=<?= $material['id']; ?>" class="btn btn-success btn-sm" title="Download">
                                    <i class="fas fa-download"></i> Download
                                </a>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="7" class="text-center">No materials uploaded yet.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>
    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$conn->close(); // Close the database connection
?>