<?php
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection
include '../includes/activity_log.php'; // Include activity log script

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Get the form data
    $id = $_POST['id'];
    $first_name = trim($_POST['first_name']);
    $last_name = trim($_POST['last_name']);
    $username = trim($_POST['username']);
    $email = trim($_POST['email']);
    $mobile_number = trim($_POST['mobile_number']);
    $register_number = trim($_POST['register_number']);
    $gender = $_POST['gender'];
    $department_id = $_POST['department_id'];
    $year_level_id = $_POST['year_level_id'];
    $approval_status = $_POST['approval_status'];

    // Fetch the current user data
    $current_query = "SELECT * FROM users WHERE id = ?";
    $current_stmt = $conn->prepare($current_query);
    if (!$current_stmt) {
        die("Prepared statement failed: " . $conn->error);
    }
    $current_stmt->bind_param("i", $id);
    $current_stmt->execute();
    $current_result = $current_stmt->get_result();
    $current_user = $current_result->fetch_assoc();

    // Check if user exists
    if (!$current_user) {
        $_SESSION['error_message'] = "User  not found.";
        header("Location: manage_admin_users.php");
        exit();
    }

    // Check for duplicate username and email
    $username_check_query = "SELECT id FROM users WHERE username = ? AND id != ?";
    $email_check_query = "SELECT id FROM users WHERE email = ? AND id != ?";

    // Check for duplicate username
    $stmt = $conn->prepare($username_check_query);
    $stmt->bind_param("si", $username, $id);
    $stmt->execute();
    $username_check_result = $stmt->get_result();

    // Check for duplicate email
    $stmt = $conn->prepare($email_check_query);
    $stmt->bind_param("si", $email, $id);
    $stmt->execute();
    $email_check_result = $stmt->get_result();

    if ($username_check_result->num_rows > 0) {
        $_SESSION['error_message'] = "Username already exists.";
        
        // Log activity for duplicate username
        $admin_id = $_SESSION['user_id'];
        $action = "Admin user failed to edit admin user";
        $description = "Attempted to edit user with ID '$id' but the username already exists.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $admin_id, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();

        header("Location: manage_admin_users.php");
        exit();
    }

    if ($email_check_result->num_rows > 0) {
        $_SESSION['error_message'] = "Email already exists.";
        
        // Log activity for duplicate email
        $admin_id = $_SESSION['user_id'];
        $action = "Admin user failed to edit admin user";
        $description = "Attempted to edit user with ID '$id' but the email already exists.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $admin_id, $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();

        header("Location: manage_admin_users.php");
        exit();
    }

    // Prepare the SQL update statement
    $stmt = $conn->prepare("UPDATE users SET first_name=?, last_name=?, username=?, email=?, mobile_number=?, register_number=?, gender=?, department_id=?, year_level_id=?, approval_status=? WHERE id=?");
    if (!$stmt) {
        die("Prepared statement failed: " . $conn->error);
    }
    $stmt->bind_param("ssssssssssi", $first_name, $last_name, $username, $email, $mobile_number, $register_number, $gender, $department_id, $year_level_id, $approval_status, $id);

    // Execute the statement
    if ($stmt->execute()) {
        // Prepare the changes array
        $changes = [];
        if ($current_user['first_name'] !== $first_name) {
            $changes[] = "First Name: '{$current_user['first_name']}' to '{$first_name}'";
        }
        if ($current_user['last_name'] !== $last_name) {
            $changes[] = "Last Name: '{$current_user['last_name']}' to '{$last_name}'";
        }
        if ($current_user['username'] !== $username) {
            $changes[] = "Username: '{$current_user['username']}' to '{$username}'";
        }
        if ($current_user['email'] !== $email) {
            $changes[] = "Email: '{$current_user['email']}' to '{$email}'";
        }
        if ($current_user['mobile_number'] !== $mobile_number) {
            $changes[] = "Mobile Number: '{$current_user['mobile_number']}' to '{$mobile_number}'";
        }
        if ($current_user['register_number'] !== $register_number) {
            $changes[] = "Register Number: '{$current_user['register_number']}' to '{$register_number}'";
        }
        if ($current_user['gender'] !== $gender) {
            $changes[] = "Gender: '{$current_user['gender']}' to '{$gender}'";
        }

        // Fetch the old department name
        $old_department_stmt = $conn->prepare("SELECT department_name FROM departments WHERE id = ?");
        $old_department_stmt->bind_param("i", $current_user['department_id']);
        $old_department_stmt->execute();
        $old_department_stmt->bind_result($old_department_name);
        $old_department_stmt->fetch();
        $old_department_stmt->close();

        // Fetch the old year level name
        $old_year_level_stmt = $conn->prepare("SELECT year_level FROM year_levels WHERE id = ?");
        $old_year_level_stmt->bind_param("i", $current_user['year_level_id']);
        $old_year_level_stmt->execute();
        $old_year_level_stmt->bind_result($old_year_level_name);
        $old_year_level_stmt->fetch();
        $old_year_level_stmt->close();

        // Ensure that the department and year level IDs are compared as integers
        if ((int)$current_user['department_id'] !== (int)$department_id) {
            // Fetch the new department name
            $new_department_stmt = $conn->prepare("SELECT department_name FROM departments WHERE id = ?");
            $new_department_stmt->bind_param("i", $department_id);
            $new_department_stmt->execute();
            $new_department_stmt->bind_result($new_department_name);
            $new_department_stmt->fetch();
            $new_department_stmt->close();

            $changes[] = "Department: '{$old_department_name}' to '{$new_department_name}'";
        }
        if ((int)$current_user['year_level_id'] !== (int)$year_level_id) {
            // Fetch the new year level name
            $new_year_level_stmt = $conn->prepare("SELECT year_level FROM year_levels WHERE id = ?");
            $new_year_level_stmt->bind_param("i", $year_level_id);
            $new_year_level_stmt->execute();
            $new_year_level_stmt->bind_result($new_year_level_name);
            $new_year_level_stmt->fetch();
            $new_year_level_stmt->close();

            $changes[] = "Year Level: '{$old_year_level_name}' to '{$new_year_level_name}'";
        }
        if ($current_user['approval_status'] !== $approval_status) {
            $changes[] = "Approval Status: '{$current_user['approval_status']}' to '{$approval_status}'";
        }

        // Prepare the success message only if there are changes
        if (!empty($changes)) {
            $action = "Admin User edited admin user with ID: $id";
            $description = "Admin user updated successfully. " . "Changes made: " . implode(", ", $changes);
            $ip_address = $_SERVER['REMOTE_ADDR'];
            $user_agent = $_SERVER['HTTP_USER_AGENT'];
            $_SESSION['success_message'] = "Admin user updated successfully. " . $description;

            // Log activity
            $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
            if (!$log_stmt) {
                die("Prepared statement failed: " . $conn->error);
            }
            $log_stmt->bind_param("issss", $_SESSION['user_id'], $action, $description, $ip_address, $user_agent);
            $log_stmt->execute();
            $log_stmt->close();
        }
    } else {
        $_SESSION['error_message'] = "Error updating admin user: " . $stmt->error;
    }

    // Close the statement and connection
    $stmt->close();
    $current_stmt->close();
    $conn->close();

    // Redirect back to the manage admin users page
    header("Location: manage_admin_users.php");
    exit();
}
?>