<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $id = $_POST['id']; // Get the ID of the class to be edited
    $class_name = trim($_POST['class_name']); // Trim whitespace
    $year_level_id = $_POST['year_level_id'];
    $department_id = $_POST['department_id'];
    $description = $_POST['description'];
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session

    // Check if the ID and new class name are set
    if (empty($id) || empty($class_name)) {
        $_SESSION['error_message'] = "Error: Class ID and Class name cannot be empty.";
        header("Location: manage_classes.php");
        exit();
    }

    // Fetch the old class details before updating
    $old_stmt = $conn->prepare("SELECT class_name, year_level_id, department_id, description FROM classes WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_classes.php");
        exit();
    }

    $old_stmt->bind_param("i", $id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_class_name, $old_year_level_id, $old_department_id, $old_description);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the old class details were found
    if (!$old_class_name) {
        $_SESSION['error_message'] = "Error: Class ID '$id' not found.";
        header("Location: manage_classes.php");
        exit();
    }

    // Fetch the old year level
    $year_level_stmt = $conn->prepare("SELECT year_level FROM year_levels WHERE id = ?");
    $year_level_stmt->bind_param("i", $old_year_level_id);
    $year_level_stmt->execute();
    $year_level_stmt->bind_result($old_year_level_name);
    $year_level_stmt->fetch();
    $year_level_stmt->close();

    // Fetch the old department name
    $department_stmt = $conn->prepare("SELECT department_name FROM departments WHERE id = ?");
    $department_stmt->bind_param("i", $old_department_id);
    $department_stmt->execute();
    $department_stmt->bind_result($old_department_name);
    $department_stmt->fetch();
    $department_stmt->close();

    // Check if the new class name already exists (excluding the current one)
    $check_stmt = $conn->prepare("SELECT COUNT(*) FROM classes WHERE class_name = ? AND id != ?");
    if (!$check_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_classes.php");
        exit();
    }

    $check_stmt->bind_param("si", $class_name, $id);
    $check_stmt->execute();
    $check_stmt->bind_result($count);
    $check_stmt->fetch();
    $check_stmt->close();

    if ($count > 0) {
        // Class already exists
        $_SESSION['error_message'] = "Error: Class '$class_name' already exists.";
    } else {
        // Prepare and execute the update statement for classes
        $stmt = $conn->prepare("UPDATE classes SET class_name = ?, year_level_id = ?, department_id = ?, description = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
        if (!$stmt) {
            $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
            header("Location: manage_classes.php");
            exit();
        }

        $stmt->bind_param("siisi", $class_name, $year_level_id, $department_id, $description, $id);

        if ($stmt->execute()) {
            // Log the activity
            $action = "Class Edited";
            $description_log = "Admin User edited class ID $id from '$old_class_name' to '$class_name'. ";

            // Initialize success message
            $success_message = "Class updated successfully from '$old_class_name' to '$class_name'. ";

            // Fetch new year level name
            $new_year_level_stmt = $conn->prepare("SELECT year_level FROM year_levels WHERE id = ?");
            $new_year_level_stmt->bind_param("i", $year_level_id);
            $new_year_level_stmt->execute();
            $new_year_level_stmt->bind_result($new_year_level_name);
            $new_year_level_stmt->fetch();
            $new_year_level_stmt->close();

            // Fetch new department name
            $new_department_stmt = $conn->prepare("SELECT department_name FROM departments WHERE id = ?");
            $new_department_stmt->bind_param("i", $department_id);
            $new_department_stmt->execute();
            $new_department_stmt->bind_result($new_department_name);
            $new_department_stmt->fetch();
            $new_department_stmt->close();

            // Check for changes in year level, department, and description
            if ($old_year_level_id != $year_level_id) {
                $description_log .= "Year level changed from '$old_year_level_name' to '$new_year_level_name'. ";
                $success_message .= "Year level changed from '$old_year_level_name' to '$new_year_level_name'. ";
            }
            if ($old_department_id != $department_id) {
                $description_log .= "Department changed from '$old_department_name' to '$new_department_name'. ";
                $success_message .= "Department changed from '$old_department_name' to '$new_department_name'. ";
            }
            if ($old_description != $description) {
                $description_log .= "Description changed from '$old_description' to '$description'. ";
                $success_message .= "Description changed from '$old_description' to '$description'. ";
            }

            $ip_address = $_SERVER['REMOTE_ADDR'];
            $user_agent = $_SERVER['HTTP_USER_AGENT'];

            $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
            if ($log_stmt) {
                $log_stmt->bind_param("issss", $user_id, $action, $description_log, $ip_address, $user_agent);
                $log_stmt->execute();
            }

            // Set the success message in the session
            $_SESSION['success_message'] = $success_message;
        } else {
            $_SESSION['error_message'] = "Error updating class: " . $stmt->error;
        }
    }

    header("Location: manage_classes.php");
    exit();
}
?>