<?php
session_start();
include '../includes/dbcon.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $id = $_POST['id']; // Get the ID of the department to be edited
    $department_name = trim($_POST['department_name']); // Trim whitespace
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session
    $class_name = "Department: " . $department_name; // Department name to be displayed in the success message

    // Check if the ID and new department name are set
    if (empty($id) || empty($department_name)) {
        $_SESSION['error_message'] = "Error: Department ID and Department name cannot be empty.";
        header("Location: manage_departments.php");
        exit();
    }

    // Fetch the old department name before updating
    $old_stmt = $conn->prepare("SELECT department_name FROM departments WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_departments.php");
        exit();
    }

    $old_stmt->bind_param("i", $id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_department_name);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the old department name was found
    if (!$old_department_name) {
        $_SESSION['error_message'] = "Error: Department ID '$id' not found.";
        header("Location: manage_departments.php");
        exit();
    }

    // Check if the new department name already exists (excluding the current one)
    $check_stmt = $conn->prepare("SELECT COUNT(*) FROM departments WHERE department_name = ? AND id != ?");
    if (!$check_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_departments.php");
        exit();
    }

    $check_stmt->bind_param("si", $department_name, $id);
    $check_stmt->execute();
    $check_stmt->bind_result($count);
    $check_stmt->fetch();
    $check_stmt->close();

    if ($count > 0) {
        // Department already exists
        $_SESSION['error_message'] = "Error: Department '$department_name' already exists.";
    } else {
        // Prepare and execute the update statement for departments
        $stmt = $conn->prepare("UPDATE departments SET department_name = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
        if (!$stmt) {
            $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
            header("Location: manage_departments.php");
            exit();
        }

        $stmt->bind_param("si", $department_name, $id);

        if ($stmt->execute()) {
            // Log the activity
            $action = "Department Edited by Admin User";
            $description = "Admin User edited department ID $id from '$old_department_name' to '$department_name'.";
            $ip_address = $_SERVER['REMOTE_ADDR'];
            $user_agent = $_SERVER['HTTP_USER_AGENT'];

            $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
            if ($log_stmt) {
                $log_stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
                $log_stmt->execute();
            }

            $_SESSION['success_message'] = "Department updated successfully from '$old_department_name' to '$department_name'.";
        } else {
            $_SESSION['error_message'] = "Error updating department: " . $stmt->error;
        }
    }

    header("Location: manage_departments.php");
    exit();
}
?>