<?php
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection

// Check if the event ID is provided
if (isset($_GET['id'])) {
    $event_id = intval($_GET['id']); // Get the event ID from the query parameter

    // Prepare the SQL statement to fetch the event details
    $stmt = $conn->prepare("SELECT cc.*, d.department_name, yl.year_level 
                            FROM class_calendar cc
                            JOIN departments d ON cc.department_id = d.id
                            JOIN year_levels yl ON cc.year_level_id = yl.id
                            WHERE cc.id = ?");
    $stmt->bind_param("i", $event_id);
    $stmt->execute();
    $result = $stmt->get_result();

    // Check if the event exists
    if ($result->num_rows > 0) {
        $event = $result->fetch_assoc();
        // Return the event details as JSON
        echo json_encode($event);
    } else {
        // Return an error message if the event is not found
        echo json_encode(['error' => 'Event not found.']);
    }

    $stmt->close();
} else {
    // Return an error message if no ID is provided
    echo json_encode(['error' => 'No event ID provided.']);
}
?>