<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

header('Content-Type: application/json'); // Set the content type to JSON

if (isset($_GET['id'])) {
    $id = intval($_GET['id']); // Ensure the ID is treated as an integer

    // Prepare and execute the query to fetch assigned classes with additional details
    $stmt = $conn->prepare("
        SELECT c.id AS class_id, c.class_name, yl.year_level, d.department_name, c.description 
        FROM student_classes sc 
        JOIN classes c ON sc.class_id = c.id 
        LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
        LEFT JOIN departments d ON c.department_id = d.id 
        WHERE sc.student_id = ?
    ");
    
    if ($stmt) {
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        $assigned_classes = [];
        while ($row = $result->fetch_assoc()) {
            $assigned_classes[] = $row; // Collect class data with additional details
        }

        // Return the assigned classes as JSON
        echo json_encode($assigned_classes); // Return the assigned classes
    } else {
        // Return an error message if the statement preparation fails
        echo json_encode(['error' => 'Database query failed']);
    }
} else {
    // Return an error message if the ID is not set
    echo json_encode(['error' => 'Invalid request']);
}
?>