<?php
session_start();
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'admin') {
    echo "User  is not logged in or not an admin.";
    header("Location: ../login.php");
    exit();
}

// Display success or error messages
$success_message = $_SESSION['success_message'] ?? null;
$error_message = $_SESSION['error_message'] ?? null;
unset($_SESSION['success_message'], $_SESSION['error_message']);

include '../includes/dbcon.php'; // Include database connection

// Fetch departments
$departments = [];
$department_query = "SELECT id, department_name, created_at, updated_at FROM departments ORDER BY department_name";
$department_result = $conn->query($department_query);
if ($department_result && $department_result->num_rows > 0) {
    while ($row = $department_result->fetch_assoc()) {
        $departments[] = $row;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Departments</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 40px;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #a777e3;
            border-color: #a777e3;
        }
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/header.php'; ?>
    <?php include '../includes/admin_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Departments</h2>

        <!-- Button to trigger Add Department Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addDepartmentModal">
            <i class="fas fa-building"></i> Add Department
        </button>

        <div class="messages">
            <?php if ($success_message): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($success_message); ?>
                </div>
            <?php endif; ?>

            <?php if ($error_message): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($error_message); ?>
                </div>
            <?php endif; ?>
        </div>

        <!-- Departments Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th> <!-- Serial Number Column -->
                    <!-- <th>ID</th> -->
                    <th>Department Name</th>
                    <th>Created at</th>
                    <th>Updated at</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($departments) > 0): ?>
                    <?php foreach ($departments as $index => $department): ?>
                        <tr>
                            <td><?= $index + 1; ?></td> <!-- Serial Number -->
                            <!-- <td><?= htmlspecialchars($department['id']); ?></td> -->
                            <td><?= htmlspecialchars($department['department_name']); ?></td>
                            <td><?= htmlspecialchars($department['created_at']); ?> UTC</td>
                            <td><?= htmlspecialchars($department['updated_at']); ?> UTC</td>
                            <td>
                                <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editDepartmentModal' onclick='populateEditModal(<?= $department['id']; ?>)'><i class='fas fa-edit'></i> Edit</button>
                                <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteDepartmentModal' onclick='setDeleteModal(<?= $department['id']; ?>)'><i class='fas fa-trash'></i> Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr><td colspan='5'>No records found</td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Add Department Modal -->
    <div class="modal fade" id="addDepartmentModal" tabindex="-1" aria-labelledby="addDepartmentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addDepartmentModalLabel">Add Department</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_department.php" method="POST">
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="department_name" class="form-label">Department Name</label>
                            <input type="text" class="form-control" id="department_name" name="department_name" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add Department</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Department Modal -->
    <div class="modal fade" id="editDepartmentModal" tabindex="-1" aria-labelledby="editDepartmentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editDepartmentModalLabel">Edit Department</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_department.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="departmentId" name="id"> <!-- Changed name to 'id' -->
                        <div class="mb-3">
                            <label for="edit_department_name" class="form-label">Department Name</label>
                            <input type="text" class="form-control" id="edit_department_name" name="department_name" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Department</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Department Modal -->
    <div class="modal fade" id="deleteDepartmentModal" tabindex="-1" aria-labelledby="deleteDepartmentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteDepartmentModalLabel">Delete Department</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_department.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="department_id" id="deleteDepartmentId">
                        <p>Are you sure you want to delete this department?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete Department</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // JavaScript function to populate edit modal
        function populateEditModal(departmentId) {
            fetch(`get_department.php?id=${departmentId}`)
                .then(response => {
                    if (!response.ok) {
                        throw new Error(`HTTP error! Status: ${response.status}`);
                    }
                    return response.json();
                })
                .then(data => {
                    if (data && data.success) {
                        document.getElementById('departmentId').value = data.id || ''; // Set the ID
                        document.getElementById('edit_department_name').value = data.department_name || ''; // Set the department name
                    } else {
                        console.error('Error fetching department:', data.message);
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to set delete modal ID
        function setDeleteModal(departmentId) {
            document.getElementById('deleteDepartmentId').value = departmentId;
        }
    </script>
</body>
</html>