<?php
// Start output buffering at the beginning of the script
ob_start();
session_start();

// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'admin') {
    echo "User  is not logged in or not an admin.";
    header("Location: ../login.php");
    exit();
}


// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch faculty users with their avatars
$query = "SELECT u.*, a.avatar_path FROM users u LEFT JOIN avatars a ON u.role = a.role AND u.gender = a.gender WHERE u.role = 'faculty'";
$result = $conn->query($query);

// Fetch departments and year levels
$departments = [];
$year_levels = [];

// Fetch departments
$dept_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$dept_result = $conn->query($dept_query);
if ($dept_result->num_rows > 0) {
    while ($row = $dept_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels
$year_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}

// Pagination settings
$records_per_page_options = ['All', 10, 25, 50, 100, 250, 500];
$records_per_page = isset($_GET['records_per_page']) ? $_GET['records_per_page'] : 10; // Default to 10
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Default to page 1

// Get total records for pagination
$total_query = "SELECT COUNT(*) as total FROM users WHERE role = 'faculty'";
$total_result = $conn->query($total_query);
$total_row = $total_result->fetch_assoc();
$total_records = $total_row['total'];
$total_pages = ceil($total_records / ($records_per_page === 'All' ? $total_records : $records_per_page));

// Calculate offset
$offset = ($current_page - 1) * ($records_per_page === 'All' ? $total_records : $records_per_page);

// Fetch faculty users with pagination
$query = "
    SELECT * FROM users 
    WHERE role = 'faculty' 
    ORDER BY CONCAT(first_name, ' ', last_name)";

// Apply LIMIT only if records_per_page is not 'All'
if ($records_per_page !== 'All') {
    $query .= " LIMIT $offset, $records_per_page";
}

$results = $conn->query($query);

// Include PhpSpreadsheet classes
require '../vendor/autoload.php'; // Autoload all Composer dependencies

// Use statements for PhpSpreadsheet classes
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

// Handle export to Excel and PDF
if (isset($_POST['export_excel']) || isset($_POST['export_pdf'])) {
    // Prepare the export query
    $export_query = "
        SELECT u.*, d.department_name, yl.year_level 
        FROM users u
        LEFT JOIN departments d ON u.department_id = d.id
        LEFT JOIN year_levels yl ON u.year_level_id = yl.id
        WHERE u.role = 'faculty' 
        ORDER BY CONCAT(u.first_name, ' ', u.last_name)";
        // Apply LIMIT only if records_per_page is not 'All'
        if ($records_per_page !== 'All') {
            $export_query .= " LIMIT $offset, $records_per_page";
        }

    $export_results = $conn->query($export_query); // Execute the export query

    // Handle field selection for export
    $fields = [];
    if (isset($_POST['include_serial_no'])) $fields[] = 'S. No.';
    if (isset($_POST['include_full_name'])) $fields[] = 'Full Name';
    if (isset($_POST['include_username'])) $fields[] = 'Username';
    if (isset($_POST['include_email'])) $fields[] = 'Email';
    if (isset($_POST['include_mobile_number'])) $fields[] = 'Mobile Number';
    if (isset($_POST['include_register_number'])) $fields[] = 'Register Number';
    if (isset($_POST['include_gender'])) $fields[] = 'Gender';
    if (isset($_POST['include_department'])) $fields[] = 'Department';
    if (isset($_POST['include_year_level'])) $fields[] = 'Year Level';
    if (isset($_POST['include_status'])) $fields[] = 'Status';

    // Include PhpSpreadsheet for Excel export
    if (isset($_POST['export_excel'])) {
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $rowNumber = 1;

        // Set headers
        $columnIndex = 'A';
        if (isset($_POST['include_serial_no'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'S. No.');
        if (isset($_POST['include_full_name'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Full Name');
        if (isset($_POST['include_username'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Username');
        if (isset($_POST['include_email'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Email');
        if (isset($_POST['include_mobile_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Mobile Number');
        if (isset($_POST['include_register_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Register Number');
        if (isset($_POST['include_gender'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Gender');
        if (isset($_POST['include_department'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Department');
        if (isset($_POST['include_year_level'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Year Level');
        if (isset($_POST['include_status'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Status');

        // Populate data
        $rowNumber++;
        $serialNo = 1; // Initialize serial number
        while ($user = $export_results->fetch_assoc()) {
            $columnIndex = 'A';
            if (isset($_POST['include_serial_no'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $serialNo++);
            if (isset($_POST['include_full_name'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['first_name'] . ' ' . $user['last_name']);
            if (isset($_POST['include_username'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['username']);
            if (isset($_POST['include_email'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['email']);
            if (isset($_POST['include_mobile_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['mobile_number']);
            if (isset($_POST['include_register_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['register_number']);
            if (isset($_POST['include_gender'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['gender']);
            if (isset($_POST['include_department'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['department_name'] ?? 'N/A');
            if (isset($_POST['include_year_level'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['year_level'] ?? 'N/A');
            if (isset($_POST['include_status'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['approval_status']);
            $rowNumber++;
        }

        // Create Excel file
        $writer = new Xlsx($spreadsheet);
        $filename = 'faculty_users.xlsx';
                
        // Clear output buffer
        ob_end_clean(); // Clear any previous output

        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment; filename="' . $filename . '"');
        header('Cache-Control: max-age=0');

        // Save the file to output
        $writer->save('php://output');
        exit();
    }

    // Handle PDF export similarly using TCPDF
    if (isset($_POST['export_pdf'])) {
        require '../vendor/tecnickcom/tcpdf/tcpdf.php'; // Include TCPDF

        // Clear output buffer
        ob_end_clean(); // Clear any previous output

        // Create new PDF document
        $pdf = new TCPDF();
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetAuthor('AcademyClan - Think Beyond, Learn Beyond.');
        $pdf->SetTitle('AcademyClan - Faculty Users Details.');
        $pdf->SetHeaderData('', 0, 'AcademyClan - Think Beyond, Learn Beyond.', 'Generated on ' . date('Y-m-d H:i:s'));
        $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
        $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
        $pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
        $pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
        $pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
        $pdf->AddPage();

        // Set font
        $pdf->SetFont('helvetica', '', 12);
        
        // Create HTML table
        $html = '<h1>AcademyClan - Faculty Users Details</h1>';
        $html .= '<table border="1" cellpadding="4"><thead><tr>';

        // Set headers
        if (isset($_POST['include_serial_no'])) $html .= '<th>S. No.</th>';
        if (isset($_POST['include_full_name'])) $html .= '<th>Full Name</th>';
        if (isset($_POST['include_username'])) $html .= '<th>Username</th>';
        if (isset($_POST['include_email'])) $html .= '<th>Email</th>';
        if (isset($_POST['include_mobile_number'])) $html .= '<th>Mobile Number</th>';
        if (isset($_POST['include_register_number'])) $html .= '<th>Register Number</th>';
        if (isset($_POST['include_gender'])) $html .= '<th>Gender</th>';
        if (isset($_POST['include_department'])) $html .= '<th>Department</th>';
        if (isset($_POST['include_year_level'])) $html .= '<th>Year Level</th>';
        if (isset($_POST['include_status'])) $html .= '<th>Status</th>';
        $html .= '</tr></thead><tbody>';

        // Populate data
        $serialNo = 1; // Initialize serial number
        while ($user = $export_results->fetch_assoc()) {
            $html .= '<tr>';
            if (isset($_POST['include_serial_no'])) $html .= '<td>' . $serialNo++ . '</td>';
            if (isset($_POST['include_full_name'])) $html .= '<td>' . $user['first_name'] . ' ' . $user['last_name'] . '</td>';
            if (isset($_POST['include_username'])) $html .= '<td>' . $user['username'] . '</td>';
            if (isset($_POST['include_email'])) $html .= '<td>' . $user['email'] . '</td>';
            if (isset($_POST['include_mobile_number'])) $html .= '<td>' . $user['mobile_number'] . '</td>';
            if (isset($_POST['include_register_number'])) $html .= '<td>' . $user['register_number'] . '</td>';
            if (isset($_POST['include_gender'])) $html .= '<td>' . $user['gender'] . '</td>';
            if (isset($_POST['include_department'])) $html .= '<td>' . ($user['department_name'] ?? 'N/A') . '</td>';
            if (isset($_POST['include_year_level'])) $html .= '<td>' . ($user['year_level'] ?? 'N/A') . '</td>';
            if (isset($_POST['include_status'])) $html .= '<td>' . $user['approval_status'] . '</td>';
            $html .= '</tr>';
        }
        $html .= '</tbody></table>';
        $pdf->writeHTML($html, true, false, true, false, '');
        $pdf->Output('faculty_users.pdf', 'D');
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Faculty Users</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 40px;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #a777e3;
            border-color: #a777e3;
        }
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/header.php'; ?>
    <?php include '../includes/admin_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Faculty Users</h2>
        <!-- Records per page selection -->
        <form method="get" class="mb-3">
            <label for="records_per_page">Records per page:</label>
            <select name="records_per_page" id="records_per_page" onchange="this.form.submit()">
                <?php foreach ($records_per_page_options as $option): ?>
                    <option value="<?php echo $option; ?>" <?php echo $option == $records_per_page ? 'selected' : ''; ?>>
                        <?php echo $option; ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </form>

        <!-- Button to trigger Add Faculty Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addFacultyModal">
            <i class="fas fa-user-plus"></i> Add Faculty User
        </button>
        <!-- Button to trigger Export Modal -->
        <button type="button" class="btn btn-danger mb-3" data-bs-toggle="modal" data-bs-target="#exportModal">
            <i class="fas fa-file-export"></i> Export
        </button>

        <!-- Messages -->
        <div class="messages">
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($_SESSION['success_message']); ?>
                </div>
                <?php unset($_SESSION['success_message']); ?>
            <?php endif; ?>

            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($_SESSION['error_message']); ?>
                </div>
                <?php unset($_SESSION['error_message']); ?>
            <?php endif; ?>
        </div>

        <!-- Faculty Users Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th>
                    <th>Avatar</th>
                    <th>Full Name</th>
                    <th>Username</th>
                    <th>Email</th>
                    <th>Mobile Number</th>
                    <th>Register Number</th>
                    <th>Gender</th>
                    <th>Department</th>
                    <th>Year Level</th>
                    <th>Status</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php
                if ($results->num_rows > 0) {
                    $serialNo = 1; // Initialize serial number
                    while ($user = $results->fetch_assoc()) {
                        $dept_name = '';
                        $year_name = '';

                        // Get department name
                        foreach ($departments as $dept) {
                            if ($dept['id'] == $user['department_id']) {
                                $dept_name = $dept['department_name'];
                                break;
                            }
                        }

                        // Get year level
                        foreach ($year_levels as $year) {
                            if ($year['id'] == $user['year_level_id']) {
                                $year_name = $year['year_level'];
                                break;
                            }
                        }

                        // Fetch avatar based on role and gender
                        $stmt = $conn->prepare("SELECT avatar_path FROM avatars WHERE role = ? AND gender = ?");
                        $stmt->bind_param("ss", $user['role'], $user['gender']);
                        $stmt->execute();
                        $avatar_result = $stmt->get_result();
                        if ($avatar_result->num_rows > 0) {
                            $avatar_data = $avatar_result->fetch_assoc();
                            $avatar_path = $avatar_data['avatar_path'];
                        } else {
                            $avatar_path = '../uploads/avatars/default-avatar.png'; // Default avatar if none found
                        }

                        echo "
                            <tr>
                                <td>{$serialNo}</td>
                                <td><img src='../uploads/{$avatar_path}' alt='avatar' class='avatar' height='50px' width='50px'></td>
                                <td>{$user['first_name']} {$user['last_name']}</td>
                                <td>{$user['username']}</td>
                                <td>{$user['email']}</td>
                                <td>{$user['mobile_number']}</td>
                                <td>{$user['register_number']}</td>
                                <td>{$user['gender']}</td>
                                <td>{$dept_name}</td>
                                <td>{$year_name}</td>
                                <td>{$user['approval_status']}</td>
                                <td>
                                    <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editFacultyModal' onclick='populateEditModal({$user['id']})'><i class='fas fa-edit'></i> Edit</button>
                                    <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteFacultyModal' onclick='setDeleteModal({$user['id']})'><i class='fas fa-trash'></i> Delete</button>
                                </td>
                            </tr>
                        ";
                        $serialNo++; // Increment serial number
                    }
                } else {
                    echo "<tr><td colspan='12'>No records found</td></tr>";
                }
                ?>
            </tbody>
        </table>

        <!-- Pagination controls -->
        <nav aria-label="Page navigation">
            <ul class="pagination justify-content-left">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=1&records_per_page=<?php echo $records_per_page; ?>" aria-label="First">
                            <span aria-hidden="true">&laquo;&laquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page - 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Previous">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>
                <?php endif; ?>

                <?php
                $max_displayed_pages = 17; // Total number of pages to display
                $start_page = max(1, $current_page - floor($max_displayed_pages / 2));
                $end_page = min($total_pages, $start_page + $max_displayed_pages - 1);

                // Adjust start page if there are not enough pages before the current page
                if ($end_page - $start_page < $max_displayed_pages - 1) {
                    $start_page = max(1, $end_page - $max_displayed_pages + 1);
                }

                // Ensure we do not exceed the total number of pages
                if ($end_page > $total_pages) {
                    $end_page = $total_pages;
                }

                // Display pages
                for ($i = $start_page; $i <= $end_page; $i++): ?>
                    <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?php echo $i; ?>&records_per_page=<?php echo $records_per_page; ?>"><?php echo $i; ?></a>
                    </li>
                <?php endfor; ?>

                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page + 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Next">
                            <span aria-hidden="true">&raquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $total_pages; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Last">
                            <span aria-hidden="true">&raquo;&raquo;</span>
                        </a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>
    </div>

    <!-- Export Modal -->
    <div class="modal fade" id="exportModal" tabindex="-1" aria-labelledby="exportModalLabel" aria -labelledby="exportModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exportModalLabel">Export Options</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="post">
                    <div class="modal-body">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="select_all_fields" onclick="toggleFieldCheckboxes(this)">
                            <label class="form-check-label" for="select_all_fields">Select All Fields</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_serial_no" name="include_serial_no" value="1" checked>
                            <label class="form-check-label" for="include_serial_no">Include Serial No</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_full_name" name="include_full_name" value="1" checked>
                            <label class="form-check-label" for="include_full_name">Include Full Name</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_username" name="include_username" value="1" checked>
                            <label class="form-check-label" for="include_username">Include Username</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_email" name="include_email" value="1" checked>
                            <label class="form-check-label" for="include_email">Include Email</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_mobile_number" name="include_mobile_number" value="1" checked>
                            <label class="form-check-label" for="include_mobile_number">Include Mobile Number</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_register_number" name="include_register_number" value="1" checked>
                            <label class="form-check-label" for="include_register_number">Include Register Number</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_gender" name="include_gender" value="1" checked>
                            <label class="form-check-label" for="include_gender">Include Gender</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_department" name="include_department" value="1" checked>
                            <label class="form-check-label" for="include_department">Include Department</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_year_level" name="include_year_level" value="1" checked>
                            <label class="form-check-label" for="include_year_level">Include Year Level</label>
                        </div>
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="include_status" name="include_status" value="1" checked>
                            <label class="form-check-label" for="include_status">Include Status</label>
                        </div>
                        <div class="modal-footer">
                            <button type="submit" name="export_excel" class="btn btn-success"><i class="fas fa-file-excel"></i> Export to Excel</button>
                            <button type="submit" name="export_pdf" class="btn btn-danger"><i class="fas fa-file-pdf"></i> Export to PDF</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Add Faculty Modal -->
    <div class="modal fade" id="addFacultyModal" tabindex="-1" aria-labelledby="addFacultyModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addFacultyModalLabel">Add Faculty User</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_faculty_user.php" method="POST">
                    <div class="modal-body">
                        <div class="mb ```php
                        <div class="mb-3">
                            <label for="first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="first_name" name="first_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="last_name" name="last_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="username" name="username" required>
                        </div>
                        <div class="mb-3">
                            <label for="email" class="form-label">Email</label>
                            <input type="email" class="form-control" id="email" name="email" required>
                        </div>
                        <div class="mb-3">
                            <label for="mobile_number" class="form-label">Mobile Number</label>
                            <input type="text" class="form-control" id="mobile_number" name="mobile_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="register_number" class="form-label">Register Number</label>
                            <input type="text" class="form-control" id="register_number" name="register_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="gender" class="form-label">Gender</label>
                            <select class="form-select" id="gender" name="gender" required>
                                <option value="male">Male</option>
                                <option value="female">Female</option>
                                <option value="other">Other</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="department_id" class="form-label">Department</label>
                            <select class="form-select" id="department_id" name="department_id" required>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= $dept['department_name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="year_level_id" name="year_level_id" required>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= $year['year_level'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add User</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Faculty Modal -->
    <div class="modal fade" id="editFacultyModal" tabindex="-1" aria-labelledby="editFacultyModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editFacultyModalLabel">Edit Faculty User</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_faculty_user.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="facultyId" name="id">
                        <div class="mb-3">
                            <label for="edit_first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="edit_first_name" name="first_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="edit_last_name" name="last_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="edit_username" name="username" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_email" class="form-label">Email</label>
                            <input type="email" ```php
                            class="form-control" id="edit_email" name="email" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_mobile_number" class="form-label">Mobile Number</label>
                            <input type="text" class="form-control" id="edit_mobile_number" name="mobile_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_register_number" class="form-label">Register Number</label>
                            <input type="text" class="form-control" id="edit_register_number" name="register_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_gender" class="form-label">Gender</label>
                            <select class="form-select" id="edit_gender" name="gender" required>
                                <option value="male">Male</option>
                                <option value="female">Female</option>
                                <option value="other">Other</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_department_id" class="form-label">Department</label>
                            <select class="form-select" id="edit_department_id" name="department_id" required>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= $dept['department_name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="edit_year_level_id" name="year_level_id" required>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= $year['year_level'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_approval_status" class="form-label">Approval Status</label>
                            <select class="form-select" id="edit_approval_status" name="approval_status" required>
                                <option value="pending">Pending</option>
                                <option value="approved">Approved</option>
                                <option value="rejected">Rejected</option>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Faculty</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Faculty Modal -->
    <div class="modal fade" id="deleteFacultyModal" tabindex="-1" aria-labelledby="deleteFacultyModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteFacultyModalLabel">Delete Faculty User</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_faculty_user.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="id" id="deleteFacultyId">
                        <p>Are you sure you want to delete this faculty user?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete User</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // JavaScript function to populate edit modal
        function populateEditModal(facultyId) {
            fetch(`get_faculty_user.php?id=${facultyId}`)
                .then(response => {
                    if (!response.ok) {
                        throw new Error(`HTTP error! Status: ${response.status}`);
                    }
                    return response.json();
                })
                .then(data => {
                    if (data && typeof data === 'object') {
                        document.getElementById('facultyId').value = data.id || '';
                        document.getElementById('edit_first_name').value = data.first_name || '';
                        document.getElementById('edit_last_name').value = data.last_name || '';
                        document.getElementById('edit_username').value = data.username || '';
                        document.getElementById('edit_email').value = data.email || '';
                        document.getElementById('edit_mobile_number').value = data.mobile_number || '';
                        document.getElementById('edit_register_number').value = data.register_number || '';
                        document.getElementById('edit_gender').value = data.gender || '';
                        document.getElementById('edit_department_id').value = data.department_id || '';
                        document.getElementById('edit_year_level_id').value = data.year_level_id || '';
                        document.getElementById('edit_approval_status').value = data.approval_status || '';
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to set delete modal ID
        function setDeleteModal(facultyId) {
            document.getElementById('deleteFacultyId').value = facultyId;
        }

        // Function to toggle field checkboxes
        function toggleFieldCheckboxes(selectAllCheckbox) {
            const checkboxes = document.querySelectorAll('input[type="checkbox"]:not(#select_all_fields)');
            checkboxes.forEach(checkbox => {
                checkbox.checked = selectAllCheckbox.checked;
            });
        }
    </script>
</body>
</html>