<?php
// Include session and database connection
include('../includes/session.php');
include('../includes/dbcon.php');

// Check if the user is logged in and is an admin
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'admin') {
    header("Location: ../login.php");
    exit();
}

// Add new lesson
if (isset($_POST['add_lesson'])) {
    $lesson_title = mysqli_real_escape_string($conn, $_POST['lesson_title']);
    $lesson_description = mysqli_real_escape_string($conn, $_POST['lesson_description']);
    $subject_id = $_POST['subject_id'];

    // Insert the new lesson into the database
    $query = "INSERT INTO lessons (lesson_title, lesson_description, subject_id) 
              VALUES ('$lesson_title', '$lesson_description', '$subject_id')";

    if (mysqli_query($conn, $query)) {
        $success_message = "Lesson added successfully!";
    } else {
        $error_message = "Error adding lesson: " . mysqli_error($conn);
    }
}

// Delete lesson
if (isset($_GET['delete_id'])) {
    $lesson_id = $_GET['delete_id'];
    $query = "DELETE FROM lessons WHERE lesson_id = '$lesson_id'";

    if (mysqli_query($conn, $query)) {
        $success_message = "Lesson deleted successfully!";
    } else {
        $error_message = "Error deleting lesson: " . mysqli_error($conn);
    }
}

// Fetch lessons and subjects
$query_lessons = "SELECT * FROM lessons";
$result_lessons = mysqli_query($conn, $query_lessons);

$query_subjects = "SELECT * FROM subjects";
$result_subjects = mysqli_query($conn, $query_subjects);
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Lessons - Online Learning System</title>
    <link rel="stylesheet" href="../assets/plugins/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" href="../assets/css/styles.css">
</head>

<body>
    <!-- Navigation Bar -->
    <nav class="navbar navbar-expand-lg navbar-light bg-light">
        <div class="container-fluid">
            <a class="navbar-brand" href="#">Online Learning System - Admin</a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav ms-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="dashboard.php">Dashboard</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="manage_faculty.php">Manage Faculty</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="manage_students.php">Manage Students</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link active" href="manage_lessons.php">Manage Lessons</a>
                    </li>
                    <li class="nav-item">
                        <a class="nav-link" href="../logout.php">Logout</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

    <!-- Main Content -->
    <div class="container mt-5">
        <h2>Manage Lessons</h2>

        <!-- Success/Error Messages -->
        <?php if (isset($success_message)): ?>
            <div class="alert alert-success"><?php echo $success_message; ?></div>
        <?php endif; ?>
        <?php if (isset($error_message)): ?>
            <div class="alert alert-danger"><?php echo $error_message; ?></div>
        <?php endif; ?>

        <!-- Add Lesson Form -->
        <h4 class="mt-4">Add New Lesson</h4>
        <form action="manage_lessons.php" method="POST">
            <div class="mb-3">
                <label for="lesson_title" class="form-label">Lesson Title</label>
                <input type="text" class="form-control" id="lesson_title" name="lesson_title" required>
            </div>
            <div class="mb-3">
                <label for="lesson_description" class="form-label">Lesson Description</label>
                <textarea class="form-control" id="lesson_description" name="lesson_description" rows="4" required></textarea>
            </div>
            <div class="mb-3">
                <label for="subject_id" class="form-label">Select Subject</label>
                <select class="form-control" id="subject_id" name="subject_id" required>
                    <option value="">Select a Subject</option>
                    <?php while ($subject = mysqli_fetch_assoc($result_subjects)): ?>
                        <option value="<?php echo $subject['subject_id']; ?>"><?php echo $subject['subject_name']; ?></option>
                    <?php endwhile; ?>
                </select>
            </div>
            <button type="submit" class="btn btn-primary" name="add_lesson">Add Lesson</button>
        </form>

        <!-- Lessons List -->
        <h4 class="mt-5">Lesson List</h4>
        <table class="table table-bordered mt-3">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Lesson Title</th>
                    <th>Subject</th>
                    <th>Description</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($lesson = mysqli_fetch_assoc($result_lessons)): ?>
                    <?php
                        // Get subject name for each lesson
                        $subject_id = $lesson['subject_id'];
                        $query_subject = "SELECT subject_name FROM subjects WHERE subject_id = '$subject_id'";
                        $result_subject = mysqli_query($conn, $query_subject);
                        $subject = mysqli_fetch_assoc($result_subject);
                    ?>
                    <tr>
                        <td><?php echo $lesson['lesson_id']; ?></td>
                        <td><?php echo $lesson['lesson_title']; ?></td>
                        <td><?php echo $subject['subject_name']; ?></td>
                        <td><?php echo $lesson['lesson_description']; ?></td>
                        <td>
                            <a href="edit_lesson.php?id=<?php echo $lesson['lesson_id']; ?>" class="btn btn-warning btn-sm">Edit</a>
                            <a href="manage_lessons.php?delete_id=<?php echo $lesson['lesson_id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this lesson?')">Delete</a>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    </div>

    <!-- Footer -->
    <footer class="footer mt-auto py-3 bg-light">
        <div class="container">
            <p class="text-center mb-0">Online Learning System - Admin - © 2025</p>
        </div>
    </footer>

    <script src="../assets/plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
</body>

</html>
