<?php
// Include session and database connection
include('../includes/session.php');
include('../includes/dbcon.php');

// Check if the user is a faculty member (session should have faculty_id)
if (!isset($_SESSION['faculty_id'])) {
    header("Location: ../login.php");  // Redirect to login if not logged in
    exit();
}

$faculty_id = $_SESSION['faculty_id'];

// Fetch quizzes created by the logged-in faculty
$quiz_query = "SELECT * FROM quizzes WHERE faculty_id = ?";
$quiz_stmt = $conn->prepare($quiz_query);
$quiz_stmt->bind_param("i", $faculty_id);
$quiz_stmt->execute();
$quiz_result = $quiz_stmt->get_result();

// Handle deleting a quiz
if (isset($_GET['delete_quiz_id'])) {
    $quiz_id = $_GET['delete_quiz_id'];
    
    // Delete associated questions and answers first
    $delete_answers_query = "DELETE FROM answers WHERE question_id IN (SELECT id FROM questions WHERE quiz_id = ?)";
    $delete_answers_stmt = $conn->prepare($delete_answers_query);
    $delete_answers_stmt->bind_param("i", $quiz_id);
    $delete_answers_stmt->execute();
    
    $delete_questions_query = "DELETE FROM questions WHERE quiz_id = ?";
    $delete_questions_stmt = $conn->prepare($delete_questions_query);
    $delete_questions_stmt->bind_param("i", $quiz_id);
    $delete_questions_stmt->execute();
    
    // Then delete the quiz itself
    $delete_quiz_query = "DELETE FROM quizzes WHERE id = ?";
    $delete_quiz_stmt = $conn->prepare($delete_quiz_query);
    $delete_quiz_stmt->bind_param("i", $quiz_id);
    $delete_quiz_stmt->execute();
    
    // Redirect after deletion
    header("Location: manage_quiz.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Manage Quizzes - Online Learning System v2</title>
    
    <!-- Bootstrap CSS -->
    <link href="../assets/plugins/bootstrap/css/bootstrap.min.css" rel="stylesheet">
    <!-- Custom CSS -->
    <link href="../assets/css/styles.css" rel="stylesheet">
</head>
<body>

<?php include('../includes/header.php'); ?>

<div class="container mt-5">
    <h2>Manage Your Quizzes</h2>
    
    <a href="create_quiz.php" class="btn btn-primary mb-4">Create New Quiz</a>
    
    <?php if ($quiz_result->num_rows > 0): ?>
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>#</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Due Date</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php while ($quiz = $quiz_result->fetch_assoc()): ?>
                    <tr>
                        <td><?php echo $quiz['id']; ?></td>
                        <td><?php echo $quiz['title']; ?></td>
                        <td><?php echo $quiz['description']; ?></td>
                        <td><?php echo date('Y-m-d H:i', strtotime($quiz['due_date'])); ?></td>
                        <td>
                            <a href="edit_quiz.php?quiz_id=<?php echo $quiz['id']; ?>" class="btn btn-warning btn-sm">Edit</a>
                            <a href="?delete_quiz_id=<?php echo $quiz['id']; ?>" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this quiz?')">Delete</a>
                        </td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    <?php else: ?>
        <div class="alert alert-warning">You haven't created any quizzes yet.</div>
    <?php endif; ?>
</div>

<?php include('../includes/footer.php'); ?>

<!-- Optional JS -->
<script src="../assets/plugins/jquery/jquery.min.js"></script>
<script src="../assets/plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
</body>
</html>
