<?php
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'admin') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch all assignments along with class details
$query = "SELECT a.*, c.class_name, d.department_name, yl.year_level, u.username 
          FROM assignments a 
          LEFT JOIN classes c ON a.class_id = c.id 
          LEFT JOIN departments d ON c.department_id = d.id 
          LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
          LEFT JOIN users u ON a.faculty_id = u.id 
          ORDER BY a.due_date DESC";

$results = $conn->query($query);

if (!$results) {
    die("Query failed: " . $conn->error);
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Assignments</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .sidebar {
            height: 100%;
            background-color: #a777e3;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #a777e3; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
        
        .container {
            padding: 80px 30px;
        }
        .success {
            background-color: #d4edda; /* Light green */
        }
        .warning {
            background-color: #fff3cd; /* Light yellow */
        }
        .danger {
            background-color: #f8d7da; /* Light red */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/header.php'; ?>
    <?php include '../includes/admin_sidebar.php'; ?>

    <div class="container">
        <h1>All Assignments</h1>

        <table class="table">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Class</th>
                    <th>Due Date</th>
                    <th>Created At</th>
                    <th>Uploaded By</th>
                </tr>
            </thead>
            <tbody>
            <?php if ($results->num_rows > 0): ?>
            <?php $serialNumber = 1; // Initialize serial number ?>
            <?php $currentDate = new DateTime(); // Current date ?>
            <?php while ($assignment = $results->fetch_assoc()): ?>
                <?php
                $dueDate = new DateTime($assignment['due_date']);
                $interval = $currentDate->diff($dueDate);
                
                // Determine the class based on the due date
                if ($dueDate < $currentDate) {
                    $class = 'danger'; // Overdue
                } elseif ($interval->days <= 1) {
                    $class = 'danger'; // Due today
                } elseif ($interval->days <= 3) {
                    $class = 'warning'; // Due in 3 days
                } else {
                    $class = 'success'; // More than 3 days away
                }
                ?>
                <tr class="<?= $class; ?>">
                    <td><?= $serialNumber++; ?></td> <!-- Display serial number -->
                    <td><?= htmlspecialchars($assignment['title']); ?></td>
                    <td><?= htmlspecialchars($assignment['description']); ?></td>
                    <td><?= htmlspecialchars($assignment['class_name'] . ' - ' . $assignment['year_level'] . ' (' . $assignment['department_name'] . ')'); ?></td>
                    <td><?= htmlspecialchars($assignment['due_date']); ?></td>
                    <td><?= htmlspecialchars($assignment['created_at']); ?></td>
                    <td><?= htmlspecialchars($assignment['username']); ?></td> <!-- Display the faculty member's username -->
                </tr>
            <?php endwhile; ?>
        <?php else: ?>
            <tr>
                <td colspan="7" class="text-center">No assignments created yet.</td>
            </tr>
        <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
// Close the database connection
$conn->close();
?>