<?php
session_start();
require_once 'includes/dbcon.php'; // Database connection

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php"); // Redirect if not logged in
    exit();
}

// Fetch user data
$stmt = $conn->prepare("SELECT * FROM users WHERE id = ?");
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo "User not found.";
    exit();
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $first_name = htmlspecialchars($_POST['first_name']);
    $last_name = htmlspecialchars($_POST['last_name']);
    $mobile_number = htmlspecialchars($_POST['mobile_number']);
    $department_id = isset($_POST['department_id']) ? htmlspecialchars($_POST['department_id']) : null;
    $year_level_id = isset($_POST['year_level_id']) ? htmlspecialchars($_POST['year_level_id']) : null;

    // Validate input
    if (empty($first_name) || empty($last_name) || empty($mobile_number)) {
        $error = "All fields are required.";
    } else {
        // Update user data
        $update_stmt = $conn->prepare(
            "UPDATE users SET first_name = ?, last_name = ?, mobile_number = ?, department_id = ?, year_level_id = ? WHERE id = ?"
        );
        $update_stmt->bind_param(
            "ssssii",
            $first_name,
            $last_name,
            $mobile_number,
            $department_id,
            $year_level_id,
            $_SESSION['user_id']
        );

        if ($update_stmt->execute()) {
            $success = "Profile updated successfully.";
            // Refresh user data
            $stmt->execute();
            $user = $stmt->get_result()->fetch_assoc();
        } else {
            $error = "Failed to update profile.";
        }
    }
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Profile</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
</head>

<body>
    <div class="container mt-5" style="max-width: 600px;">
        <h2 class="text-center mb-4"><i class="fas fa-edit"></i> Edit Profile</h2>
        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?php echo $error; ?></div>
        <?php endif; ?>
        <?php if (isset($success)): ?>
            <div class="alert alert-success"><?php echo $success; ?></div>
        <?php endif; ?>
        <form method="POST">
            <div class="mb-3">
                <label for="first_name" class="form-label">First Name</label>
                <input type="text" name="first_name" id="first_name" class="form-control" value="<?php echo htmlspecialchars($user['first_name']); ?>" required>
            </div>
            <div class="mb-3">
                <label for="last_name" class="form-label">Last Name</label>
                <input type="text" name="last_name" id="last_name" class="form-control" value="<?php echo htmlspecialchars($user['last_name']); ?>" required>
            </div>
            <div class="mb-3">
                <label for="mobile_number" class="form-label">Mobile Number</label>
                <input type="text" name="mobile_number" id="mobile_number" class="form-control" value="<?php echo htmlspecialchars($user['mobile_number']); ?>" required>
            </div>
            <?php if ($user['role'] === 'student'): ?>
                <div class="mb-3">
                    <label for="department_id" class="form-label">Department ID</label>
                    <input type="text" name="department_id" id="department_id" class="form-control" value="<?php echo htmlspecialchars($user['department_id']); ?>">
                </div>
                <div class="mb-3">
                    <label for="year_level_id" class="form-label">Year Level ID</label>
                    <input type="text" name="year_level_id" id="year_level_id" class="form-control" value="<?php echo htmlspecialchars($user['year_level_id']); ?>">
                </div>
            <?php endif; ?>
            <button type="submit" class="btn btn-primary w-100">Save Changes</button>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>
