<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $class_id = $_POST['class_id'];
    $date = $_POST['date'];
    $status = $_POST['status'];

    // Check if student_ids are set
    if (isset($_POST['student_ids']) && is_array($_POST['student_ids'])) {
        foreach ($_POST['student_ids'] as $student_id) {
            // Check for duplicate attendance entry
            $check_stmt = $conn->prepare("SELECT COUNT(*) FROM attendance WHERE student_id = ? AND class_id = ? AND date = ?");
            $check_stmt->bind_param("iis", $student_id, $class_id, $date);
            $check_stmt->execute();
            $check_stmt->bind_result($count);
            $check_stmt->fetch();
            $check_stmt->close();

            if ($count > 0) {
                // Attendance record already exists for this student
                $_SESSION['error_message'] = "Error: Attendance record already exists for student ID: $student_id on this date.";
                // Optionally, you can break the loop or continue to the next student
                continue; // Skip to the next student
            } else {
                // Prepare and execute the insert statement for attendance
                $stmt = $conn->prepare("INSERT INTO attendance (student_id, class_id, date, status) VALUES (?, ?, ?, ?)");
                $stmt->bind_param("iiss", $student_id, $class_id, $date, $status);

                if ($stmt->execute()) {
                    // Log the activity
                    $action = "Attendance marked by Faculty";
                    $description_log = "Marked attendance for student ID: " . $student_id . " in class ID: " . $class_id . " on date: " . $date;
                    $ip_address = $_SERVER['REMOTE_ADDR'];
                    $user_agent = $_SERVER['HTTP_USER_AGENT'];
                    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session

                    $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
                    $log_stmt->bind_param("issss", $user_id, $action, $description_log, $ip_address, $user_agent);
                    $log_stmt->execute();
                } else {
                    $_SESSION['error_message'] = "Error marking attendance for student ID: $student_id.";
                }
            }
        }

        // Set success message if at least one attendance was marked
        $_SESSION['success_message'] = "Attendance marked successfully for selected students.";
    } else {
        $_SESSION['error_message'] = "No students selected.";
    }

    header("Location: manage_attendance.php");
    exit();
}
?>