<?php
session_start();
include '../includes/dbcon.php'; // Include database connection
include '../activity_log.php'; // Include activity log script

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Trim and sanitize inputs
    $student_id = trim($_POST['student_id']);
    $class_ids = isset($_POST['class_id']) ? $_POST['class_id'] : []; // Ensure class_ids is an array
    $remove_class_ids = isset($_POST['remove_class_id']) ? $_POST['remove_class_id'] : []; // Ensure remove_class_ids is an array

    // Check for empty fields
    if (!empty($student_id)) {
        // Fetch student user details
        $stmt = $conn->prepare("SELECT first_name, last_name FROM users WHERE id = ? AND role = 'student'");
        $stmt->bind_param("i", $student_id);
        $stmt->execute();
        $student_result = $stmt->get_result();
        $student = $student_result->fetch_assoc();

        if ($student) {
            $student_name = $student['first_name'] . ' ' . $student['last_name'];

            // Fetch currently assigned classes
            $current_classes_query = "SELECT class_id FROM student_classes WHERE student_id = ?";
            $current_classes_stmt = $conn->prepare($current_classes_query);
            $current_classes_stmt->bind_param("i", $student_id);
            $current_classes_stmt->execute();
            $current_classes_result = $current_classes_stmt->get_result();

            // Store currently assigned class IDs
            $current_assigned_ids = [];
            while ($row = $current_classes_result->fetch_assoc()) {
                $current_assigned_ids[] = $row['class_id'];
            }

            // Remove existing class assignments
            if (!empty($remove_class_ids)) {
                $removed_classes = []; // Array to hold removed class names
                foreach ($remove_class_ids as $class_id) {
                    // Fetch class name for logging
                    $class_stmt = $conn->prepare("SELECT class_name FROM classes WHERE id = ?");
                    $class_stmt->bind_param("i", $class_id);
                    $class_stmt->execute();
                    $class_result = $class_stmt->get_result();
                    $class_data = $class_result->fetch_assoc();

                    if ($class_data) {
                        // Log the removal of the class
                        logActivity($conn, $student_id, 'Class Removed by Faculty User', "$student_name removed from Class - " . $class_data['class_name']);
                        $removed_classes[] = $class_data['class_name']; // Store removed class name
                    }
                }

                // Remove existing class assignments
                $delete_stmt = $conn->prepare("DELETE FROM student_classes WHERE student_id = ? AND class_id IN (" . implode(',', $remove_class_ids) . ")");
                $delete_stmt->bind_param("i", $student_id);
                if ($delete_stmt->execute()) {
                    // Set success message for removal
                    $_SESSION['success_message'] = "$student_name successfully removed from the following classes: " . implode(", ", $removed_classes) . ".";
                }
            }

            // Assign classes to student
            $assigned_classes = [];
            foreach ($class_ids as $class_id) {
                // If not assigned, insert into student_classes
                if (!in_array($class_id, $current_assigned_ids)) {
                    $stmt = $conn->prepare("INSERT INTO student_classes (student_id, class_id, assigned_at) VALUES (?, ?, NOW())");
                    $stmt->bind_param("ii", $student_id, $class_id);

                    if ($stmt->execute()) {
                        // Fetch class name for logging
                        $class_stmt = $conn->prepare("SELECT class_name FROM classes WHERE id = ?");
                        $class_stmt->bind_param("i", $class_id);
                        $class_stmt->execute();
                        $class_result = $class_stmt->get_result();
                        $class_data = $class_result->fetch_assoc();

                        if ($class_data) {
                            $assigned_classes[] = $class_data['class_name'];
                        }

                        // Log the class assignment
                        logActivity($conn, $student_id, 'Class Assigned by Faculty User', "$student_name assigned to Class - " . $class_data['class_name']);
                    } else {
                        $_SESSION['error_message'] = "Something went wrong while assigning classes. Please try again.";
                        header("Location: manage_students.php");
                        exit();
                    }
                }
            }

            // Set success message for assignment
            if (!empty($assigned_classes)) {
                $_SESSION['success_message'] .= "$student_name assigned to Class - " . implode(", ", $assigned_classes) . " successfully.";
            }

            header("Location: manage_students.php");
            exit();
        } else {
            $_SESSION['error_message'] = "Student not found.";
            header("Location: manage_students.php");
            exit();
        }
    } else {
        $_SESSION['error_message'] = "Please fill in all fields.";
        header("Location: manage_students.php");
        exit();
    }
} else {
    // If the request method is not POST, redirect to manage students
    header("Location: manage_students.php");
    exit();
}
?>