<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php'; // Include database connection

// Fetch departments and year levels
$departments = [];
$year_levels = [];

// Fetch departments
$dept_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$dept_result = $conn->query($dept_query);
if ($dept_result->num_rows > 0) {
    while ($row = $dept_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels
$year_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}

// Handle form submissions for adding, editing, and deleting events
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $user_id = $_SESSION['user_id']; // Assuming user_id is stored in session

    if (isset($_POST['add_event'])) {
        // Add event logic
        $department_id = $_POST['department_id'];
        $year_level_id = $_POST['year_level_id'];
        $event_title = $_POST['event_title'];
        $event_description = $_POST['event_description'];
        $event_date = $_POST['event_date'];

        // Check for duplicate event
        $check_query = "SELECT * FROM class_calendar WHERE department_id = ? AND year_level_id = ? AND event_title = ? AND event_description = ? AND event_date = ?";
        $check_stmt = $conn->prepare($check_query);
        $check_stmt->bind_param("iisss", $department_id, $year_level_id, $event_title, $event_description, $event_date);
        $check_stmt->execute();
        $check_result = $check_stmt->get_result();

        if ($check_result->num_rows > 0) {
            $error_message = "An event with the same title, description, and date already exists for this department and year level.";
        } else {
            $stmt = $conn->prepare("INSERT INTO class_calendar (department_id, year_level_id, event_title, event_description, event_date) VALUES (?, ?, ?, ?, ?)");
            $stmt->bind_param("iisss", $department_id, $year_level_id, $event_title, $event_description, $event_date);
            if ($stmt->execute()) {
                // Log activity
                logActivity($conn, $user_id, 'Faculty user added an Event', "Added event: '$event_title' with description: '$event_description', Department: '$department_id', Year Level: '$year_level_id', Event Date: '$event_date'");
                $success_message = "Event added successfully with event: '$event_title' , Description: '$event_description', Department: '{$department['department_name']}', Year Level: '{$year_level['year_level']}', Event Date: '$event_date'!";
            } else {
                $error_message = "Error adding event: " . $conn->error;
            }
            $stmt->close();
        }
    } elseif (isset($_POST['edit_event'])) {
        // Edit event logic
        $event_id = $_POST['event_id'];
        $department_id = $_POST['department_id'];
        $year_level_id = $_POST['year_level_id'];
        $event_title = $_POST['event_title'];
        $event_description = $_POST['event_description'];
        $event_date = $_POST['event_date'];

        // Fetch old event details for logging
        $old_event_query = "SELECT event_title, event_description, department_id, year_level_id, event_date FROM class_calendar WHERE id=?";
        $old_event_stmt = $conn->prepare($old_event_query);
        $old_event_stmt->bind_param("i", $event_id);
        $old_event_stmt->execute();
        $old_event_result = $old_event_stmt->get_result();
        $old_event = $old_event_result->fetch_assoc();

        // Prepare the update statement
        $stmt = $conn->prepare("UPDATE class_calendar SET department_id=?, year_level_id=?, event_title=?, event_description=?, event_date=? WHERE id=?");
        $stmt->bind_param("iisssi", $department_id, $year_level_id, $event_title, $event_description, $event_date, $event_id);

        // Initialize an array to hold changes
        $changes = [];

        // Compare old and new values
        if ($old_event['event_title'] !== $event_title) {
            $changes[] = "Event title changed from '{$old_event['event_title']}' to '$event_title'";
        }
        if ($old_event['event_description'] !== $event_description) {
            $changes[] = "Event description changed from '{$old_event['event_description']}' to '$event_description'";
        }
        if ((int)$old_event['department_id'] !== (int)$department_id) {
            // Fetch new department name
            $dept_query = "SELECT department_name FROM departments WHERE id = ?";
            $dept_stmt = $conn->prepare($dept_query);
            $dept_stmt->bind_param("i", $department_id);
            $dept_stmt->execute();
            $dept_result = $dept_stmt->get_result();
            $department = $dept_result->fetch_assoc();
            $changes[] = "Event department changed from '{$old_event['department_name']}' to '{$department['department_name']}'";
        }
        if ((int)$old_event['year_level_id'] !== (int)$year_level_id) {
            // Fetch new year level
            $year_query = "SELECT year_level FROM year_levels WHERE id = ?";
            $year_stmt = $conn->prepare($year_query);
            $year_stmt->bind_param("i", $year_level_id);
            $year_stmt->execute();
            $year_result = $year_stmt->get_result();
            $year_level = $year_result->fetch_assoc();
            $changes[] = "Event year level changed from '{$old_event['year_level']}' to '{$year_level['year_level']}'";
        }
        if ($old_event['event_date'] !== $event_date) {
            $changes[] = "Event date changed from '{$old_event['event_date']}' to '$event_date'";
        }

        // Execute the update
        if ($stmt->execute()) {
            // Log only the changes made
            if (!empty($changes)) {
                $changes_message = implode(", ", $changes);
                logActivity($conn, $user_id, 'Faculty user edited an Event', $changes_message);
            }
            $success_message = "Event updated successfully!";
        } else {
            $error_message = "Error updating event: " . $conn->error;
        }
        $stmt->close();
    } elseif (isset($_POST['delete_event'])) {
        // Delete event logic
        $event_id = $_POST['event_id'];

        // Fetch event details for logging
        $delete_event_query = "SELECT event_title, event_description, department_id, year_level_id, event_date FROM class_calendar WHERE id=?";
        $delete_event_stmt = $conn->prepare($delete_event_query);
        $delete_event_stmt->bind_param("i", $event_id);
        $delete_event_stmt->execute();
        $delete_event_result = $delete_event_stmt->get_result();
        $delete_event = $delete_event_result->fetch_assoc();

        // Delete the event
        $stmt = $conn->prepare("DELETE FROM class_calendar WHERE id=?");
        $stmt->bind_param("i", $event_id);
        if ($stmt->execute()) {
            // Log activity
            logActivity($conn, $user_id, 'Faculty user deleted an Event', "Deleted event: '{$delete_event['event_title']}' with description: '{$delete_event['event_description']}', Department: '{$delete_event['department_id']}', Year Level: '{$delete_event['year_level_id']}', Event Date: '{$delete_event['event_date']}'");
            $success_message = "Event '{$delete_event['event_title']}' deleted successfully!";
        } else {
            $error_message = "Error deleting event: " . $conn->error;
        }
        $stmt->close();
    }
}

// Pagination settings
$records_per_page_options = ['All', 10, 25, 50, 100, 150, 200];
$records_per_page = isset($_GET['records_per_page']) ? $_GET['records_per_page'] : 10; // Default to 10
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Default to page 1

// Get selected department and year level
$selected_department = isset($_GET['department_id']) ? $_GET['department_id'] : '';
$selected_year_level = isset($_GET['year_level_id']) ? $_GET['year_level_id'] : '';

// Fetch events based on filters
$filter_query = "SELECT cc.*, d.department_name, yl.year_level 
                 FROM class_calendar cc
                 JOIN departments d ON cc.department_id = d.id
                 LEFT JOIN year_levels yl ON cc.year_level_id = yl.id
                 WHERE 1=1"; // Start with a base query

if ($selected_department) {
    $filter_query .= " AND d.id = " . intval($selected_department);
}
if ($selected_year_level) {
    $filter_query .= " AND yl.id = " . intval($selected_year_level);
}

// Add ordering by event date
$filter_query .= " ORDER BY cc.event_date";

// Get total records for pagination
$total_query = "SELECT COUNT(*) as total FROM ($filter_query) as filtered";
$total_result = $conn->query($total_query);
$total_row = $total_result->fetch_assoc();
$total_records = $total_row['total'];
$total_pages = ceil($total_records / ($records_per_page === 'All' ? $total_records : $records_per_page));

// Calculate offset
$offset = ($current_page - 1) * ($records_per_page === 'All' ? $total_records : $records_per_page);

// Fetch events with pagination
$query = $filter_query . " LIMIT $offset, " . ($records_per_page === 'All' ? $total_records : $records_per_page);
$events = $conn->query($query);

// Function to log activity
function logActivity($conn, $user_id, $action, $description) {
    $stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description) VALUES (?, ?, ?)");
    $stmt->bind_param("iss", $user_id, $action, $description);
    $stmt->execute();
    $stmt->close();
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Calendar of Events</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-top:10px;
            margin-left: 250px;
            padding: 70px 30px;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }

        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <!-- HTML Form for Adding Events -->
    <div class="container">
        <h2>Calendar of Events</h2>
        
        <!-- Filter Options -->
        <form method="get" class="mb-3">
            <div class="row">
                <div class="col-md-4">
                    <label for="year_level_id">Year Level:</label>
                    <select name="year_level_id" id="year_level_id" class="form-select" onchange="this.form.submit()">
                        <option value="">All Year Levels</option>
                        <?php foreach ($year_levels as $year): ?>
                            <option value="<?= $year['id'] ?>" <?= $year['id'] == $selected_year_level ? 'selected' : ''; ?>>
                                <?= $year['year_level'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4">
                    <label for="department_id">Department:</label>
                    <select name="department_id" id="department_id" class="form-select" onchange="this.form.submit()">
                        <option value="">All Departments</option>
                        <?php foreach ($departments as $dept): ?>
                            <option value="<?= $dept['id'] ?>" <?= $dept['id'] == $selected_department ? 'selected' : ''; ?>>
                                <?= $dept['department_name'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4">
                    <label for="records_per_page">Records per page:</label>
                    <select name="records_per_page" id="records_per_page" class="form-select" onchange="this.form.submit()">
                        <?php foreach ($records_per_page_options as $option): ?>
                            <option value="<?php echo $option; ?>" <?php echo $option == $records_per_page ? 'selected' : ''; ?>>
                                <?php echo $option; ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>
        </form>

        <!-- Button to trigger Add Event Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addEventModal">
            <i class="fas fa-plus"></i> Add Event
        </button>

        <!-- Messages -->
        <div class="messages">
            <?php if (isset($success_message)): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($success_message); ?>
                </div>
            <?php endif; ?>

            <?php if (isset($error_message)): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($error_message); ?>
                </div>
            <?php endif; ?>
        </div>
        
        <h3 class="mt-4">Existing Events</h3>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Department</th>
                    <th>Year Level</th>
                    <th>Event Title</th>
                    <th>Event Description</th>
                    <th>Event Date</th>
                    <th>Created At</th>
                    <th>Updated At</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($events->num_rows > 0): ?>
                    <?php $serialNo = 1; // Initialize serial number ?>
                    <?php while ($event = $events->fetch_assoc()): ?>
                        <tr>
                            <td><?= $serialNo++ ?></td>
                            <td><?= htmlspecialchars($event['department_name']) ?></td>
                            <td><?= htmlspecialchars($event['year_level']) ?></td>
                            <td><?= htmlspecialchars($event['event_title']) ?></td>
                            <td><?= htmlspecialchars($event['event_description']) ?></td>
                            <td><?= htmlspecialchars($event['event_date']) ?></td>
                            <td><?= htmlspecialchars($event['created_at']) ?></td>
                            <td><?= htmlspecialchars($event['updated_at']) ?></td>
                            <td>
                                <button class="btn btn-warning btn-sm" data-bs-toggle="modal" data-bs-target="#editEventModal" onclick="populateEditModal(<?= $event['id'] ?>)">
                                    <i class="fas fa-edit"></i> Edit
                                </button>
                                <form method="POST" action="" style="display:inline;">
                                    <input type="hidden" name="event_id" value="<?= $event['id'] ?>">
                                    <button type="submit" name="delete_event" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this event?');">
                                        <i class="fas fa-trash"></i> Delete
                                    </button>
                                </form>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="9">No events found.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- Pagination controls -->
        <nav aria-label="Page navigation">
            <ul class="pagination">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page - 1; ?>&records_per_page=<?php echo $records_per_page; ?>&department_id=<?php echo $selected_department; ?>&year_level_id=<?php echo $selected_year_level; ?>">Previous</a>
                    </li>
                <?php endif; ?>

                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?php echo $i; ?>&records_per_page=<?php echo $records_per_page; ?>&department_id=<?php echo $selected_department; ?>&year_level_id=<?php echo $selected_year_level; ?>"><?php echo $i; ?></a>
                    </li>
                <?php endfor; ?>

                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page + 1; ?>&records_per_page=<?php echo $records_per_page; ?>&department_id=<?php echo $selected_department; ?>&year_level_id=<?php echo $selected_year_level; ?>">Next</a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>
    </div>

    <!-- Add Event Modal -->
    <div class="modal fade" id="addEventModal" tabindex="-1" aria-labelledby="addEventModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addEventModalLabel">Add Event</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="POST" action="">
                    <div class="modal-body">
                            <div class="mb-3">
                                <label for="department_id" class="form-label">Department</label>
                                <select name="department_id" id="department_id" class="form-select" required>
                                    <option value="">Select Department</option>
                                    <?php foreach ($departments as $dept): ?>
                                        <option value="<?= $dept['id'] ?>"><?= htmlspecialchars($dept['department_name']) ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="mb-3">
                                <label for="year_level_id" class="form-label">Year Level</label>
                                <select name="year_level_id" id="year_level_id" class="form-select" required>
                                    <option value="">Select Year Level</option>
                                    <?php foreach ($year_levels as $year): ?>
                                        <option value="<?= $year['id'] ?>"><?= htmlspecialchars($year['year_level']) ?></option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="mb-3">
                                <label for="event_title" class="form-label">Event Title</label>
                                <input type="text" name="event_title" id="event_title" class="form-control" required>
                            </div>
                            <div class="mb-3">
                                <label for="event_description" class="form-label">Event Description</label>
                                <textarea name="event_description" id="event_description" class="form-control" required></textarea>
                            </div>
                            <div class="mb-3">
                                <label for="event_date" class="form-label">Event Date</label>
                                <input type="date" name="event_date" id="event_date" class="form-control" required>
                            </div>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                            <button type="submit" name="add_event" class="btn btn-primary">Add Event</button>
                        </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Event Modal -->
    <div class="modal fade" id="editEventModal" tabindex="-1" aria-labelledby="editEventModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editEventModalLabel">Edit Event</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="POST" action="">
                    <div class="modal-body">
                        <input type="hidden" name="event_id" id="edit_event_id">
                        <div class="mb-3">
                            <label for="edit_department_id" class="form-label">Department</label>
                            <select name="department_id" id="edit_department_id" class="form-select" required>
                                <option value="">Select Department</option>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= htmlspecialchars($dept['department_name']) ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_year_level_id" class="form-label">Year Level</label>
                            <select name="year_level_id" id="edit_year_level_id" class="form-select" required>
                                <option value="">Select Year Level</option>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= htmlspecialchars($year['year_level']) ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_event_title" class="form-label">Event Title</label>
                            <input type="text" name="event_title" id="edit_event_title" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_event_description" class="form-label">Event Description</label>
                            <textarea name="event_description" id="edit_event_description" class="form-control" required></textarea>
                        </div>
                        <div class="mb-3">
                            <label for="edit_event_date" class="form-label">Event Date</label>
                            <input type="date" name="event_date" id="edit_event_date" class="form-control" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss=" modal">Close</button>
                        <button type="submit" name="edit_event" class="btn btn-primary">Update Event</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script>
        function populateEditModal(eventId) {
            // Fetch event details using AJAX or pre-fill with PHP
            // This is a placeholder for the actual implementation
            // Example: document.getElementById('edit_event_id').value = eventId;
        }
    </script>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>