<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $attendance_id = $_POST['attendance_id']; // Get the ID of the attendance record to be deleted
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session

    // Check if the attendance ID is set
    if (empty($attendance_id)) {
        $_SESSION['error_message'] = "Error: Attendance ID cannot be empty.";
        header("Location: manage_attendance.php");
        exit();
    }

    // Fetch the attendance record before deleting
    $old_stmt = $conn->prepare("SELECT student_id, class_id, date FROM attendance WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_attendance.php");
        exit();
    }

    $old_stmt->bind_param("i", $attendance_id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_student_id, $old_class_id, $old_date);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the attendance record was found
    if (!$old_student_id) {
        $_SESSION['error_message'] = "Error: Attendance ID '$attendance_id' not found.";
        header("Location: manage_attendance.php");
        exit();
    }

    // Prepare and execute the delete statement for attendance
    $stmt = $conn->prepare("DELETE FROM attendance WHERE id = ?");
    if (!$stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_attendance.php");
        exit();
    }

    $stmt->bind_param("i", $attendance_id);

    if ($stmt->execute()) {
        // Log the activity
        $action = "Attendance deleted by Faculty";
        $description = "Deleted attendance record for student ID $old_student_id in class ID $old_class_id on date $old_date.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
        if ($log_stmt) {
            $log_stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
            $log_stmt->execute();
        }

        $_SESSION['success_message'] = "Attendance record deleted successfully.";
    } else {
        $_SESSION['error_message'] = "Error deleting attendance record: " . $stmt->error;
    }

    header("Location: manage_attendance.php");
    exit();
}
?>