<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $class_id = $_POST['class_id']; // Get the ID of the class to be deleted
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session

    // Check if the class ID is set
    if (empty($class_id)) {
        $_SESSION['error_message'] = "Error: Class ID cannot be empty.";
        header("Location: manage_classes.php");
        exit();
    }

    // Fetch the class name before deleting
    $old_stmt = $conn->prepare("SELECT class_name FROM classes WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_classes.php");
        exit();
    }

    $old_stmt->bind_param("i", $class_id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_class_name);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the class name was found
    if (!$old_class_name) {
        $_SESSION['error_message'] = "Error: Class ID '$class_id' not found.";
        header("Location: manage_classes.php");
        exit();
    }

    // Prepare and execute the delete statement for classes
    $stmt = $conn->prepare("DELETE FROM classes WHERE id = ?");
    if (!$stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_classes.php");
        exit();
    }

    $stmt->bind_param("i", $class_id);

    if ($stmt->execute()) {
        // Log the activity
        $action = "Faculty user deleted";
        $description = "Faculty user deleted class ID $class_id: '$old_class_name'.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];

        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
        if ($log_stmt) {
            $log_stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
            $log_stmt->execute();
        }

        $_SESSION['success_message'] = "Class deleted successfully: '$old_class_name'.";
    } else {
        $_SESSION['error_message'] = "Error deleting class: " . $stmt->error;
    }

    header("Location: manage_classes.php");
    exit();
}
?>