<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Get the question ID from the URL
$question_id = isset($_GET['question_id']) ? intval($_GET['question_id']) : 0;

// Handle deletion
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['delete_question'])) {
    // Delete options associated with the question
    $delete_options_stmt = $conn->prepare("DELETE FROM quiz_options WHERE question_id=?");
    $delete_options_stmt->bind_param("i", $question_id);
    $delete_options_stmt->execute();
    $delete_options_stmt->close();

    // Delete the question
    $delete_question_stmt = $conn->prepare("DELETE FROM quiz_questions WHERE id=?");
    $delete_question_stmt->bind_param("i", $question_id);
    if ($delete_question_stmt->execute()) {
        header("Location: questions_list.php?message=Question deleted successfully!");
        exit();
    } else {
        echo 'Error: ' . $delete_question_stmt->error;
    }
    $delete_question_stmt->close();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Delete Question</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container">
        <h1>Delete Question</h1>
        <p>Are you sure you want to delete this question?</p>
        <form method="POST" action="">
            <input type="hidden" name="delete_question" value="1">
            <button type="submit" class="btn btn-danger">Delete Question</button>
            <a href="quiz_details.php?" class="btn btn-secondary">Cancel</a>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>