<?php
session_start();
// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

include '../includes/dbcon.php'; // Include database connection

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Get the user ID from the POST request
    $id = $_POST['id'];

    // Fetch the user details before deletion
    $current_query = "
        SELECT u.first_name, u.last_name, u.username, u.email, u.mobile_number, 
               u.register_number, u.gender, d.department_name, yl.year_level, 
               u.approval_status 
        FROM users u
        LEFT JOIN departments d ON u.department_id = d.id
        LEFT JOIN year_levels yl ON u.year_level_id = yl.id
        WHERE u.id = ? AND u.role = 'student'";
    
    $current_stmt = $conn->prepare($current_query);
    $current_stmt->bind_param("i", $id);
    $current_stmt->execute();
    $current_result = $current_stmt->get_result();
    $current_user = $current_result->fetch_assoc();

    // Check if user exists
    if (!$current_user) {
        $_SESSION['error_message'] = "User not found.";
        header("Location: manage_students.php");
        exit();
    }

    // Prepare the SQL delete statement
    $stmt = $conn->prepare("DELETE FROM users WHERE id = ? AND role = 'student'");
    $stmt->bind_param("i", $id);

    // Execute the statement
    if ($stmt->execute()) {
        // Log activity with user details
        $action = "Faculty user deleted student user with ID: $id";
        $description = "Student user details: First Name: {$current_user['first_name']}, Last Name: {$current_user['last_name']}, Username: {$current_user['username']}, Email: {$current_user['email']}, Mobile Number: {$current_user['mobile_number']}, Register Number: {$current_user['register_number']}, Gender: {$current_user['gender']}, Department name: {$current_user['department_name']}, Year Level: {$current_user['year_level']}, Approval Status: {$current_user['approval_status']}.";
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $user_agent = $_SERVER['HTTP_USER_AGENT'];
        $_SESSION['success_message'] = "Student user deleted successfully." . $description;

        // Insert log entry
        $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent, created_at) VALUES (?, ?, ?, ?, ?, NOW())");
        $log_stmt->bind_param("issss", $_SESSION['user_id'], $action, $description, $ip_address, $user_agent);
        $log_stmt->execute();
        $log_stmt->close();
    } else {
        $_SESSION['error_message'] = "Error deleting student user: " . $stmt->error;
    }

    // Close the statement and connection
    $stmt->close();
    $current_stmt->close();
    $conn->close();

    // Redirect back to the manage students page
    header("Location: manage_students.php");
    exit();
}
?>