<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $attendance_id = $_POST['id']; // Get the ID of the attendance record to be edited
    $student_id = $_POST['student_id'];
    $class_id = $_POST['class_id'];
    $date = $_POST['date'];
    $status = $_POST['status'];
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session

    // Check if the attendance ID is set
    if (empty($attendance_id)) {
        $_SESSION['error_message'] = "Error: Attendance ID cannot be empty.";
        header("Location: manage_attendance.php");
        exit();
    }

    // Fetch the old attendance details before updating
    $old_stmt = $conn->prepare("SELECT student_id, class_id, date, status FROM attendance WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_attendance.php");
        exit();
    }

    $old_stmt->bind_param("i", $attendance_id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_student_id, $old_class_id, $old_date, $old_status);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the old attendance details were found
    if (!$old_student_id) {
        $_SESSION['error_message'] = "Error: Attendance ID '$attendance_id' not found.";
        header("Location: manage_attendance.php");
        exit();
    }

    // Check for duplicate attendance entry for the same student, class, and date (excluding the current record)
    $check_stmt = $conn->prepare("SELECT COUNT(*) FROM attendance WHERE student_id = ? AND class_id = ? AND date = ? AND id != ?");
    $check_stmt->bind_param("iisi", $student_id, $class_id, $date, $attendance_id);
    $check_stmt->execute();
    $check_stmt->bind_result($count);
    $check_stmt->fetch();
    $check_stmt->close();

    if ($count > 0) {
        // Attendance record already exists
        $_SESSION['error_message'] = "Error: Attendance record already exists for this student on this date.";
    } else {
        // Prepare and execute the update statement for attendance
        $stmt = $conn->prepare("UPDATE attendance SET student_id = ?, class_id = ?, date = ?, status = ? WHERE id = ?");
        if (!$stmt) {
            $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
            header("Location: manage_attendance.php");
            exit();
        }

        $stmt->bind_param("iissi", $student_id, $class_id, $date, $status, $attendance_id);

        if ($stmt->execute()) {
            // Log the activity
            $action = "Attendance updated";
            $description = "Updated attendance record for student ID $student_id in class ID $class_id on date $date from status '$old_status' to '$status'.";
            $ip_address = $_SERVER['REMOTE_ADDR'];
            $user_agent = $_SERVER['HTTP_USER_AGENT'];

            $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
            if ($log_stmt) {
                $log_stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
                $log_stmt->execute();
            }

            $_SESSION['success_message'] = "Attendance record updated successfully.";
        } else {
            $_SESSION['error_message'] = "Error updating attendance record: " . $stmt->error;
        }
    }

    header("Location: manage_attendance.php");
    exit();
}
?>