<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Get the question ID from the URL
$question_id = isset($_GET['question_id']) ? intval($_GET['question_id']) : 0;

// Initialize message variables
$message = '';
$message_type = '';

// Function to fetch question details
function fetchQuestion($conn, $question_id) {
    $stmt = $conn->prepare("SELECT * FROM quiz_questions WHERE id=?");
    $stmt->bind_param("i", $question_id);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc();
}

// Function to update the question
function updateQuestion($conn, $question_id, $question_text, $question_type, $explanation, $image_path) {
    $stmt = $conn->prepare("UPDATE quiz_questions SET question_text=?, question_type=?, explanation=?, image_path=? WHERE id=?");
    $stmt->bind_param("ssssi", $question_text, $question_type, $explanation, $image_path, $question_id);
    return $stmt->execute();
}

// Fetch the question details
$question = fetchQuestion($conn, $question_id);

// Handle updating the question
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_question'])) {
    // Update question logic
    $question_text = $_POST['question_text'];
    $question_type = $_POST['question_type'];
    $explanation = $_POST['explanation'];
    $image_path = $question['image_path']; // Keep the existing image path

    // Handle image upload
    if (isset($_FILES['image']) && $_FILES['image']['error'] == UPLOAD_ERR_OK) {
        $target_dir = "uploads/"; // Ensure this directory exists and is writable
        $target_file = $target_dir . basename($_FILES["image"]["name"]);
        $imageFileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

        // Check if the file is an actual image
        $check = getimagesize($_FILES["image"]["tmp_name"]);
        if ($check !== false) {
            // Move the uploaded file to the target directory
            if (move_uploaded_file($_FILES["image"]["tmp_name"], $target_file)) {
                $image_path = $target_file; // Update the path for database insertion
            } else {
                $message = "Sorry, there was an error uploading your file.";
                $message_type = 'danger';
            }
        } else {
            $message = "File is not an image.";
            $message_type = 'danger';
        }
    }

    // Update the question
    if (updateQuestion($conn, $question_id, $question_text, $question_type, $explanation, $image_path)) {
        $message = 'Question updated successfully!';
        $message_type = 'success';
    } else {
        $message = 'Error updating question: ' . $stmt->error;
        $message_type = 'danger';
    }
}

// Fetch options for the question
$options_stmt = $conn->prepare("SELECT * FROM quiz_options WHERE question_id=?");
$options_stmt->bind_param("i", $question_id);
$options_stmt->execute();
$options_result = $options_stmt->get_result();
$options = [];
while ($option = $options_result->fetch_assoc()) {
    $options[] = $option;
}
$options_stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Edit Question</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container">
        <h1>Edit Question</h1>

        <!-- Display success or error message -->
        <?php if ($message): ?>
            <div class="alert alert-<?php echo $message_type; ?>" role="alert">
                <?php echo htmlspecialchars($message); ?>
            </div>
        <?php endif; ?>

        <form method="POST" action="" enctype="multipart/form-data">
            <div class="mb-3">
                <label for="question_text" class="form-label">Question Text</label>
                <input type="text" class="form-control" id="question_text" name="question_text" value="<?php echo htmlspecialchars($question['question_text']); ?>" required>
            </div>
            <div class="mb-3">
                <label for="question_type" class="form-label">Question Type</label>
                <select class="form-select" id="question_type" name="question_type" required>
                    <option value="multiple-choice" <?php echo $question['question_type'] === 'multiple-choice' ? 'selected' : ''; ?>>Multiple Choice</option>
                    <option value="checkbox" <?php echo $question['question_type'] === 'checkbox' ? 'selected' : ''; ?>>Checkbox</option>
                    <option value="true-false" <?php echo $question['question_type'] === 'true-false' ? 'selected' : ''; ?>>True/False</option>
                </select>
            </div>
            <div class="mb-3">
                <label for="explanation" class="form-label">Explanation</label>
                <textarea class="form-control" id="explanation" name="explanation"><?php echo htmlspecialchars($question['explanation']); ?></textarea>
            </div>
            <div class="mb-3">
                <label for="image" class="form-label">Upload New Image (optional)</label>
                <input type="file" class="form-control" id="image" name="image" accept="image/*">
                <small>Current Image: <?php echo $question['image_path'] ? htmlspecialchars($question['image_path']) : 'No image uploaded'; ?></small>
            </div>
            <input type="hidden" name="update_question" value="1">
            <button type="submit" class="btn btn-primary">Update Question</button>
        </form>

        <h2>Options</h2>
        <form id="optionsForm">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>Option Text</th>
                        <th>Is Correct?</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($options)): ?>
                        <tr>
                            <td colspan="3" class="text-center">No options added yet.</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($options as $option): ?>
                            <tr>
                                <td>
                                    <input type="text" class="form-control" name="options[]" value="<?php echo htmlspecialchars($option['option_text']); ?>" required>
                                    <input type="hidden" name="option_ids[]" value="<?php echo $option['option_id']; ?>">
                                </td>
                                <td>
                                    <?php if ($question['question_type'] === 'checkbox'): ?>
                                        <input type="checkbox" name="is_correct[<?php echo $option['option_id']; ?>]" value="1" <?php echo $option['is_correct'] ? 'checked' : ''; ?>> Correct
                                    <?php else: ?>
                                        <input type="radio" name="is_correct" value="<?php echo $option['option_id']; ?>" <?php echo $option['is_correct'] ? 'checked' : ''; ?>> Correct
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <button type="button" class="btn btn-danger btn-sm" onclick="deleteOption(<?php echo $option['option_id']; ?>)">Delete</button>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
            <button type="button" class="btn btn-success" id="addOptionButton">Add Option</button>
            <button type="button" class="btn btn-primary" id="saveOptionsButton">Save Options</button>
        </form>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        document.getElementById('addOptionButton').addEventListener('click', function() {
            const tableBody = document.querySelector('table tbody');
            const newRow = document.createElement('tr');
            newRow.innerHTML = `
                <td>
                    <input type="text" class="form-control" name="options[]" required>
                    <input type="hidden" name="option_ids[]" value="">
                </td>
                <td>
                    <input type="checkbox" name="is_correct[]" value="0"> Correct
                </td>
                <td>
                    <button type="button" class="btn btn-danger btn-sm" onclick="deleteOption(0)">Delete</button>
                </td>
            `;
            tableBody.appendChild(newRow);
        });

        document.getElementById('saveOptionsButton').addEventListener('click', function() {
            const formData = new FormData(document.getElementById('optionsForm'));
            formData.append('update_options', '1'); // Add update flag
            formData.append('question_id', <?php echo $question_id; ?>); // Add question ID

            fetch('update_options.php', {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok: ' + response.statusText);
                }
                return response.json();
            })
            .then(data => {
                if (data.success) {
                    alert('Options updated successfully!');
                    location.reload(); // Reload the page to see the changes
                } else {
                    alert('Error: ' + data.message);
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred while updating options: ' + error.message);
            });
        });

        function deleteOption(optionId) {
            if (confirm('Are you sure you want to delete this option?')) {
                const xhr = new XMLHttpRequest();
                xhr.open('POST', 'delete_option.php', true);
                xhr.setRequestHeader('Content-Type', 'application/x-www-form-urlencoded');
                xhr.onload = function() {
                    if (xhr.status === 200) {
                        location.reload(); // Reload the page to see the changes
                    } else {
                        alert('Error deleting option.');
                    }
                };
                xhr.send('option_id=' + optionId);
            }
        }
    </script>
</body>
</html>