<?php
session_start();
include '../includes/dbcon.php';

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $id = $_POST['id']; // Get the ID of the year level to be edited
    $year_level = trim($_POST['year_level']); // Trim whitespace
    $user_id = $_SESSION['user_id']; // Assuming user ID is stored in session
    $class_name = "Year Level: " . $year_level; // Class name to be displayed in the success message

    // Check if the ID and new year level are set
    if (empty($id) || empty($year_level)) {
        $_SESSION['error_message'] = "Error: Year level ID and Year level cannot be empty.";
        header("Location: manage_year_levels.php");
        exit();
    }

    // Fetch the old year level before updating
    $old_stmt = $conn->prepare("SELECT year_level FROM year_levels WHERE id = ?");
    if (!$old_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_year_levels.php");
        exit();
    }

    $old_stmt->bind_param("i", $id);
    $old_stmt->execute();
    $old_stmt->bind_result($old_year_level);
    $old_stmt->fetch();
    $old_stmt->close();

    // Check if the old year level was found
    if (!$old_year_level) {
        $_SESSION['error_message'] = "Error: Year level ID '$id' not found.";
        header("Location: manage_year_levels.php");
        exit();
    }

    // Check if the new year level already exists (excluding the current one)
    $check_stmt = $conn->prepare("SELECT COUNT(*) FROM year_levels WHERE year_level = ? AND id != ?");
    if (!$check_stmt) {
        $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
        header("Location: manage_year_levels.php");
        exit();
    }

    $check_stmt->bind_param("si", $year_level, $id);
    $check_stmt->execute();
    $check_stmt->bind_result($count);
    $check_stmt->fetch();
    $check_stmt->close();

    if ($count > 0) {
        // Year level already exists
        $_SESSION['error_message'] = "Error: Year level '$year_level' already exists.";
    } else {
        // Prepare and execute the update statement for year levels
        $stmt = $conn->prepare("UPDATE year_levels SET year_level = ?, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
        if (!$stmt) {
            $_SESSION['error_message'] = "Error preparing statement: " . $conn->error;
            header("Location: manage_year_levels.php");
            exit();
        }

        $stmt->bind_param("si", $year_level, $id);

        if ($stmt->execute()) {
            // Log the activity
            $action = "Year Level Edited by Faculty User";
            $description = "Faculty User edited year level ID $id from '$old_year_level' to '$year_level'.";
            $ip_address = $_SERVER['REMOTE_ADDR'];
            $user_agent = $_SERVER['HTTP_USER_AGENT'];

            $log_stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
            if ($log_stmt) {
                $log_stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
                $log_stmt->execute();
            }

            $_SESSION['success_message'] = "Year level updated successfully from '$old_year_level' to '$year_level'.";
        } else {
            $_SESSION['error_message'] = "Error updating year level: " . $stmt->error;
        }
    }

    header("Location: manage_year_levels.php");
    exit();
}
?>