<?php
include '../includes/dbcon.php'; // Include database connection

// Prepare the SQL statement
$department_id = isset($_GET['department_id']) ? intval($_GET['department_id']) : 0;
$year_level_id = isset($_GET['year_level_id']) ? intval($_GET['year_level_id']) : 0;

$query = "
    SELECT c.id, c.class_name, yl.year_level, d.department_name, c.description 
    FROM classes c 
    LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
    LEFT JOIN departments d ON c.department_id = d.id 
    WHERE 1=1"; // Start with a base query

$params = [];
if ($department_id > 0) {
    $query .= " AND c.department_id = ?";
    $params[] = $department_id; // Add department_id to parameters
}
if ($year_level_id > 0) {
    $query .= " AND c.year_level_id = ?";
    $params[] = $year_level_id; // Add year_level_id to parameters
}

// Prepare and execute the statement
$stmt = $conn->prepare($query);
if ($params) {
    $stmt->bind_param(str_repeat('i', count($params)), ...$params); // Bind parameters
}
$stmt->execute();
$result = $stmt->get_result();

$classes = [];
if ($result->num_rows > 0) {
    while ($row = $result->fetch_assoc()) {
        $classes[] = $row; // Collect class data
    }
}

// Set the content type to JSON
header('Content-Type: application/json');
echo json_encode($classes); // Return as JSON

// Close the statement and connection
$stmt->close();
$conn->close();
?>