<?php
session_start();
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'faculty') {
    echo "User  is not logged in or not a faculty.";
    header("Location: ../login.php");
    exit();
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

include '../includes/dbcon.php'; // Include database connection

// Fetch classes for dropdown
$classes = [];
$class_query = "SELECT c.id, CONCAT(c.class_name, ' (', d.department_name, ' - ', yl.year_level, ')') AS class_name FROM classes c
                JOIN departments d ON c.department_id = d.id JOIN year_levels yl ON c.year_level_id = yl.id ORDER BY c.class_name";
$class_result = $conn->query($class_query);
if ($class_result && $class_result->num_rows > 0) {
    while ($row = $class_result->fetch_assoc()) {
        $classes[] = $row;
    }
}

// Initialize attendance records
$attendance_records = [];

// Check if a specific student and class are selected to view their attendance
$selected_student_id = isset($_POST['student_id']) ? $_POST['student_id'] : null;
$selected_date = isset($_POST['attendance_date']) ? $_POST['attendance_date'] : null;
$selected_class_id = isset($_POST['class_id']) ? $_POST['class_id'] : null;

if ($selected_student_id && $selected_class_id) {
    // Prepare the attendance query based on selected student and class
    $attendance_query = "SELECT a.id, a.date, a.status, a.student_id, u.first_name, u.last_name, c.class_name 
                         FROM attendance a
                         JOIN users u ON a.student_id = u.id
                         JOIN classes c ON a.class_id = c.id
                         WHERE a.student_id = ? AND a.class_id = ?";
    
    // Add date filter if a date is selected
    if ($selected_date) {
        $attendance_query .= " AND a.date = ?";
    }
    
    $attendance_query .= " ORDER BY a.date DESC";
    
    $stmt = $conn->prepare($attendance_query);
    
    if ($selected_date) {
        $stmt->bind_param("iis", $selected_student_id, $selected_class_id, $selected_date);
    } else {
        $stmt->bind_param("ii", $selected_student_id, $selected_class_id);
    }
    
    $stmt->execute();
    $attendance_result = $stmt->get_result();
    $attendance_records = $attendance_result->fetch_all(MYSQLI_ASSOC);
    $stmt->close();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Attendance</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Attendance</h2>

        <!-- Attendance Selection Form -->
        <form method="POST" class="mb-3">
            <div class="row">
                <div class="col-md-4 mb-3">
                    <label for="class_id" class="form-label">Select Class</label>
                    <select class="form-select" id="class_id" name="class_id" required onchange="fetchStudents(this.value)">
                        <option value="">Select Class</option>
                        <?php foreach ($classes as $class): ?>
                            <option value="<?= $class['id']; ?>" <?= ($selected_class_id == $class['id']) ? 'selected' : ''; ?>>
                                <?= htmlspecialchars($class['class_name']); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4 mb-3">
                    <label for="student_id" class="form-label">Select Student</label>
                    <select class="form-select" id="student_id" name="student_id" required>
                        <option value="">Select Student</option>
                        <?php if ($selected_class_id): ?>
                            <!-- Populate students based on selected class -->
                            <script>
                                document.addEventListener('DOMContentLoaded', function() {
                                    fetchStudents(<?= json_encode($selected_class_id); ?>);
                                });
                            </script>
                        <?php endif; ?>
                    </select>
                </div>
                <div class="col-md-4 mb-3">
                    <label for="attendance_date" class="form-label">Select Date</label>
                    <input type="date" class="form-control" id="attendance_date" name="attendance_date" value="<?= htmlspecialchars($selected_date); ?>">
                </div>
            </div>
            <button type="submit" class="btn btn-primary">
                <i class="fas fa-eye"></i> View Attendance
            </button>
            <button type="button" class="btn btn-success" data-bs-toggle="modal" data-bs-target="#addAttendanceModal">
                <i class="fas fa-check"></i> Mark Attendance
            </button>
        </form>

        <!-- Messages -->
        <div class="messages">
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($_SESSION['success_message']); ?>
                </div>
                <?php unset($_SESSION['success_message']); ?>
            <?php endif; ?>

            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($_SESSION['error_message']); ?>
                </div>
                <?php unset($_SESSION['error_message']); ?>
            <?php endif; ?>
        </div>

        <!-- Attendance Records Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th>
                    <th>Student Name</th>
                    <th>Class Name</th>
                    <th>Date</th>
                    <th>Status</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($attendance_records) > 0): ?>
                    <?php foreach ($attendance_records as $index => $record): ?>
                        <tr>
                            <td><?= $index + 1; ?></td>
                            <td><?= htmlspecialchars($record['first_name'] . ' ' . $record['last_name']); ?></td>
                            <td><?= htmlspecialchars($record['class_name']); ?></td>
                            <td><?= htmlspecialchars($record['date']); ?></td>
                            <td><?= htmlspecialchars($record['status']); ?></td>
                            <td>
                                <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editAttendanceModal' onclick='populateEditModal(<?= $record['id']; ?>)'><i class='fas fa-edit'></i> Edit</button>
                                <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteAttendanceModal' onclick='setDeleteModal(<?= $record['id']; ?>)'><i class='fas fa-trash'></i> Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr><td colspan='5'>No attendance records found for this student in the selected class on the selected date.</td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Add Attendance Modal -->
    <div class="modal fade" id="addAttendanceModal" tabindex="-1" aria-labelledby="addAttendanceModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addAttendanceModalLabel">Mark Attendance</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_attendance.php" method="POST">
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="class_id" class="form-label">Class</label>
                            <select class="form-select" id="class_id_modal" name="class_id" required onchange="fetchStudentsForModal(this.value)">
                                <option value="">Select Class</option>
                                <?php foreach ($classes as $class): ?>
                                    <option value="<?= $class['id']; ?>"><?= htmlspecialchars($class['class_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="studentCheckboxes" class="form-label">Students</label>
                            <div class="form-check">
                                <input class="form-check-input" type="checkbox" id="selectAll" onclick="toggleSelectAll(this)">
                                <label class="form-check-label" for="selectAll">Select All</label>
                            </div>
                            <div id="studentCheckboxes">
                                <!-- Checkboxes will be populated here based on selected class -->
                            </div>
                        </div>
                        <div class="mb-3">
                            <label for="attendance_date" class="form-label">Date</label>
                            <input type="date" class="form-control" id="attendance_date" name="date" required>
                        </div>
                        <div class="mb-3">
                            <label for="status" class="form-label">Status</label>
                            <select class="form-select" id="status" name="status" required>
                                <option value="present">Present</option>
                                <option value="absent">Absent</option>
                                <option value="on-duty">On-Duty</option>
                                <option value="holiday">Holiday</option>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Mark Attendance</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Attendance Modal -->
    <div class="modal fade" id="editAttendanceModal" tabindex="-1" aria-labelledby="editAttendanceModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editAttendanceModalLabel">Edit Attendance</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_attendance.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="attendanceId" name="id">
                        <div class="mb-3">
                            <label for="edit_student_id" class="form-label">Student ID</label>
                            <input type="text" class="form-control" id="edit_student_id" name="student_id" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_attendance_date" class="form-label">Date</label>
                            <input type="date" class="form-control" id="edit_attendance_date" name="date" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_status" class="form-label">Status</label>
                            <select class="form-select" id="edit_status" name="status" required>
                                <option value="present">Present</option>
                                <option value="absent">Absent</option>
                                <option value="on-duty">On-Duty</option>
                                <option value="holiday">Holiday</option>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-warning">Update Attendance</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Attendance Modal -->
    <div class="modal fade" id="deleteAttendanceModal" tabindex="-1" aria-labelledby="deleteAttendanceModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteAttendanceModalLabel">Delete Attendance</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_attendance.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="deleteAttendanceId" name="attendance_id">
                        <p>Are you sure you want to delete this attendance record?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        function fetchStudentsForModal(classId) {
            fetch(`get_students.php?class_id=${classId}`)
                .then(response => response.json())
                .then(data => {
                    const studentCheckboxes = document.getElementById('studentCheckboxes');
                    studentCheckboxes.innerHTML = ''; // Clear previous checkboxes
                    if (data && data.length > 0) {
                        data.forEach(student => {
                            const checkbox = `
                                <div class="form-check">
                                    <input class="form-check-input" type="checkbox" name="students[]" value="${student.id}" id="student_${student.id}">
                                    <label class="form-check-label" for="student_${student.id}">
                                        ${student.first_name} ${student.last_name}
                                    </label>
                                </div>`;
                            studentCheckboxes.innerHTML += checkbox;
                        });
                    } else {
                        studentCheckboxes.innerHTML = '<p>No students found for this class.</p>';
                    }
                })
                .catch(error => console.error('Error fetching students:', error));
        }
        function toggleSelectAll(selectAllCheckbox) {
            const checkboxes = document.querySelectorAll('#studentCheckboxes .form-check-input');
            checkboxes.forEach(checkbox => {
                checkbox.checked = selectAllCheckbox.checked; // Set each checkbox to the state of the "Select All" checkbox
            });
        }
        function populateEditModal(attendanceId) {
            fetch(`get_attendance.php?id=${attendanceId}`)
                .then(response => response.json())
                .then(data => {
                    if (data && data.success) {
                        document.getElementById('attendanceId').value = data.id || '';
                        document.getElementById('edit_student_id').value = data.student_id || '';
                        document.getElementById('edit_attendance_date').value = data.date || '';
                        document.getElementById('edit_status').value = data.status || '';
                    } else {
                        console.error('Error fetching attendance:', data.message);
                    }
                })
                .catch(error => console.error('Fetch failed:', error));
        }

        function setDeleteModal(attendanceId) {
            document.getElementById('deleteAttendanceId').value = attendanceId;
        }
    </script>
</body>
</html>