<?php
session_start();
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'faculty') {
    echo "User  is not logged in or not a faculty.";
    header("Location: ../login.php");
    exit();
}

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

include '../includes/dbcon.php'; // Include database connection

// Fetch classes
$classes = [];
$class_query = "SELECT c.id, c.class_name, c.year_level_id, c.department_id, c.description, c.created_at, c.updated_at, d.department_name, yl.year_level 
                FROM classes c
                LEFT JOIN departments d ON c.department_id = d.id
                LEFT JOIN year_levels yl ON c.year_level_id = yl.id
                ORDER BY c.class_name";
$class_result = $conn->query($class_query);
if ($class_result && $class_result->num_rows > 0) {
    while ($row = $class_result->fetch_assoc()) {
        $classes[] = $row;
    }
}

// Fetch departments for dropdown
$departments = [];
$department_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$department_result = $conn->query($department_query);
if ($department_result && $department_result->num_rows > 0) {
    while ($row = $department_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels for dropdown
$year_levels = [];
$year_level_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_level_result = $conn->query($year_level_query);
if ($year_level_result && $year_level_result->num_rows > 0) {
    while ($row = $year_level_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Classes</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Classes</h2>

        <!-- Button to trigger Add Class Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addClassModal">
            <i class="fas fa-school"></i> Add Class
        </button>

        <!-- Messages -->
        <div class="messages">
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($_SESSION['success_message']); ?>
                </div>
                <?php unset($_SESSION['success_message']); ?>
            <?php endif; ?>

            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($_SESSION['error_message']); ?>
                </div>
                <?php unset($_SESSION['error_message']); ?>
            <?php endif; ?>
        </div>

        <!-- Classes Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th> <!-- Serial Number Column -->
                    <!-- <th>ID</th> -->
                    <th>Class Name</th>
                    <th>Year Level</th>
                    <th>Department</th>
                    <th>Description</th>
                    <th>Created at</th>
                    <th>Updated at</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($classes) > 0): ?>
                    <?php foreach ($classes as $index => $class): ?>
                        <tr>
                            <td><?= $index + 1; ?></td> <!-- Serial Number -->
                            <!-- <td><?= htmlspecialchars($class['id']); ?></td> -->
                            <td><?= htmlspecialchars($class['class_name']); ?></td>
                            <td><?= htmlspecialchars($class['year_level']); ?></td>
                            <td><?= htmlspecialchars($class['department_name']); ?></td>
                            <td><?= htmlspecialchars($class['description']); ?></td>
                            <td><?= htmlspecialchars($class['created_at']); ?> UTC</td>
                            <td><?= htmlspecialchars($class['updated_at']); ?> UTC</td>
                            <td>
                                <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editClassModal' onclick='populateEditModal(<?= $class['id']; ?>)'><i class='fas fa-edit'></i> Edit</button>
                                <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteClassModal' onclick='setDeleteModal(<?= $class['id']; ?>)'><i class='fas fa-trash'></i> Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr><td colspan='9'>No records found</td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Add Class Modal -->
    <div class="modal fade" id="addClassModal" tabindex="-1" aria-labelledby="addClassModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addClassModalLabel">Add Class</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_class.php" method="POST">
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="class_name" class="form-label">Class Name</label>
                            <input type="text" class="form-control" id="class_name" name="class_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="year_level_id" name="year_level_id" required>
                                <option value="">Select Year Level</option>
                                <?php foreach ($year_levels as $year_level): ?>
                                    <option value="<?= $year_level['id']; ?>"><?= htmlspecialchars($year_level['year_level']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="department_id" class="form-label">Department</label>
                            <select class="form-select" id="department_id" name="department_id" required>
                                <option value="">Select Department</option>
                                <?php foreach ($departments as $department): ?>
                                    <option value="<?= $department['id']; ?>"><?= htmlspecialchars($department['department_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="description" class="form-label">Description</label>
                            <textarea class="form-control" id="description" name="description"></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add Class</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Class Modal -->
    <div class="modal fade" id="editClassModal" tabindex="-1" aria-labelledby="editClassModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editClassModalLabel">Edit Class</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_class.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="classId" name="id"> <!-- Changed name to 'id' -->
                        <div class="mb-3">
                            <label for="edit_class_name" class="form-label">Class Name</label>
                            <input type="text" class="form-control" id="edit_class_name" name="class_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="edit_year_level_id" name="year_level_id" required>
                                <option value="">Select Year Level</option>
                                <?php foreach ($year_levels as $year_level): ?>
                                    <option value="<?= $year_level['id']; ?>"><?= htmlspecialchars($year_level['year_level']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_department_id" class="form-label">Department</label>
                            <select class="form-select" id="edit_department_id" name="department_id" required>
                                <option value="">Select Department</option>
                                <?php foreach ($departments as $department): ?>
                                    <option value="<?= $department['id']; ?>"><?= htmlspecialchars($department['department_name']); ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_description" class="form-label">Description</label>
                            <textarea class="form-control" id="edit_description" name="description"></textarea>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Class</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Class Modal -->
    <div class="modal fade" id="deleteClassModal" tabindex="-1" aria-labelledby="deleteClassModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteClassModalLabel">Delete Class</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_class.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="class_id" id="deleteClassId">
                        <p>Are you sure you want to delete this class?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete Class</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // JavaScript function to populate edit modal
        function populateEditModal(classId) {
            fetch(`get_class.php?id=${classId}`)
                .then(response => {
                    if (!response.ok) {
                        throw new Error(`HTTP error! Status: ${response.status}`);
                    }
                    return response.json();
                })
                .then(data => {
                    if (data && data.success) {
                        document.getElementById('classId').value = data.id || ''; // Set the ID
                        document.getElementById('edit_class_name').value = data.class_name || ''; // Set the class name
                        document.getElementById('edit_year_level_id').value = data.year_level_id || ''; // Set the year level
                        document.getElementById('edit_department_id').value = data.department_id || ''; // Set the department
                        document.getElementById('edit_description').value = data.description || ''; // Set the description
                    } else {
                        console.error('Error fetching class:', data.message);
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to set delete modal ID
        function setDeleteModal(classId) {
            document.getElementById('deleteClassId').value = classId;
        }
    </script>
</body>
</html>