<?php
// Start output buffering at the beginning of the script
ob_start();
session_start();
// Check if the user is logged in and has the role of 'admin'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch departments and year levels
$departments = [];
$year_levels = [];

// Fetch departments
$dept_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$dept_result = $conn->query($dept_query);
if ($dept_result->num_rows > 0) {
    while ($row = $dept_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels
$year_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}

// Pagination settings
$records_per_page_options = ['All', 10, 25, 50, 100, 150, 200, 250, 500, 1000];
$records_per_page = isset($_GET['records_per_page']) ? $_GET['records_per_page'] : 10; // Default to 10
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Default to page 1

// Get selected department and year level
$selected_department = isset($_GET['department_id']) ? $_GET['department_id'] : '';
$selected_year_level = isset($_GET['year_level_id']) ? $_GET['year_level_id'] : '';

// Build the query based on selected filters
$filter_query = "
    SELECT u.*, d.department_name, yl.year_level 
    FROM users u
    LEFT JOIN departments d ON u.department_id = d.id
    LEFT JOIN year_levels yl ON u.year_level_id = yl.id
    WHERE u.role = 'student'";

if ($selected_department) {
    $filter_query .= " AND u.department_id = " . intval($selected_department);
}
if ($selected_year_level) {
    $filter_query .= " AND u.year_level_id = " . intval($selected_year_level);
}

// Add ordering by full name
$filter_query .= " ORDER BY CONCAT(u.first_name, ' ', u.last_name)";

// Get total records for pagination
$total_query = "SELECT COUNT(*) as total FROM ($filter_query) as filtered";
$total_result = $conn->query($total_query);
$total_row = $total_result->fetch_assoc();
$total_records = $total_row['total'];
$total_pages = ceil($total_records / ($records_per_page === 'All' ? $total_records : $records_per_page));

// Calculate offset
$offset = ($current_page - 1) * ($records_per_page === 'All' ? $total_records : $records_per_page);

// Fetch student users with pagination
$query = $filter_query . ($records_per_page === 'All' ? "" : " LIMIT $offset, $records_per_page");
$results = $conn->query($query);

// Include PhpSpreadsheet classes
require '../vendor/autoload.php'; // Autoload all Composer dependencies

// Use statements for PhpSpreadsheet classes
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;

// Handle export to Excel and PDF
if (isset($_POST['export_excel']) || isset($_POST['export_pdf'])) {
    // Use the same query as the results query for export
    $export_query = $filter_query; // Reuse the filter query

    // Handle field selection for export
    $fields = [];
    if (isset($_POST['include_serial_no'])) $fields[] = 'S. No.';
    // if ( (isset($_POST['include_id'])) $fields[] = 'ID';
    if (isset($_POST['include_full_name'])) $fields[] = 'Full Name';
    if (isset($_POST['include_username'])) $fields[] = 'Username';
    if (isset($_POST['include_email'])) $fields[] = 'Email';
    if (isset($_POST['include_mobile_number'])) $fields[] = 'Mobile Number';
    if (isset($_POST['include_register_number'])) $fields[] = 'Register Number';
    if (isset($_POST['include_gender'])) $fields[] = 'Gender';
    if (isset($_POST['include_department'])) $fields[] = 'Department';
    if (isset($_POST['include_year_level'])) $fields[] = 'Year Level';
    if (isset($_POST['include_classes'])) $fields[] = 'Classes'; // Include classes in export
    if (isset($_POST['include_status'])) $fields[] = 'Status';

    // Include PhpSpreadsheet for Excel export
    if (isset($_POST['export_excel'])) {
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();
        $rowNumber = 1;

        // Set headers
        $columnIndex = 'A';
        if (isset($_POST['include_serial_no'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'S. No.');
        if (isset($_POST['include_full_name'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Full Name');
        if (isset($_POST['include_username'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Username');
        if (isset($_POST['include_email'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Email');
        if (isset($_POST['include_mobile_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Mobile Number');
        if (isset($_POST['include_register_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Register Number');
        if (isset($_POST['include_gender'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Gender');
        if (isset($_POST['include_department'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Department');
        if (isset($_POST['include_year_level'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Year Level');
        if (isset($_POST['include_classes'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Classes'); // Add classes header
        if (isset($_POST['include_status'])) $sheet->setCellValue($columnIndex++ . $rowNumber, 'Status');

        // Populate data for export
        $rowNumber++;
        $serialNo = 1; // Initialize serial number

        // Fetch the data for export using the same query
        $export_results = $conn->query($export_query); // Execute the export query
        while ($user = $export_results->fetch_assoc()) {
            $columnIndex = 'A';
            if (isset($_POST['include_serial_no'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $serialNo++);
            if (isset($_POST['include_full_name'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['first_name'] . ' ' . $user['last_name']);
            if (isset($_POST['include_username'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['username']);
            if (isset($_POST['include_email'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['email']);
            if (isset($_POST['include_mobile_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['mobile_number']);
            if (isset($_POST['include_register_number'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['register_number']);
            if (isset($_POST['include_gender'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['gender']);
            if (isset($_POST['include_department'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['department_name']);
            if (isset($_POST['include_year_level'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['year_level']);
            if (isset($_POST['include_classes'])) {
                // Fetch assigned classes for export
                $class_query = "SELECT c.class_name FROM student_classes sc JOIN classes c ON sc.class_id = c.id WHERE sc.student_id = ?";
                $class_stmt = $conn->prepare($class_query);
                $class_stmt->bind_param("i", $user[' id']);
                $class_stmt->execute();
                $class_result = $class_stmt->get_result();

                $assigned_classes = [];
                while ($class_row = $class_result->fetch_assoc()) {
                    $assigned_classes[] = $class_row['class_name'];
                }
                $class_list = empty($assigned_classes) ? "None" : implode(", ", $assigned_classes);
                $sheet->setCellValue($columnIndex++ . $rowNumber, $class_list); // Add classes to the sheet
            }
            if (isset($_POST['include_status'])) $sheet->setCellValue($columnIndex++ . $rowNumber, $user['approval_status']);
            $rowNumber++;
        }

        // Create Excel file
        $writer = new Xlsx($spreadsheet);
        $filename = 'student_users.xlsx';

        // Clear output buffer
        ob_end_clean(); // Clear any previous output

        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment; filename="' . $filename . '"');
        header('Cache-Control: max-age=0');

        // Save the file to output
        $writer->save('php://output');
        exit();
    }

    // Handle PDF export similarly using TCPDF
    if (isset($_POST['export_pdf'])) {
        require '../vendor/tecnickcom/tcpdf/tcpdf.php'; // Include TCPDF
        
        // Clear output buffer
        ob_end_clean(); // Clear any previous output

        // Create new PDF document
        $pdf = new TCPDF();
        $pdf->SetCreator(PDF_CREATOR);
        $pdf->SetAuthor('AcademyClan - Think Beyond, Learn Beyond.');
        $pdf->SetTitle('AcademyClan - Student Users Details');
        $pdf->SetHeaderData('', 0, 'AcademyClan - Think Beyond, Learn Beyond.', 'Generated on ' . date('Y-m-d H:i:s'));
        $pdf->setHeaderFont(Array(PDF_FONT_NAME_MAIN, '', PDF_FONT_SIZE_MAIN));
        $pdf->setFooterFont(Array(PDF_FONT_NAME_DATA, '', PDF_FONT_SIZE_DATA));
        $pdf->SetDefaultMonospacedFont(PDF_FONT_MONOSPACED);
        $pdf->SetMargins(PDF_MARGIN_LEFT, PDF_MARGIN_TOP, PDF_MARGIN_RIGHT);
        $pdf->SetAutoPageBreak(TRUE, PDF_MARGIN_BOTTOM);
        $pdf->AddPage();

        // Set font
        $pdf->SetFont('helvetica', '', 12);
        
        // Create HTML table
        $html = '<h1>AcademyClan - Student Users Details</h1>';
        $html .= '<table border="1" cellpadding="4"><thead><tr>';

        // Set headers
        if (isset($_POST['include_serial_no'])) $html .= '<th>S. No.</th>';
        if (isset($_POST['include_full_name'])) $html .= '<th>Full Name</th>';
        if (isset($_POST['include_username'])) $html .= '<th>Username</th>';
        if (isset($_POST['include_email'])) $html .= '<th>Email</th>';
        if (isset($_POST['include_mobile_number'])) $html .= '<th>Mobile Number</th>';
        if (isset($_POST['include_register_number'])) $html .= '<th>Register Number</th>';
        if (isset($_POST['include_gender'])) $html .= '<th>Gender</th>';
        if (isset($_POST['include_department'])) $html .= '<th>Department</th>';
        if (isset($_POST['include_year_level'])) $html .= '<th>Year Level</th>';
        if (isset($_POST['include_classes'])) $html .= '<th>Classes</th>';
        if (isset($_POST['include_status'])) $html .= '<th>Status</th>';
        $html .= '</tr></thead><tbody>';

        // Populate data for PDF export
        $serialNo = 1; // Initialize serial number
        // Fetch the data for export using the same query
        $export_results = $conn->query($export_query); // Execute the export query
        while ($user = $export_results->fetch_assoc()) {
            $html .= '<tr>';
            if (isset($_POST['include_serial_no'])) $html .= '<td>' . $serialNo++ . '</td>';
            if (isset($_POST['include_full_name'])) $html .= '<td>' . $user['first_name'] . ' ' . $user['last_name'] . '</td>';
            if (isset($_POST['include_username'])) $html .= '<td>' . $user['username'] . '</td>';
            if (isset($_POST['include_email'])) $html .= '<td>' . $user['email'] . '</td>';
            if (isset($_POST['include_mobile_number'])) $html .= '<td>' . $user['mobile_number'] . '</td>';
            if (isset($_POST ['include_register_number'])) $html .= '<td>' . $user['register_number'] . '</td>';
            if (isset($_POST['include_gender'])) $html .= '<td>' . $user['gender'] . '</td>';
            if (isset($_POST['include_department'])) $html .= '<td>' . $user['department_name'] . '</td>';
            if (isset($_POST['include_year_level'])) $html .= '<td>' . $user['year_level'] . '</td>';
            if (isset($_POST['include_classes'])) {
                // Fetch assigned classes for PDF export
                $class_query = "SELECT c.class_name FROM student_classes sc JOIN classes c ON sc.class_id = c.id WHERE sc.student_id = ?";
                $class_stmt = $conn->prepare($class_query);
                $class_stmt->bind_param("i", $user['id']);
                $class_stmt->execute();
                $class_result = $class_stmt->get_result();

                $assigned_classes = [];
                while ($class_row = $class_result->fetch_assoc()) {
                    $assigned_classes[] = $class_row['class_name'];
                }
                $class_list = empty($assigned_classes) ? "None" : implode(", ", $assigned_classes);
                $html .= '<td>' . $class_list . '</td>'; // Add classes to the table
            }
            if (isset($_POST['include_status'])) $html .= '<td>' . $user['approval_status'] . '</td>';
            $html .= '</tr>';
        }
        $html .= '</tbody></table>';
        $pdf->writeHTML($html, true, false, true, false, '');
        $pdf->Output('student_users.pdf', 'D');
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Students</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
            margin-left: 107px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
        
        #classCheckboxes p {
            color: red; /* Change color to red for visibility */
            font-weight: bold; /* Make the text bold */
        }
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Students</h2>

        <!-- Button to trigger Add Student Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addStudentModal">
            <i class="fas fa-user-plus"></i> Add Student
        </button>

        <!-- Button to trigger Export Modal -->
        <button type="button" class="btn btn-danger mb-3" data-bs-toggle="modal" data-bs-target="#exportModal">
            <i class="fas fa-file-export"></i> Export
        </button>
        <!-- Filter Options -->
        <form method="get" class="mb-3" style="margin-left: 107px;">
            <div class="row">
                <div class="col-md-4">
                    <label for="year_level_id">Year Level:</label>
                    <select name="year_level_id" id="year_level_id" class="form-select" onchange="this.form.submit()">
                        <option value="">All Year Levels</option>
                        <?php foreach ($year_levels as $year): ?>
                            <option value="<?= $year['id'] ?>" <?= $year['id'] == $selected_year_level ? 'selected' : ''; ?>>
                                <?= $year['year_level'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4">
                    <label for="department_id">Department:</label>
                    <select name="department_id" id="department_id" class="form-select" onchange="this.form.submit()">
                        <option value="">All Departments</option>
                        <?php foreach ($departments as $dept): ?>
                            <option value="<?= $dept['id'] ?>" <?= $dept['id'] == $selected_department ? 'selected' : ''; ?>>
                                <?= $dept['department_name'] ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-4">
                    <label for="records_per_page">Records per page:</label>
                    <select name="records_per_page" id="records_per_page" class="form-select" onchange="this.form.submit()">
                        <?php foreach ($records_per_page_options as $option): ?>
                            <option value="<?php echo $option; ?>" <?php echo $option == $records_per_page ? 'selected' : ''; ?>>
                                <?php echo $option; ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
            </div>
        </form>

        <div class="messages">
            <?php if (isset($_SESSION['success_message'])): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($_SESSION['success_message']); ?>
                </div>
                <?php unset($_SESSION['success_message']); ?>
            <?php endif; ?>

            <?php if (isset($_SESSION['error_message'])): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($_SESSION['error_message']); ?>
                </div>
                <?php unset($_SESSION['error_message']); ?>
            <?php endif; ?>
        </div>

        <!-- Student Users Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th>
                    <th>Avatar</th>
                    <th>Full Name</th>
                    <th>Username</th>
                    <th>Email</th>
                    <th>Mobile Number</th>
                    <th>Register Number</th>
                    <th>Gender</th>
                    <th>Department</th>
                    <th>Year Level</th>
                    <th>Classes</th>
                    <th>Approval Status</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php
                if ($results->num_rows > 0) {
                    $serialNo = 1; // Initialize serial number
                    while ($user = $results->fetch_assoc()) {
                        // Get department name
                        $dept_name = '';
                        foreach ($departments as $dept) {
                            if ($dept['id'] == $user['department_id']) {
                                $dept_name = $dept['department_name'];
                                break;
                            }
                        }

                        // Get year level name
                        $year_name = '';
                        foreach ($year_levels as $year) {
                            if ($year['id'] == $user['year_level_id']) {
                                $year_name = $year['year_level'];
                                break;
                            }
                        }

                        // Fetch avatar based on role and gender
                        $stmt = $conn->prepare("SELECT avatar_path FROM avatars WHERE role = ? AND gender = ?");
                        $stmt->bind_param("ss", $user['role'], $user['gender']);
                        $stmt->execute();
                        $avatar_result = $stmt->get_result();
                        if ($avatar_result->num_rows > 0) {
                            $avatar_data = $avatar_result->fetch_assoc();
                            $avatar_path = $avatar_data['avatar_path'];
                        } else {
                            $avatar_path = '../uploads/avatars/default-avatar.png'; // Default avatar if none found
                        }

                        // Fetch assigned classes
                        $class_query = "SELECT c.class_name FROM student_classes sc JOIN classes c ON sc.class_id = c.id WHERE sc.student_id = ?";
                        $class_stmt = $conn->prepare($class_query);
                        $class_stmt->bind_param("i", $user['id']);
                        $class_stmt->execute();
                        $class_result = $class_stmt->get_result();
 
                        $assigned_classes = [];
                        while ($class_row = $class_result->fetch_assoc()) {
                            $assigned_classes[] = $class_row['class_name'];
                        }
                        $class_list = implode(", ", $assigned_classes);
 
                        echo "
                            <tr>
                                <td>{$serialNo}</td>
                                <td><img src='../uploads/{$avatar_path}' alt='avatar' class='avatar' height='50px' width='50px'></td>
                                <td>{$user['first_name']} {$user['last_name']}</td>
                                <td>{$user['username']}</td>
                                <td>{$user['email']}</td>
                                <td>{$user['mobile_number']}</td>
                                <td>{$user['register_number']}</td>
                                <td>{$user['gender']}</td>
                                <td>{$dept_name}</td>
                                <td>{$year_name}</td>
                                <td>{$class_list}</td>
                                <td>{$user['approval_status']}</td>
                                <td>
                                    <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editStudentModal' onclick='populateEditModal({$user['id']})'>
                                        <i class='fas fa-edit'></i> Edit
                                    </button>
                                    <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteStudentModal' onclick='setDeleteModal({$user['id']})'>
                                        <i class='fas fa-trash'></i> Delete
                                    </button>
                                    <button class='btn btn-info btn-sm' data-bs-toggle='modal' data-bs-target='#assignClassesModal' onclick='setAssignClassesModal({$user['id']})'>
                                        <i class='fas fa-chalkboard-teacher'></i> Assign Classes
                                    </button>
                                </td>
                            </tr>
                        ";
                        $serialNo++; // Increment serial number
                    }
                } else {
                    echo "<tr><td colspan='13'>No records found</td></tr>";
                }
                ?>
            </tbody>
        </table>

        <!-- Pagination controls -->
        <nav aria-label="Page navigation">
            <ul class="pagination justify-content-left">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=1&records_per_page=<?php echo $records_per_page; ?>" aria-label="First">
                            <span aria-hidden="true">&laquo;&laquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page - 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Previous">
                            <span aria-hidden="true">&laquo;</span>
                        </a>
                    </li>
                <?php endif; ?>

                <?php
                $max_displayed_pages = 17; // Total number of pages to display
                $start_page = max(1, $current_page - floor($max_displayed_pages / 2));
                $end_page = min($total_pages, $start_page + $max_displayed_pages - 1);

                // Adjust start page if there are not enough pages before the current page
                if ($end_page - $start_page < $max_displayed_pages - 1) {
                    $start_page = max(1, $end_page - $max_displayed_pages + 1);
                }

                // Ensure we do not exceed the total number of pages
                if ($end_page > $total_pages) {
                    $end_page = $total_pages;
                }

                // Display pages
                for ($i = $start_page; $i <= $end_page; $i++): ?>
                    <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?php echo $i; ?>&records_per_page=<?php echo $records_per_page; ?>"><?php echo $i; ?></a>
                    </li>
                <?php endfor; ?>

                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page + 1; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Next">
                            <span aria-hidden="true">&raquo;</span>
                        </a>
                    </li>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $total_pages; ?>&records_per_page=<?php echo $records_per_page; ?>" aria-label="Last">
                            <span aria-hidden="true">&raquo;&raquo;</span>
                        </a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>
    </div>

    <!-- Export Modal -->
    <div class="modal fade" id="exportModal" tabindex="-1" aria-labelledby="exportModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="exportModalLabel">Export Options</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form method="post">
                    <div class="modal-body">
                        <div class="form-check">
                            <input type="checkbox" class="form-check-input" id="select_all_fields" onclick="toggleFieldCheckboxes(this)">
                            <label class="form-check-label" for="select_all_fields">Select All Fields</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_serial_no" id="include_serial_no" checked>
                            <label class="form-check-label" for="include_serial_no">Include Serial Number</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_full_name" id="include_full_name" checked>
                            <label class="form-check-label" for="include_full_name">Include Full Name</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_username" id="include_username" checked>
                            <label class="form-check-label" for="include_username">Include Username</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_email" id="include_email" checked>
                            <label class="form-check-label" for="include_email">Include Email</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_mobile_number" id="include_mobile_number" checked>
                            <label class="form-check-label" for="include_mobile_number">Include Mobile Number</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_register_number" id="include_register_number" checked>
                            <label class="form-check-label" for="include_register_number">Include Register Number</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_gender" id="include_gender" checked>
                            <label class="form-check-label" for="include_gender">Include Gender</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_department" id="include_department" checked>
                            <label class="form-check-label" for="include_department">Include Department</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_year_level" id="include_year_level" checked>
                            <label class="form-check-label" for="include_year_level">Include Year Level</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_classes" id="include_classes" checked>
                            <label class="form-check-label" for="include_classes">Include Classes</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="checkbox" name="include_status" id="include_status" checked>
                            <label class="form-check-label" for="include_status">Include Approval Status</label>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" name="export_excel" class="btn btn-success"><i class="fas fa-file-excel"></i> Export to Excel</button>
                        <button type="submit" name="export_pdf" class="btn btn-danger"><i class="fas fa-file-pdf"></i> Export to PDF</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Add Student Modal -->
    <div class="modal fade" id="addStudentModal" tabindex="-1" aria-labelledby="addStudentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addStudentModalLabel">Add Student</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_student.php" method="POST">
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="first_name" name="first_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="last_name" name="last_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="username" name="username" required>
                        </div>
                        <div class="mb-3">
                            <label for="email" class="form-label">Email</label>
                            <input type="email" class="form-control" id="email" name="email" required>
                        </div>
                        <div class="mb-3">
                            <label for="mobile_number" class="form-label">Mobile Number</label>
                            <input type="text" class="form-control" id="mobile_number" name="mobile_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="register_number" class="form-label">Register Number</label>
                            <input type="text" class="form-control" id="register_number" name="register_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="gender" class="form-label">Gender</label>
                            <select class="form-select" id="gender" name="gender" required>
                                <option value="male">Male</option>
                                <option value="female">Female</option>
                                <option value="other">Other</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="department_id" class="form-label">Department</label>
                            <select class="form-select" id="department_id" name="department_id" required>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= $dept['department_name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="year_level_id" name="year_level_id" required>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= $year['year_level'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add Student</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Student Modal -->
    <div class="modal fade" id="editStudentModal" tabindex="-1" aria-labelledby="editStudentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editStudentModalLabel">Edit Student</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_student.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="studentId" name="id">
                        <div class="mb-3">
                            <label for="edit_first_name" class="form-label">First Name</label>
                            <input type="text" class="form-control" id="edit_first_name" name="first_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_last_name" class="form-label">Last Name</label>
                            <input type="text" class="form-control" id="edit_last_name" name="last_name" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_username" class="form-label">Username</label>
                            <input type="text" class="form-control" id="edit_username" name="username" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_email" class="form-label">Email</label>
                            <input type="email" class="form-control" id="edit_email" name="email" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_mobile_number" class="form-label">Mobile Number</label>
                            <input type="text" class="form-control" id="edit_mobile_number" name="mobile_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_register_number" class="form-label">Register Number</label>
                            <input type="text" class="form-control" id="edit_register_number" name="register_number" required>
                        </div>
                        <div class="mb-3">
                            <label for="edit_gender" class="form-label">Gender</label>
                            <select class="form-select" id="edit_gender" name="gender" required>
                                <option value="male">Male</option>
                                <option value="female">Female</option>
                                <option value="other">Other</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_department_id" class="form-label">Department</label>
                            <select class="form-select" id="edit_department_id" name="department_id" required>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= $dept['department_name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="edit_year_level_id" class="form-label">Year Level</label>
                            <select class="form-select" id="edit_year_level_id" name="year_level_id" required>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= $year['year_level'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    <div class="mb-3">
                            <label for="edit_approval_status" class="form-label">Approval Status</label>
                            <select class="form-select" id="edit_approval_status" name="approval_status" required>
                                <option value="pending">Pending</option>
                                <option value="approved">Approved</option>
                                <option value="rejected">Rejected</option>
                            </select>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Student</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Student Modal -->
    <div class="modal fade" id="deleteStudentModal" tabindex="-1" aria-labelledby="deleteStudentModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteStudentModalLabel">Delete Student</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_student.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="id" id="deleteStudentId">
                        <p>Are you sure you want to delete this student?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete User</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Assign Classes Modal -->
    <div class="modal fade" id="assignClassesModal" tabindex="-1" aria-labelledby="assignClassesModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="assignClassesModalLabel">Assign Classes to Student</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="assign_classes.php" method="POST" onsubmit="return validateClassSelection();">
                    <div class="modal-body">
                        <input type="hidden" id="assignStudentId" name="student_id">
                        
                        <!-- Filter Options -->
                        <div class="mb-3">
                            <label for="filter_year_level_id" class="form-label">Year Level</label>
                            <select id="filter_year_level_id" class="form-select" onchange="fetchClasses()">
                                <option value="0">All Year Levels</option>
                                <?php foreach ($year_levels as $year): ?>
                                    <option value="<?= $year['id'] ?>"><?= $year['year_level'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label for="filter_department_id" class="form-label">Department</label>
                            <select id="filter_department_id" class="form-select" onchange="fetchClasses()">
                                <option value="0">All Departments</option>
                                <?php foreach ($departments as $dept): ?>
                                    <option value="<?= $dept['id'] ?>"><?= $dept['department_name'] ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div id="existingClasses" class="mb-3">
                            <label for="existing_classes" class="form-label"><b>Currently Assigned Classes or Select to Remove from assigned classes.</b></label>
                            <ul id="existingClassesList"></ul>
                            <div id="noAssignedClassesMessage" style="display:none; color: red;">No classes currently assigned.</div>
                        </div>

                        <div class="mb-3">
                            <label for="class_id" class="form-label"><b>Select Classes to Assign</b></label>
                            <div>
                                <input type="checkbox" id="select_all_classes" onclick="toggleClassCheckboxes(this)">
                                <label for="select_all_classes">Select All</label>
                            </div>
                            <div id="classCheckboxes">
                                <!-- Classes will be populated here dynamically -->
                                <div id="loadingIndicator" style="display:none;">Loading...</div>
                            </div>
                            <div id="noClassesMessage" style="display:none; color: red;">No classes found for the selected filters.</div>
                        </div>

                        <div id="loadingIndicator" style="display:none;">Loading...</div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" onclick="clearFilters()">Clear Filters</button>
                        <button type="submit" class="btn btn-primary">Assign Classes</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // JavaScript function to populate edit modal
        function populateEditModal(studentId) {
            fetch(`get_student_user.php?id=${studentId}`)
                .then(response => {
                    if (!response.ok) {
                        throw new Error(`HTTP error! Status: ${response.status}`);
                    }
                    return response.json();
                })
                .then(data => {
                    if (data && typeof data === 'object') {
                        document.getElementById('studentId').value = data.id || '';
                        document.getElementById('edit_first_name').value = data.first_name || '';
                        document.getElementById('edit_last_name').value = data.last_name || '';
                        document.getElementById('edit_username').value = data.username || '';
                        document.getElementById('edit_email').value = data.email || '';
                        document.getElementById('edit_mobile_number').value = data.mobile_number || '';
                        document.getElementById('edit_register_number').value = data.register_number || '';
                        document.getElementById('edit_gender').value = data.gender || '';
                        document.getElementById('edit_department_id').value = data.department_id || '';
                        document.getElementById('edit_year_level_id').value = data.year_level_id || '';
                        document.getElementById('edit_approval_status').value = data.approval_status || '';
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to set delete modal ID
        function setDeleteModal(studentId) {
            document.getElementById('deleteStudentId').value = studentId;
        }

        // Function to set the Assign Classes Modal with the student ID
        function setAssignClassesModal(studentId) {
            document.getElementById('assignStudentId').value = studentId; // Set the student ID in the hidden input
            clearFilters(); // Clear filters when the modal is opened
            fetchClasses(); // Fetch classes based on the cleared filters
        }

        // Debounce function
        function debounce(func, delay) {
            let timeout;
            return function(...args) {
                clearTimeout(timeout);
                timeout = setTimeout(() => func.apply(this, args), delay);
            };
        }

        // Function to fetch classes based on selected filters
        const fetchClasses = debounce(() => {
            const departmentId = document.getElementById('filter_department_id').value;
            const yearLevelId = document.getElementById('filter_year_level_id').value;

            // Show loading indicator
            const loadingIndicator = document.getElementById('loadingIndicator');
            loadingIndicator.style.display = 'block';

            // Fetch classes based on selected filters
            let url = 'fetch_classes.php';
            let params = [];

            if (yearLevelId !== '0') {
                params.push(`year_level_id=${yearLevelId}`);
            }
            if (departmentId !== '0') {
                params.push(`department_id=${departmentId}`);
            }

            const queryString = params.length > 0 ? `?${params.join('&')}` : '';

            fetch(`${url}${queryString}`)
                .then(response => response.json())
                .then(data => {
                    const classCheckboxes = document.getElementById('classCheckboxes');
                    classCheckboxes.innerHTML = ''; // Clear previous checkboxes
                    const noClassesMessage = document.getElementById('noClassesMessage');
                    noClassesMessage.style.display = 'none'; // Hide no classes message

                    // Check if any classes were returned
                    if (data.length === 0) {
                        noClassesMessage.style.display = 'block'; // Show no classes found message
                    } else {
                        data.forEach(classItem => {
                            const checkbox = document.createElement('div');
                            checkbox.className = 'form-check';
                            checkbox.innerHTML = `
                                <input class="form-check-input" type="checkbox" name="class_id[]" value="${classItem.id}" id="class_${classItem.id}">
                                <label class="form-check-label" for="class_${classItem.id}">
                                    ${classItem.class_name}
                                    <br>
                                    <small>Year Level: ${classItem.year_level}</small>
                                    <br>
                                    <small>Department: ${classItem.department_name}</small>
                                    <br>
                                    <small>Handled by: ${classItem.description}</small>
                                </label>
                            `;
                            classCheckboxes.appendChild(checkbox);
                        });
                    }

                    // Fetch assigned classes for the student
                    fetchAssignedClasses();
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                })
                .finally(() => {
                    // Hide loading indicator
                    loadingIndicator.style.display = 'none';
                });
        }, 300); // 300ms debounce delay

        // Function to fetch assigned classes for the student
        function fetchAssignedClasses() {
            const studentId = document.getElementById('assignStudentId').value;

            fetch(`get_student_classes.php?id=${studentId}`)
                .then(response => response.json())
                .then(assignedClasses => {
                    const existingClassesList = document.getElementById('existingClassesList');
                    existingClassesList.innerHTML = ''; // Clear previous assigned classes
                    const noAssignedClassesMessage = document.getElementById('noAssignedClassesMessage');
                    noAssignedClassesMessage.style.display = 'none'; // Hide no assigned classes message

                    // Check if any assigned classes were returned
                    if (assignedClasses.length === 0) {
                        noAssignedClassesMessage.style.display = 'block'; // Show no assigned classes message
                    } else {
                        assignedClasses.forEach(classItem => {
                            const listItem = document.createElement('li');
                            listItem.innerHTML = `
                                <input type="checkbox" name="remove_class_id[]" value="${classItem.class_id}" id="remove_class_${classItem.class_id}">
                                <label for="remove_class_${classItem.class_id}">
                                    ${classItem.class_name} 
                                    <br>
                                    <small>Year Level: ${classItem.year_level}</small>
                                    <br>
                                    <small>Department: ${classItem.department_name}</small>
                                    <br>
                                    <small>Handled by: ${classItem.description}</small>
                                </label>
                            `;// Add class name and details to the list
                            existingClassesList.appendChild(listItem);
                        });
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to validate class selection before submission
        function validateClassSelection() {
            const newClassCheckboxes = document.querySelectorAll('#classCheckboxes input[type="checkbox"]:checked');
            const removeClassCheckboxes = document.querySelectorAll('#existingClassesList input[type="checkbox"]:checked');

            if (newClassCheckboxes.length === 0 && removeClassCheckboxes.length === 0) {
                alert('Please select at least one class to assign or remove before submitting.'); // Alert if no classes are selected
                return false; // Prevent form submission
            }
            return true; // Allow form submission
        }
        // Function to clear filters and reset selections
        function clearFilters() {
            document.getElementById('filter_department_id').value = '0';
            document.getElementById('filter_year_level_id').value = '0';
            fetchClasses(); // Fetch all classes again
        }

        // Add event listeners to the filter select elements
        document.getElementById('filter_department_id').addEventListener('change', fetchClasses);
        document.getElementById('filter_year_level_id').addEventListener('change', fetchClasses);

        // Function to toggle all class checkboxes
        function toggleClassCheckboxes(selectAllCheckbox, isSelect = true) {
            const checkboxes = document.querySelectorAll('#classCheckboxes input[type="checkbox"]');
            checkboxes.forEach(checkbox => {
                checkbox.checked = isSelect ? selectAllCheckbox.checked : false; // Select or deselect based on the checkbox clicked
            });
        }

        // Initialize clear filters when the modal is shown
        document.getElementById('assignClassesModal').addEventListener('show.bs.modal', function () {
            clearFilters(); // Call clearFilters to reset the filters and fetch classes
        });
    </script>
</body>
</html>