<?php
session_start();
if (!isset($_SESSION['user_id']) || $_SESSION['role'] != 'faculty') {
    echo "User is not logged in or not a faculty.";
    header("Location: ../login.php");
    exit();
}


// Display success or error messages
$success_message = $_SESSION['success_message'] ?? null;
$error_message = $_SESSION['error_message'] ?? null;
unset($_SESSION['success_message'], $_SESSION['error_message']);

include '../includes/dbcon.php'; // Include database connection

// Fetch year levels
$year_levels = [];
$year_query = "SELECT id, year_level, created_at, updated_at FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result && $year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Manage Academic Years</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .messages .alert {
            margin-bottom: 20px;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        .sidebar {
            height: 100%;
            background-color: #6e8efb;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #6e8efb; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #f39c12; /* Hover effect for dropdown items */
        }
        
    </style>
</head>
<body>

    <!-- Header and Sidebar -->
    <?php include '../includes/faculty_header.php'; ?>
    <?php include '../includes/faculty_sidebar.php'; ?>

    <div class="container mt-5">
        <h2>Manage Academic Years</h2>

        <!-- Button to trigger Add Year Level Modal -->
        <button type="button" class="btn btn-primary mb-3" data-bs-toggle="modal" data-bs-target="#addYearLevelModal">
            <i class="fas fa-calendar-alt"></i> Add Year Level
        </button>

        <div class="messages">
            <?php if ($success_message): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($success_message); ?>
                </div>
            <?php endif; ?>

            <?php if ($error_message): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($error_message); ?>
                </div>
            <?php endif; ?>
        </div>

        <!-- Year Levels Table -->
        <table class="table table-bordered">
            <thead>
                <tr>
                    <th>S. No.</th> <!-- Serial Number Column -->
                    <!-- <th>ID</th> -->
                    <th>Year Level</th>
                    <th>Created at</th>
                    <th>Updated at</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
                <?php if (count($year_levels) > 0): ?>
                    <?php foreach ($year_levels as $index =>  $year): ?>
                        <tr>
                            <td><?= $index + 1; ?></td> <!-- Serial Number -->
                            <!-- <td><?= htmlspecialchars($year['id']); ?></td> -->
                            <td><?= htmlspecialchars($year['year_level']); ?></td>
                            <td><?= htmlspecialchars($year['created_at']); ?> UTC</td>
                            <td><?= htmlspecialchars($year['updated_at']); ?> UTC</td>
                            <td>
                                <button class='btn btn-warning btn-sm' data-bs-toggle='modal' data-bs-target='#editYearLevelModal' onclick='populateEditModal(<?= $year['id']; ?>)'><i class='fas fa-edit'></i> Edit</button>
                                <button class='btn btn-danger btn-sm' data-bs-toggle='modal' data-bs-target='#deleteYearLevelModal' onclick='setDeleteModal(<?= $year['id']; ?>)'><i class='fas fa-trash'></i> Delete</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php else: ?>
                    <tr><td colspan='5'>No records found</td></tr>
                <?php endif; ?>
            </tbody>
        </table>
    </div>

    <!-- Add Year Level Modal -->
    <div class="modal fade" id="addYearLevelModal" tabindex="-1" aria-labelledby="addYearLevelModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="addYearLevelModalLabel">Add Year Level</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="add_year_level.php" method="POST">
                    <div class="modal-body">
                        <div class="mb-3">
                            <label for="year_level" class="form-label">Year Level</label>
                            <input type="text" class="form-control" id="year_level" name="year_level" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add Year Level</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Edit Year Level Modal -->
    <div class="modal fade" id="editYearLevelModal" tabindex="-1" aria-labelledby="editYearLevelModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="editYearLevelModalLabel">Edit Year Level</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="edit_year_level.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" id="yearLevelId" name="id"> <!-- Changed name to 'id' -->
                        <div class="mb-3">
                            <label for="edit_year_level" class="form-label">Year Level</label>
                            <input type="text" class="form-control" id="edit_year_level" name="year_level" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update Year Level</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Delete Year Level Modal -->
    <div class="modal fade" id="deleteYearLevelModal" tabindex="-1" aria-labelledby="deleteYearLevelModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="deleteYearLevelModalLabel">Delete Year Level</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <form action="delete_year_level.php" method="POST">
                    <div class="modal-body">
                        <input type="hidden" name="year_level_id" id="deleteYearLevelId">
                        <p>Are you sure you want to delete this year level?</p>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-danger">Delete Year Level</button>
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Include Bootstrap JS -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // JavaScript function to populate edit modal
        function populateEditModal(yearLevelId) {
            fetch(`get_year_level.php?id=${yearLevelId}`)
                .then(response => {
                    if (!response.ok) {
                        throw new Error(`HTTP error! Status: ${response.status}`);
                    }
                    return response.json();
                })
                .then(data => {
                    if (data && data.success) {
                        document.getElementById('yearLevelId').value = data.id || ''; // Set the ID
                        document.getElementById('edit_year_level').value = data.year_level || ''; // Set the year level
                    } else {
                        console.error('Error fetching year level:', data.message);
                    }
                })
                .catch(error => {
                    console.error('Fetch failed:', error);
                });
        }

        // Function to set delete modal ID
        function setDeleteModal(yearLevelId) {
            document.getElementById('deleteYearLevelId').value = yearLevelId;
        }
    </script>
</body>
</html>