<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Enable error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Check if the user is logged in and has the role of 'faculty'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'faculty') {
    echo json_encode(['success' => false, 'message' => 'Unauthorized']);
    exit();
}

// Initialize response array
$response = ['success' => false, 'message' => ''];

// Handle updating options
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_options'])) {
    $question_id = intval($_POST['question_id']);
    $options = $_POST['options'];
    $is_correct = isset($_POST['is_correct']) ? $_POST['is_correct'] : [];
    $option_ids = $_POST['option_ids'];

    // Reset all options to not correct
    if (!$conn->query("UPDATE quiz_options SET is_correct=0 WHERE question_id=" . intval($question_id))) {
        $response['message'] = 'Error resetting options: ' . $conn->error;
        echo json_encode($response);
        exit();
    }

    // Call the appropriate function based on question type
    $question_type = fetchQuestion($conn, $question_id)['question_type'];
    if ($question_type === 'multiple-choice') {
        $options_error = updateMultipleChoiceOptions($conn, $question_id, $options, $is_correct, $option_ids);
    } elseif ($question_type === 'true-false') {
        $options_error = updateTrueFalseOptions($conn, $question_id, $options, $is_correct, $option_ids);
    } elseif ($question_type === 'checkbox') {
        $options_error = updateCheckboxOptions($conn, $question_id, $options, $is_correct, $option_ids);
    }

    if ($options_error) {
        $response['message'] = $options_error; // Capture any error from updating options
    } else {
        $response['success'] = true;
        $response['message'] = 'Options updated successfully!';
    }
}

// Return JSON response
echo json_encode($response);

// Function to fetch question details
function fetchQuestion($conn, $question_id) {
    $stmt = $conn->prepare("SELECT question_type FROM quiz_questions WHERE id=?");
    $stmt->bind_param("i", $question_id);
    $stmt->execute();
    return $stmt->get_result()->fetch_assoc();
}

// Function to update multiple choice options
function updateMultipleChoiceOptions($conn, $question_id, $options, $is_correct, $option_ids) {
    foreach ($options as $index => $option_text) {
        $is_correct_value = (isset($is_correct) && $is_correct == $option_ids[$index]) ? 1 : 0; // Only one can be correct
        if (isset($option_ids[$index]) && !empty($option_ids[$index])) {
            // Update existing option
            $option_id = intval($option_ids[$index]);
            $option_stmt = $conn->prepare("UPDATE quiz_options SET option_text=?, is_correct=? WHERE option_id=?");
            $option_stmt->bind_param("sii", $option_text, $is_correct_value, $option_id);
            if (!$option_stmt->execute()) {
                return 'Error updating option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        } else {
            // Insert new option if it doesn't exist
            $option_stmt = $conn->prepare("INSERT INTO quiz_options (question_id, option_text, is_correct) VALUES (?, ?, ?)");
            $option_stmt->bind_param("isi", $question_id, $option_text, $is_correct_value);
            if (!$option_stmt->execute()) {
                return 'Error inserting option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        }
    }
    return ''; // Return empty string if no error
}

// Function to update true/false options
function updateTrueFalseOptions($conn, $question_id, $options, $is_correct, $option_ids) {
    foreach ($options as $index => $option_text) {
        $is_correct_value = (isset($is_correct) && $is_correct == $option_ids[$index]) ? 1 : 0; // Only one can be correct
        if (isset($option_ids[$index]) && !empty($option_ids[$index])) {
            // Update existing option
            $option_id = intval($option_ids[$index]);
            $option_stmt = $conn->prepare("UPDATE quiz_options SET option_text=?, is_correct=? WHERE option_id=?");
            $option_stmt->bind_param("sii", $option_text, $is_correct_value, $option_id);
            if (!$option_stmt->execute()) {
                return 'Error updating option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        } else {
            // Insert new option if it doesn't exist
            $option_stmt = $conn->prepare("INSERT INTO quiz_options (question_id, option_text, is_correct) VALUES (?, ?, ?)");
            $option_stmt->bind_param("isi", $question_id, $option_text, $is_correct_value);
            if (!$option_stmt->execute()) {
                return 'Error inserting option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        }
    }
    return ''; // Return empty string if no error
}

// Function to update checkbox options
function updateCheckboxOptions($conn, $question_id, $options, $is_correct, $option_ids) {
    foreach ($options as $index => $option_text) {
        $is_correct_value = isset($is_correct[$option_ids[$index]]) ? 1 : 0; // Allow multiple correct options
        if (isset($option_ids[$index]) && !empty($option_ids[$index])) {
            // Update existing option
            $option_id = intval($option_ids[$index]);
            $option_stmt = $conn->prepare("UPDATE quiz_options SET option_text=?, is_correct=? WHERE option_id=?");
            $option_stmt->bind_param("sii", $option_text, $is_correct_value, $option_id);
            if (!$option_stmt->execute()) {
                return 'Error updating option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        } else {
            // Insert new option if it doesn't exist
            $option_stmt = $conn->prepare("INSERT INTO quiz_options (question_id, option_text, is_correct) VALUES (?, ?, ?)");
            $option_stmt->bind_param("isi", $question_id, $option_text, $is_correct_value);
            if (!$option_stmt->execute()) {
                return 'Error inserting option: ' . $option_stmt->error; // Return error message
            }
            $option_stmt->close();
        }
    }
    return ''; // Return empty string if no error
}