<?php
// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// SMTP Configuration
define('SMTP_USERNAME', 'academyclanofficial@gmail.com'); // Your Gmail Address
define('SMTP_PASSWORD', 'vrlroovxawlbhxzq'); // Your App Password

require 'includes/dbcon.php'; // Database connection
require 'vendor/autoload.php'; // Autoload all Composer dependencies
require 'vendor/phpmailer/src/Exception.php';
require 'vendor/phpmailer/src/PHPMailer.php';
require 'vendor/phpmailer/src/SMTP.php';

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Initialize message variable
$message = '';
$showModal = false;

// Rate limiting variables
$rateLimit = 3; // Max attempts
$timeFrame = 3600; // 1 hour in seconds

// Check if email is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $email = $_POST['email'];

    // Validate email format
    if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
        $message = "Invalid email format.";
        $showModal = true;
    } else {
        // Check if email exists in the users table
        $stmt = $conn->prepare("SELECT id FROM users WHERE email = ?");
        $stmt->bind_param("s", $email);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();
            $userId = $user['id'];

            // Rate limiting check
            $stmt = $conn->prepare("SELECT COUNT(*) AS request_count FROM activity_logs WHERE user_id = ? AND action = 'User   requested password reset' AND created_at > NOW() - INTERVAL 1 HOUR");
            $stmt->bind_param("i", $userId);
            $stmt->execute();
            $rateResult = $stmt->get_result();
            $rateData = $rateResult->fetch_assoc();

            if ($rateData['request_count'] >= $rateLimit) {
                $message = "You have exceeded the maximum number of password reset requests. Please try again later.";
                $showModal = true;
            } else {
                // Check if a valid token already exists
                $stmt = $conn->prepare("SELECT reset_token, token_expiry FROM password_resets WHERE user_id = ? AND token_expiry > NOW()");
                $stmt->bind_param("i", $userId);
                $stmt->execute();
                $tokenResult = $stmt->get_result();

                if ($tokenResult->num_rows > 0) {
                    // A valid token already exists
                    $message = "You already have a valid password reset token. Please check your email for the reset link.";
                    $showModal = true;
                } else {
                    // Generate secure reset token
                    $token = bin2hex(random_bytes(32)); // More secure token
                    $expiry = date("Y-m-d H:i:s", strtotime('+1 hour'));

                    // Insert the reset token into the password_resets table
                    $stmt = $conn->prepare("INSERT INTO password_resets (user_id, reset_token, token_expiry) VALUES (?, ?, ?)");
                    $stmt->bind_param("iss", $userId, $token, $expiry);
                    $stmt->execute();

                    // Log the password reset request
                    logActivity($conn, $userId, "User requested password reset", "User requested a password reset for email: $email");

                    // Send reset email
                    if (sendResetEmail($email, $token)) {
                        $message = 'Password reset email has been sent.';
                        $showModal = true; // Show modal for success message
                    } else {
                        $message = "Message could not be sent. Please try again later.";
                        $showModal = true; // Show modal for error message
                    }
                }
            }
        } else {
            $message = "Email address not found.";
            $showModal = true; // Show modal for error message
        }
    }
}

// Function to log activity
function logActivity($conn, $userId, $action, $description) {
    $ipAddress = $_SERVER['REMOTE_ADDR']; // Get the user's IP address
    $userAgent = $_SERVER['HTTP_USER_AGENT']; // Get the user's browser user agent

    $stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
    $stmt->bind_param("issss", $userId, $action, $description, $ipAddress, $userAgent);
    $stmt->execute();
}

// Function to send reset email
function sendResetEmail($email, $token) {
    $resetLink = "https://unique.selfmade.technology/reset_password.php?token=$token"; // Update with your domain
    $mail = new PHPMailer(true);
    try {
        $mail->isSMTP();
        $mail->Host = 'smtp.gmail.com';
        $mail->SMTPAuth = true;
        $mail->Username = SMTP_USERNAME; // Your Gmail Address
        $mail->Password = SMTP_PASSWORD; // Your App Password
        $mail->SMTPSecure = 'tls';
        $mail->Port = 587;

        $mail->setFrom(SMTP_USERNAME, 'AcademyClan - Support');
        $mail->addAddress($email);
        $mail->isHTML(true);
        $mail->Subject = 'AcademyClan - Password Reset Requested Link';
        $mail->Body = "
            <div style='font-family: Arial, sans-serif; color: #333;'>
                <div style='background-color: #f4f7fc; padding: 20px; border-radius: 10px;'>
                    <h2 style='color: #6e8efb;'>Password Reset Request</h2>
                    <p>Dear User,</p>
                    <p>We received a request to reset your password for your account associated with this email address. If you did not request a password reset, please disregard this email.</p>
                    <p style='text-align: center;'>
                        <a href='$resetLink' style='background-color: #6e8efb; color: white; padding: 12px 20px; text-decoration: none; border-radius: 5px; font-weight: bold; font-size: 16px;'>Reset Your Password</a>
                    </p>
                    <p style='text-align: center; font-size: 12px; color: #777;'>This link will expire in 1 hour for your security.</p>
                    <p>If you need further assistance, please do not hesitate to contact our support team.</p>
                    <p>Thank you for being a valued member of our community!</p>
                    <p style='font-weight: bold;'>Best regards,<br>AcademyClan<br>Think Beyond, Learn Beyond.</p>
                    <p style='text-align: center;'>
                        <a href='https://unique.selfmade.technology/' style='color: #6e8efb;'>Visit our website</a>
                    </p>
                </div>
                <div style='margin-top: 20px; font-size: 12px; color: #999;'>
                    <p>This is a system-generated email. Please do not reply to this email.</p>
                </div>
            </div>
        ";

        $mail->AltBody = "Dear User,\n\nWe received a request to reset your password for your account associated with this email address. If you did not request a password reset, please disregard this email.\n\nTo reset your password, please click the following link: $resetLink\n\nThis link will expire in 1 hour for your security. If you need further assistance, please do not hesitate to contact our support team.\n\nThank you for being a valued member of our community!\n\nBest regards,\nAcademyClan\nThink Beyond, Learn Beyond.\nVisit our website: http://unique.selfmade.technology\n\nThis is a system-generated email. Please do not reply to this email.";

        $mail->send();
        return true;
    } catch (Exception $e) {
        error_log("Mailer Error: {$mail->ErrorInfo}"); // Log error
        return false;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Forgot Password</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f7fc;
        }
        .card {
            border-radius: 10px;
        }
        .card-header {
            background-color: #a777e3;
            color: white;
        }
        .card-body {
            background-color: #ffffff;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .btn-custom {
            background-color: #6e8efb;
            color: white;
            font-size: 16px;
        }
        .btn-custom:hover {
            background-color: #0056b3;
        }
        .text-center a {
            color: #ffffff;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="row justify-content-center">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header text-center">
                        <h3><i class="fas fa-key"></i> Forgot Password</h3>
                    </div>
                    <p class="text-center mt-3">
                        <i class="fas fa-envelope"></i> Please provide your email address to receive a password reset link and set a new password for your account.
                    </p>
                    <div class="card-body">
                        <form action="" method="POST">
                            <div class="form-group">
                                <label for="email"><i class="fas fa-user"></i> Enter your email address:</label>
                                <input type="email" class="form-control" id="email" name="email" required>
                            </div>
                            <div class="text-center mt-3">
                                <button type="submit" class="btn btn-custom"><i class="fas fa-paper-plane"></i> Send Reset Link</button>
                            </div>
                        </form>
                        <p class="text-center mt-3">
                            <i class="fas fa-info-circle"></i> If you already know your password, click below to return to the login page.
                        </p>
                        <div class="text-center mt-3">
                            <a href="login.php" class="btn btn-custom"><i class="fas fa-arrow-left"></i> Back to Login</a>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal for displaying messages -->
    <div class="modal fade" id="messageModal" tabindex="-1" aria-labelledby="messageModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="messageModalLabel">Message</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body" id="modalMessage">
                    <?php
                    if ($showModal) {
                        echo $message;
                    }
                    ?>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            <?php if ($showModal) { ?>
                $('#messageModal').modal('show');
            <?php } ?>
        });
    </script>
</body>
</html>