<?php
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

// Fetch user data with role and gender
$stmt = $conn->prepare("
    SELECT users.first_name, users.last_name, users.role, users.gender, avatars.avatar_path AS avatar 
    FROM users 
    LEFT JOIN avatars ON users.role = avatars.role AND users.gender = avatars.gender
    WHERE users.id = ?
");
$stmt->bind_param("i", $_SESSION['user_id']);
$stmt->execute();
$result = $stmt->get_result();
$user = $result->fetch_assoc();

if (!$user) {
    echo "User not found.";
    exit();
}

// Fallback to default avatar if no match in avatars table
$avatar = $user['avatar'] ?? 'avatars/default-avatar.png';
?>

<nav class="navbar navbar-expand-lg navbar-light bg-custom fixed-top">
    <div class="container-fluid">
        <a class="navbar-brand d-flex align-items-center" href="#">
            <img src="../assets/images/logo.png" alt="AcademyClan Logo" class="logo">
            <div class="d-flex flex-column align-items-start">
                <span style="color:#003366; font-weight: bold;">AcademyClan</span>
                <span class="navbar-text tagline" style="color:#debb03; font-weight: bold; font-family: 'Arial', sans-serif;">
                    Think Beyond. Learn Beyond.
                </span>
            </div>
        </a>

        <!-- Fullscreen Toggle (hidden on mobile) -->
        <button id="fullscreenToggle" class="btn btn-sm btn-light me-3 d-none d-lg-block">
            <i class="fas fa-expand"></i>
        </button>

        <!-- Toggle Button for mobile view -->
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>

        <!-- Navbar Links -->
        <div class="collapse navbar-collapse" id="navbarNav">
            <div class="ms-auto d-flex align-items-center">
                <!-- User Info Dropdown -->
                <div class="dropdown">
                    <div class="d-flex align-items-center" id="userDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                        <img src="../uploads/<?php echo htmlspecialchars($avatar); ?>" alt="Avatar" class="rounded-circle" width="40" height="40">
                        <span class="ms-2 text-white user-name"><?php echo htmlspecialchars($user['first_name'] . ' ' . $user['last_name']); ?></span>
                    </div>
                    <ul class="dropdown-menu dropdown-menu-end">
                        <li><a class="dropdown-item" href="../view_profile.php">Profile</a></li>
                        <li><a class="dropdown-item" href="../edit_profile.php">Edit Profile</a></li>
                        <li><a class="dropdown-item" href="../logout.php">Logout</a></li>
                    </ul>
                </div>
                <div id="current-time" class="text-white ms-3"></div>
            </div>
        </div>
    </div>
</nav>

<script>
    function updateTime() {
        const now = new Date();
        const timeString = now.toLocaleTimeString([], { hour: '2-digit', minute: '2-digit', second: '2-digit' });
        const dayString = now.toLocaleString('en-US', { weekday: 'long' });
        const dateString = now.toLocaleString('en-US', { year: 'numeric', month: 'short', day: 'numeric' });
        
        document.getElementById('current-time').innerHTML = `${timeString}<br>${dayString}, ${dateString}`;
        requestAnimationFrame(updateTime);
    }

    function toggleFullscreen() {
        if (!document.fullscreenElement) {
            document.documentElement.requestFullscreen().then(() => {
                localStorage.setItem('fullscreen', 'true'); // Store fullscreen state
                console.log("Entered fullscreen mode");
            }).catch(err => {
                console.error(`Error attempting to enable full-screen mode: ${err.message} (${err.name})`);
            });
        } else {
            document.exitFullscreen().then(() => {
                localStorage.setItem('fullscreen', 'false'); // Update fullscreen state
                console.log("Exited fullscreen mode");
            }).catch(err => {
                console.error(`Error attempting to exit full-screen mode: ${err.message} (${err.name})`);
            });
        }
    }

    // Attach event listener to the fullscreen toggle button
    document.getElementById('fullscreenToggle').addEventListener('click', toggleFullscreen);
    
    // Check fullscreen state on page load
    document.addEventListener('DOMContentLoaded', (event) => {
        if (localStorage.getItem('fullscreen') === 'true') {
            document.getElementById('fullscreen-message').style.display = 'block'; 
            console.log("Fullscreen was previously enabled, please click the button to re-enter.");
        }
    });

    updateTime(); // Start the time update loop
</script>

<style>
    .bg-custom {
        background-color: #a777e3;
    }

    .navbar-toggler-icon {
        background-color: #fff;
    }

    .navbar-brand {
        color: white !important;
    }

    .navbar-nav .text-white {
        color: white !important;
    }

    .profile-menu img {
        width: 40px;
        height: 40px;
        border-radius: 50%;
    }

    /* Responsive styles */
    .logo {
        height: 50px;
        width: 50px;
        border-radius: 50%;
        margin-right: 5px;
    }

    .tagline {
        font-size: small;
        line-height: 0;
    }

    .current-time {
        font-size: small; /* Smaller font for mobile */
        text-align: right; /* Align text to the right */
    }

    .user-name {
        font-size: small; /* Smaller font for mobile */
    }

    /* Dropdown styles */
    .dropdown-menu {
        min-width: 150px; /* Set a minimum width for the dropdown */
    }

    @media (max-width: 768px) {
        .navbar-nav .text-white {
            font-size: 0.9rem; /* Slightly smaller font on mobile */
        }

        .current-time {
            right: 5px; /* Adjust position for mobile */
        }

        .user-name {
            font-size: 0.9rem; /* Adjust user name font size for mobile */
        }
    }
</style>