<?php

// Set the timezone to Asia/Kolkata
ini_set('date.timezone','Asia/Kolkata');
date_default_timezone_set('Asia/Kolkata');
session_start();

include('includes/dbcon.php'); // Include database connection

// Check if the user is logged in and prevent unauthorized access
if (!isset($_SESSION['user_id']) && basename($_SERVER['PHP_SELF']) != 'login.php') {
    header("Location: ../login.php");
    exit();
}

// If the user is logged in, fetch their details
if (isset($_SESSION['user_id'])) {
    $user_id = $_SESSION['user_id'];
    $query = "SELECT * FROM users WHERE id = ?"; // Updated to use the correct column name: 'id'
    $stmt = $conn->prepare($query);

    if ($stmt) {
        $stmt->bind_param("i", $user_id);
        $stmt->execute();
        $result = $stmt->get_result();

        // Check if the user exists in the database
        if ($result->num_rows === 1) {
            $user_data = $result->fetch_assoc();
            $user_role = $user_data['role'];
            $user_name = $user_data['first_name'] . ' ' . $user_data['last_name'];
        } else {
            // If no user is found, log out the session
            session_unset();
            session_destroy();
            header("Location: ../login.php");
            exit();
        }

        $stmt->close();
    } else {
        // Log error if the prepared statement fails
        die("Database query failed: " . $conn->error);
    }
}
?>
