<?php
session_start();

// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include necessary files
include('includes/dbcon.php');
include('activity_log.php');

// Debug database connection
if (!$conn) {
    die("Database connection failed: " . mysqli_connect_error());
}

$message = '';
$showModal = false;
$redirectUrl = ''; // Variable to store the redirect URL
$fullName = ''; // Variable to store the user's full name
$errorMessage = ''; // Variable to store error messages
$showErrorModal = false; // Variable to control the display of the error modal

// Check if the form is submitted
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Trim and sanitize inputs
    $loginInput = trim($_POST['login_input']);
    $password = trim($_POST['password']);

    if (!empty($loginInput) && !empty($password)) {
        // Check if the input is an email or username
        $sql = "SELECT *, CONCAT(first_name, ' ', last_name) AS full_name FROM users WHERE username = ? OR email = ?";
        $stmt = $conn->prepare($sql);

        // Check for statement preparation error
        if (!$stmt) {
            die("Prepared statement failed: " . $conn->error);
        }

        $stmt->bind_param("ss", $loginInput, $loginInput);

        // Execute the statement and check for errors
        if (!$stmt->execute()) {
            die("Query execution failed: " . $stmt->error);
        }

        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $user = $result->fetch_assoc();

            if (password_verify($password, $user['password'])) {
                if ($user['approval_status'] === 'approved') {
                    session_regenerate_id(true);
                    $_SESSION['user_id'] = $user['id'];
                    $_SESSION['role'] = $user['role'];
                    $fullName = $user['full_name']; // Get the full name from the query
                    logActivity($conn, $user['id'], 'User  Login', 'Successful login.');

                    // Set redirect URL based on user role
                    switch ($user['role']) {
                        case 'admin':
                            $redirectUrl = "admin/dashboard.php";
                            break;
                        case 'faculty':
                            $redirectUrl = "faculty/dashboard.php";
                            break;
                        case 'student':
                            $redirectUrl = "student/dashboard.php";
                            break;
                        default:
                            die("Unknown user role.");
                    }
                } elseif ($user['approval_status'] === 'rejected') {
                    $errorMessage = "Your account has been rejected. Please contact the administrator.";
                    logActivity($conn, $user['id'], 'Unauthorized Login Attempt', 'Login failed due to account being rejected.');
                    $showErrorModal = true;
                } else {
                    $errorMessage = "Your account is not approved. Please contact the administrator.";
                    logActivity($conn, $user['id'], 'Unauthorized Login Attempt', 'Login failed due to account not being approved.');
                    $showErrorModal = true;
                }
            } else {
                $errorMessage = "Invalid username or password.";
                logActivity($conn, $user['id'], 'Failed Login Attempt', 'Incorrect password.');
                $showErrorModal = true;
            }
        } else {
            $errorMessage = "No user found with the provided username or email.";
            logActivity($conn, null, 'Failed Login Attempt', 'No user found for input: ' . $loginInput);
            $showErrorModal = true;
        }
    } else {
        $errorMessage = "Please fill in all fields.";
        $showErrorModal = true;
    }

    // Show modal for messages
    $showModal = true;
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Login</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f5f5f5;
        }

        .container {
            background-color: #a777e3;
            padding: 30px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }

        .btn-primary {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }

        .btn-primary:hover {
            background-color: #5b79e0;
            border-color: #5b79e0;
        }

        .btn-secondary {
            background-color: #f39c12;
            border-color: #f39c12;
            color: #fff;
        }

        .btn-secondary:hover {
            background-color: #e67e22;
            border-color: #e67e22;
        }

        .forgot-password {
            color: #ffffff;
            text-decoration: none;
        }

        .forgot-password:hover {
            text-decoration: underline;
        }
    </style>
</head>

<body>
    <div class="container mt-5">
        <h2 class="text-center text-white mb-4">Login</h2>
        <form method="POST">
            <div class="mb-3">
                <label for="login_input" class="form-label text-white"><i class="fas fa-user"></i> Username or Email</label>
                <input type="text" class="form-control" id="login_input" name="login_input" autocomplete="off" required>
            </div>
            <div class="mb-3">
                <label for="password" class="form-label text-white"><i class="fas fa-lock"></i> Password</label>
                <input type="password" class="form-control" id="password" name="password" required>
            </div>
            <button type="submit" class="btn btn-primary w-100">Login</button>
        </form>

        <div class="mt-3 text-center">
            <a href="forgot_password.php" class="forgot-password">Forgot your password?</a>
        </div>

        <div class="mt-4 text-center">
            <p class="text-white">Don't have an account?</p>
            <a href="register.php" class="btn btn-secondary w-100">Register Here</a>
        </div>
    </div>

    <!-- Modal for displaying messages -->
    <div class="modal fade" id="messageModal" tabindex="-1" aria-labelledby="messageModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="messageModalLabel">
                        <?php if ($redirectUrl): ?>
                            <i class="fas fa-check-circle text-success"></i> Welcome
                        <?php else: ?>
                            <i class="fas fa-exclamation-circle text-danger"></i> Error
                        <?php endif; ?>
                    </h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <?php if ($showModal): ?>
                        <?php if ($redirectUrl): ?>
                            <p><?php echo "Welcome, " . htmlspecialchars($fullName) . "! You have logged in successfully. We're glad to have you back. Let's get started!"; ?></p>
                        <?php else: ?>
                            <p><?php echo htmlspecialchars($errorMessage); ?></p>
                        <?php endif; ?>
                    <?php endif; ?>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            <?php if ($showModal): ?>
                $('#messageModal').modal('show').on('hidden.bs.modal', function () {
                    // Redirect after the modal is closed if there is a redirect URL
                    if ("<?php echo $redirectUrl; ?>") {
                        window.location.href = "<?php echo $redirectUrl; ?>";
                    }
                });
            <?php endif; ?>
        });
    </script>
</body>

</html>