<?php
session_start();

// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include necessary files
include('includes/dbcon.php');   // For database connection

// Check if the user is logged in
if (isset($_SESSION['user_id'])) {
    // Get user ID from session
    $user_id = (int)$_SESSION['user_id'];

    // Log the logout action
    $action = 'User Logout';
    $description = 'User has logged out successfully.';
    $ip_address = $_SERVER['REMOTE_ADDR'] ?? 'Unknown';
    $user_agent = $_SERVER['HTTP_USER_AGENT'] ?? 'Unknown';

    $sql = "INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) 
            VALUES (?, ?, ?, ?, ?)";
    $stmt = $conn->prepare($sql);

    if (!$stmt) {
        die("Prepared statement error: " . $conn->error);
    }

    $stmt->bind_param("issss", $user_id, $action, $description, $ip_address, $user_agent);
    if (!$stmt->execute()) {
        die("Execution error: " . $stmt->error);
    }
}

// Destroy session
session_unset();
session_destroy();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Logout</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f5f5f5;
        }
    </style>
</head>
<body>

    <!-- Confirmation Modal -->
    <div class="modal fade" id="confirmLogoutModal" tabindex="-1" aria-labelledby="confirmLogoutModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="confirmLogoutModalLabel">Confirm Logout</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    Are you sure you want to log out?
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button type="button" class="btn btn-danger" id="confirmLogout">Logout</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Success Modal -->
    <div class="modal fade" id="successLogoutModal" tabindex="-1" aria-labelledby="successLogoutModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="successLogoutModalLabel">Logged Out</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    You have successfully logged out.
                </div>
                <div class="modal-footer">
                    <a href="login.php" class="btn btn-primary">Login Again</a>
                </div>
            </div>
        </div>
    </div>

    <script>
        $(document).ready(function() {
            // Show confirmation modal on logout button click
            $('#logoutButton').click(function() {
                $('#confirmLogoutModal').modal('show');
            });

            // Handle logout confirmation
            $('#confirmLogout').click(function() {
                // Redirect to logout.php to process logout
                window.location.href = 'logout.php';
            });

            // Show success modal after logout
            <?php if (!isset($_SESSION['user_id'])): ?>
                $(document).ready(function() {
                    $('#successLogoutModal').modal('show');
                });
            <?php endif; ?>
        });
    </script>
</body>
</html>