<?php
include 'includes/dbcon.php';
include 'activity_log.php'; // Include activity log script

// Fetch departments
$departments = [];
$dept_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$dept_result = $conn->query($dept_query);
if ($dept_result->num_rows > 0) {
    while ($row = $dept_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels
$year_levels = [];
$year_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}

$showModal = false; // Flag to control modal display
$modalType = ''; // Type of modal (success or error)
$modalMessage = ''; // Message to display in the modal
$userDetails = []; // Array to hold user details

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Retrieve form data and sanitize input
    $username = trim($_POST['username']);
    $email = trim($_POST['email']);
    $password = password_hash(trim($_POST['password']), PASSWORD_BCRYPT); // Encrypt password
    $first_name = trim($_POST['first_name']);
    $last_name = trim($_POST['last_name']);
    $register_number = trim($_POST['register_number']);
    $department_id = $_POST['department_id'] ?? null;
    $year_level_id = $_POST['year_level_id'] ?? null;
    $mobile_number = trim($_POST['mobile_number']);
    $role = $_POST['role'];
    $gender = $_POST['gender'];

    // Fetch avatar_id based on role and gender
    $avatar_query = "SELECT id FROM avatars WHERE role = ? AND gender = ?";
    $stmt = $conn->prepare($avatar_query);
    $stmt->bind_param("ss", $role, $gender);
    $stmt->execute();
    $avatar_result = $stmt->get_result();
    $avatar_id = $avatar_result->num_rows > 0 ? $avatar_result->fetch_assoc()['id'] : null;

    // Initialize error array
    $errors = [];

    // Check if the email, username, mobile number, and register number already exist
    $check_query = "SELECT id, email, username, mobile_number, register_number FROM users WHERE email = ? OR username = ? OR mobile_number = ? OR register_number = ?";
    $stmt = $conn->prepare($check_query);
    $stmt->bind_param("ssss", $email, $username, $mobile_number, $register_number);
    $stmt->execute();
    $check_result = $stmt->get_result();

    while ($row = $check_result->fetch_assoc()) {
        if ($row['email'] === $email) {
            $errors[] = "<i class='fas fa-exclamation-circle text-danger'></i> This email is already registered!";
            logActivity($conn, null, 'Registration Error', "Email already exists: $email");
        }
        if ($row['username'] === $username) {
            $errors[] = "<i class='fas fa-exclamation-circle text-danger'></i> This username is already taken!";
            logActivity($conn, null, 'Registration Error', "Username already exists: $username");
        }
        if ($row['mobile_number'] === $mobile_number) {
            $errors[] = "<i class='fas fa-exclamation-circle text-danger'></i> This mobile number is already registered!";
            logActivity($conn, null, 'Registration Error', "Mobile number already exists: $mobile_number");
        }
        if ($row['register_number'] === $register_number) {
            $errors[] = "<i class='fas fa-exclamation-circle text-danger'></i> This register number is already registered!";
            logActivity($conn, null, 'Registration Error', "Register number already exists: $register_number");
        }
    }

    // If there are no errors, proceed to insert the new user
    if (empty($errors)) {
        // Insert new user into the database
        $sql = "INSERT INTO users 
                (username, email, password, role, approval_status, first_name, last_name, register_number, department_id, year_level_id, mobile_number, avatar_id, gender) 
                VALUES (?, ?, ?, ?, 'pending', ?, ?, ?, ?, ?, ?, ?, ?)";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ssssssssssss", $username, $email, $password, $role, $first_name, $last_name, $register_number, $department_id, $year_level_id, $mobile_number, $avatar_id, $gender);

        if ($stmt->execute()) {
            // Log the account creation with user details
            $newUserId = $stmt->insert_id; // Get the newly created user ID

            // Fetch department name
            $dept_query = "SELECT department_name FROM departments WHERE id = ?";
            $dept_stmt = $conn->prepare($dept_query);
            $dept_stmt->bind_param("i", $department_id);
            $dept_stmt->execute();
            $dept_result = $dept_stmt->get_result();
            $department_name = $dept_result->num_rows > 0 ? $dept_result->fetch_assoc()['department_name'] : 'N/A';

            // Fetch year level
            $year_query = "SELECT year_level FROM year_levels WHERE id = ?";
            $year_stmt = $conn->prepare($year_query);
            $year_stmt->bind_param("i", $year_level_id);
            $year_stmt->execute();
            $year_result = $year_stmt->get_result();
            $year_level_name = $year_result->num_rows > 0 ? $year_result->fetch_assoc()['year_level'] : 'N/A';

            $description = "New user registered: First Name: $first_name, Last Name: $last_name, Username: $username, Email: $email, Mobile Number: $mobile_number, Register Number: $register_number, Gender: $gender, Department name: $department_name, Year Level: $year_level_name.";
            logActivity($conn, $newUserId, 'Account Created by New User', $description);


            // Prepare user details for modal with icons
            $userDetails = [
                '<i class="fas fa-user"></i> First Name' => $first_name,
                '<i class="fas fa-user"></i> Last Name' => $last_name,
                '<i class="fas fa-user-circle"></i> Username' => $username,
                '<i class="fas fa-envelope"></i> Email' => $email,
                '<i class="fas fa-phone"></i> Mobile Number' => $mobile_number,
                '<i class="fas fa-id-card"></i> Register Number' => $register_number,
                '<i class="fas fa-venus-mars"></i> Gender' => $gender,
                '<i class="fas fa-building"></i> Department' => $department_name, // Added department name
                '<i class="fas fa-graduation-cap"></i> Year Level' => $year_level_name // Added year level
            ];

            // Set success message for modal
            $modalType = 'success';
            $modalMessage = "Registration successful! Your account approval status is in pending. Your details will be verified and approved by the respective faculty or by the admin within 24 hours.";
            $showModal = true;
        } else {
            // Set error message for modal
            $modalType = 'error';
            $modalMessage = "Something went wrong. Please try again.";
            $showModal = true;
        }
    } else {
        // Set error message for modal
        $modalType = 'error';
        $modalMessage = implode("<br>", $errors);
        $showModal = true;
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Register</title>
    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">

    <style>
        body {
            background-color: #f5f5f5;
        }
        .container {
            background-color: #a777e3;
            padding: 30px;
            border-radius: 8px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .form-label i {
            margin-right: 10px;
        }
        .btn-primary {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        .btn-primary:hover {
            background-color: #5b79e0;
            border-color: #5b79e0;
        }
        .btn-secondary {
            background-color: #f39c12;
            border-color: #f39c12;
            color: #fff;
        }

        .btn-secondary:hover {
            background-color: #e67e22;
            border-color: #e67e22;
        }
    </style>
</head>
<body>
<div class="container mt-5">
    <h2 class="text-center text-white mb-4">Register</h2>
    <form method="POST">
        <div class="mb-3">
            <label for="username" class="form-label text-white"><i class="fas fa-user"></i> Username</label>
            <input type="text" class="form-control" id="username" name="username" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="email" class="form-label text-white"><i class="fas fa-envelope"></i> Email</label>
            <input type="email" class="form-control" id="email" name="email" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="password" class="form-label text-white"><i class="fas fa-lock"></i> Password</label>
            <input type="password" class="form-control" id="password" name="password" required>
        </div>
        <div class="mb-3">
            <label for="first_name" class="form-label text-white"><i class="fas fa-user-circle"></i> First Name</label>
            <input type="text" class="form-control" id="first_name" name="first_name" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="last_name" class="form-label text-white"><i class="fas fa-user-circle"></i> Last Name</label>
            <input type="text" class="form-control" id="last_name" name="last_name" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="register_number" class="form-label text-white"><i class="fas fa-id-card"></i> Register Number</label>
            <input type="text" class="form-control" id="register_number" name="register_number" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="mobile_number" class="form-label text-white"><i class="fas fa-phone"></i> Mobile Number</label>
            <input type="text" class="form-control" id="mobile_number" name="mobile_number" autocomplete="off" required>
        </div>
        <div class="mb-3">
            <label for="department_id" class="form-label text-white"><i class="fas fa-building"></i> Department</label>
            <select class="form-select" id="department_id" name="department_id" required>
                <?php foreach ($departments as $dept): ?>
                    <option value="<?= $dept['id']; ?>"><?= $dept['department_name']; ?></option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="mb-3">
            <label for="year_level_id" class="form-label text-white"><i class="fas fa-graduation-cap"></i> Year Level</label>
            <select class="form-select" id="year_level_id" name="year_level_id" required>
                <?php foreach ($year_levels as $year): ?>
                    <option value="<?= $year['id']; ?>"><?= $year['year_level']; ?></option>
                <?php endforeach; ?>
            </select>
        </div>
        <div class="mb-3">
            <label for="gender" class="form-label text-white"><i class="fas fa-venus-mars"></i> Gender</label>
            <select class="form-select" id="gender" name="gender" required>
                <option value="male">Male</option>
                <option value="female">Female</option>
                <option value="other">Other</option>
            </select>
        </div>
        <div class="mb-3">
            <label for="role" class="form-label text-white"><i class="fas fa-user-tag"></i> Role</label>
            <select class="form-select" id="role" name="role" required>
                <option value="faculty">Faculty</option>
                <option value="student">Student</option>
                <option value="admin">Admin</option>
            </select>
        </div>
        <button type="submit" class="btn btn-primary w-100">Register</button>
    </form>
    <div class="mt-4 text-center">
            <p class="text-white">Already have an account?</p>
            <a href="login.php" class="btn btn-secondary w-100">Login Here</a>
    </div>
</div>

<!-- Modal for Success/Error Messages -->
<div class="modal fade" id="messageModal" tabindex="-1" aria-labelledby="messageModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title" id="messageModalLabel">
                    <?php if ($modalType === 'success'): ?>
                        <i class="fas fa-check-circle text-success"></i> Success
                    <?php else: ?>
                        <i class="fas fa-exclamation-triangle text-danger"></i> Error
                    <?php endif; ?>
                </h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <?php if ($modalType === 'success'): ?>
                    <i class="fas fa-thumbs-up text-success"></i> <?= $modalMessage; ?>
                    <br>
                    <h6>User Details:</h6>
                    <ul style="list-style-type: none; padding-left: 0;">
                        <?php foreach ($userDetails as $key => $value): ?>
                            <li><?= $key; ?>: <strong><?= $value; ?></strong></li>
                        <?php endforeach; ?>
                    </ul>
                <?php else: ?>
                    <?= $modalMessage; ?> <!-- This will now include icons for each error -->
                <?php endif; ?>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">
                    <i class="fas fa-times"></i> Close
                </button>
                <?php if ($modalType === 'success'): ?>
                    <a href="login.php" class="btn btn-primary">
                        <i class="fas fa-sign-in-alt"></i> Login
                    </a>
                <?php endif; ?>
            </div>
        </div>
    </div>
</div>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
<script>
    // Show the modal if there is a message to display
    <?php if ($showModal): ?>
        var myModal = new bootstrap.Modal(document.getElementById('messageModal'), {
            keyboard: false
        });
        myModal.show();
    <?php endif; ?>
</script>
</body>
</html>