<?php
// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Database connection
require 'includes/dbcon.php'; // Include your database connection file

// Initialize message variable
$message = '';
$showModal = false;
$showLoginButton = false; // Variable to control the display of the login button

// Check if the token is provided
if (isset($_GET['token'])) {
    $token = $_GET['token'];

    // Validate the token
    $stmt = $conn->prepare("SELECT user_id FROM password_resets WHERE reset_token = ? AND token_expiry > NOW()");
    $stmt->bind_param("s", $token);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        // Token is valid, proceed to reset password
        if ($_SERVER['REQUEST_METHOD'] == 'POST') {
            $newPassword = $_POST['new_password'];
            $confirmPassword = $_POST['confirm_password'];

            // Validate password
            if (strlen($newPassword) < 6) {
                $message = "Password must be at least 6 characters long.";
                $showModal = true;
            } elseif ($newPassword !== $confirmPassword) {
                $message = "Passwords do not match.";
                $showModal = true;
            } else {
                // Hash the new password
                $hashedPassword = password_hash($newPassword, PASSWORD_DEFAULT);

                // Get user ID from the token
                $user = $result->fetch_assoc();
                $userId = $user['user_id'];

                // Update the user's password in the users table
                $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
                $stmt->bind_param("si", $hashedPassword, $userId);
                $stmt->execute();

                // Log the password reset activity
                logActivity($conn, $userId, "Password Reset", "User has reset their password.");

                // Delete the used token from the password_resets table
                $stmt = $conn->prepare("DELETE FROM password_resets WHERE reset_token = ?");
                $stmt->bind_param("s", $token);
                $stmt->execute();

                $message = "Your password has been reset successfully. You can now log in with your new password.";
                $showModal = true;
                $showLoginButton = true; // Show the login button
            }
        }
    } else {
        $message = "Invalid or expired token.";
        $showModal = true;
    }
} else {
    $message = "No token provided.";
    $showModal = true;
}

// Function to log activity
function logActivity($conn, $userId, $action, $description) {
    $ipAddress = $_SERVER['REMOTE_ADDR']; // Get the user's IP address
    $userAgent = $_SERVER['HTTP_USER_AGENT']; // Get the user's browser user agent

    $stmt = $conn->prepare("INSERT INTO activity_logs (user_id, action, description, ip_address, user_agent) VALUES (?, ?, ?, ?, ?)");
    $stmt->bind_param("issss", $userId, $action, $description, $ipAddress, $userAgent);
    $stmt->execute();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reset Password</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f7fc;
        }
        .card {
            border-radius: 10px;
        }
        .card-header {
            background-color: #a777e3;
            color: white;
        }
        .card-body {
            background-color: #ffffff;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .btn-custom {
            background-color: #6e8efb;
            color: white;
            font-size: 16px;
        }
        .btn-custom:hover {
            background-color: #0056b3;
        }
    </style>
</head>
<body>
    <div class="container mt-5">
        <div class="row justify-content-center">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-header text-center">
                        <h3><i class="fas fa-key"></i> Reset Password</h3>
                    </div>
                    <div class="card-body">
                        <form action="" method="POST">
                            <div class="form-group">
                                <label for="new_password"><i class="fas fa-lock"></i> New Password:</label>
                                <input type="password" class="form-control" id="new_password" name="new_password" required>
                            </div>
                            <div class="form-group mt-3">
                                <label for="confirm_password"><i class="fas fa-lock"></i> Confirm Password:</label>
                                <input type="password" class="form-control" id="confirm_password" name="confirm_password" required>
                            </div>
                            <div class="text-center mt-3">
                                <button type="submit" class="btn btn-custom"><i class="fas fa-paper-plane"></i> Reset Password</button>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal for displaying messages -->
    <div class="modal fade" id="messageModal" tabindex="-1" aria-labelledby="messageModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="messageModalLabel">Message</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body" id="modalMessage">
                    <?php
                    if ($showModal) {
                        echo $message;
                    }
                    ?>
                </div>
                <div class="modal-footer">
                    <?php if ($showLoginButton): ?>
                        <a href="login.php" class="btn btn-custom"><i class="fas fa-sign-in-alt"></i> Login</a>
                    <?php endif; ?>
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            <?php if ($showModal) { ?>
                $('#messageModal').modal('show');
            <?php } ?>
        });
    </script>
</body>
</html>