<?php
session_start();
include '../includes/dbcon.php'; // Include your database connection file

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php"); // Redirect to login if not logged in
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

$user_id = $_SESSION['user_id'];

// Get the lesson ID from the URL
if (isset($_GET['lesson_id'])) {
    $lesson_id = intval($_GET['lesson_id']); // Ensure it's an integer

    // Check if the lesson already exists in the backpack
    $checkQuery = "SELECT * FROM backpack WHERE student_id = ? AND lesson_id = ?";
    $checkStmt = $conn->prepare($checkQuery);
    $checkStmt->bind_param("ii", $user_id, $lesson_id);
    $checkStmt->execute();
    $checkResult = $checkStmt->get_result();

    if ($checkResult->num_rows > 0) {
        // Lesson already exists in the backpack
        header("Location: my_lessons.php?message=This lesson is already in your backpack.");
        exit();
    }

    // Insert into backpack table
    $query = "INSERT INTO backpack (student_id, lesson_id) VALUES (?, ?)";
    $stmt = $conn->prepare($query);

    if (!$stmt) {
        die("Database query preparation failed: " . $conn->error);
    }

    $stmt->bind_param("ii", $user_id, $lesson_id);
    if ($stmt->execute()) {
        // Redirect back to my lessons with a success message
        header("Location: my_lessons.php?message=Lesson added to backpack successfully.");
    } else {
        die("Error adding lesson to backpack: " . $stmt->error);
    }
} else {
    die("No lesson ID specified.");
}

$checkStmt->close();
$stmt->close();
$conn->close();
?>