<?php
session_start();
// Check if the user is logged in and has the role of 'student'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch assignments for the logged-in student along with grades
$query = "
    SELECT a.*, c.class_name, d.department_name, yl.year_level, g.grade, g.feedback, s.id AS submission_id 
    FROM assignments a 
    LEFT JOIN classes c ON a.class_id = c.id 
    LEFT JOIN departments d ON c.department_id = d.id 
    LEFT JOIN year_levels yl ON c.year_level_id = yl.id 
    LEFT JOIN student_classes sc ON c.id = sc.class_id 
    LEFT JOIN submissions s ON a.id = s.assignment_id AND s.student_id = ? 
    LEFT JOIN grades g ON s.id = g.submission_id 
    WHERE sc.student_id = ? 
    ORDER BY a.due_date DESC
";

$stmt = $conn->prepare($query);
$stmt->bind_param("ii", $_SESSION['user_id'], $_SESSION['user_id']);
$stmt->execute();
$results = $stmt->get_result();

if (!$results) {
    die("Query failed: " . $conn->error);
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Assignments</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 70px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 75px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .overdue {
            background-color: #f8d7da; /* Light red background for overdue assignments */
            border-color: #f5c6cb; /* Red border */
        }
        .due-today {
            background-color: #fff3cd; /* Light yellow background for assignments due today */
            border-color: #ffeeba; /* Yellow border */
        }
        .due-tomorrow {
            background-color: #fff3cd; /* Light yellow background for assignments due tomorrow */
            border-color: #ffeeba; /* Yellow border */
        }
        .due-soon {
            background-color: #d4edda; /* Light green background for assignments due soon */
            border-color: #c3e6cb; /* Green border */
        }
        .modal-header {
            background-color: #007bff; /* Bootstrap primary color */
            color: white;
        }

        .card {
            border: 1px solid #007bff; /* Border color matching the header */
        }

        .progress {
            height: 20px; /* Adjust height of the progress bar */
        }
        @media (max-width: 576px) {
            .modal-dialog {
                max-width: 100%; /* Full width on small screens */
                margin-left: 250px;

            }
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/student_header.php'; ?>
    <?php include '../includes/student_sidebar.php'; ?>
    <div class="container">
        <h1>Your Assignments</h1>

        <h2>All Assignments</h2>
        <table class="table">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Title</th>
                    <th>Description</th>
                    <th>Class</th>
                    <th>Total Marks</th>
                    <th>Due Date</th>
                    <th>Actions</th>
                </tr>
            </thead>
            <tbody>
            <?php if ($results->num_rows > 0): ?>
                <?php $serialNumber = 1; // Initialize serial number ?>
                <?php $currentDate = date('Y-m-d'); // Get current date ?>
                <?php while ($assignment = $results->fetch_assoc()): ?>
                    <?php
                    $dueDate = $assignment['due_date'];
                    $daysUntilDue = (strtotime($dueDate) - strtotime($currentDate)) / (60 * 60 * 24); // Calculate days until due
                    $isOverdue = $daysUntilDue < 0; // Check if the assignment is overdue
                    $isDueToday = $daysUntilDue == 1; // Check if due today
                    $isDueTomorrow = $daysUntilDue == 2; // Check if due tomorrow
                    ?>
                    <tr class="<?= $isOverdue ? 'overdue' : ($isDueToday ? 'due-today' : ($isDueTomorrow ? 'due-tomorrow' : ($daysUntilDue >= 3 ? 'due-soon' : ''))); ?>">
                        <td><?= $serialNumber++; ?></td> <!-- Display serial number -->
                        <td><?= htmlspecialchars($assignment['title']); ?></td>
                        <td><?= htmlspecialchars($assignment['description']); ?></td>
                        <td><?= htmlspecialchars($assignment['class_name'] . ' - ' . $assignment['year_level'] . ' (' . $assignment['department_name'] . ')'); ?></td>
                        <td><?= htmlspecialchars($assignment['total_marks']); ?></td>
                        <td><?= htmlspecialchars($assignment['due_date']); ?></td>
                        <td>
                            <button class="btn btn-info" data-bs-toggle="modal" data-bs-target="#viewModal<?= $assignment['id']; ?>">
                                <i class="fas fa-eye"></i> View Details
                            </button>
                            <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#submitModal<?= $assignment['id']; ?>">
                                <i class="fas fa-upload"></i> Submit
                            </button>
                            <button class="btn btn-secondary" data-bs-toggle="modal" data-bs-target="#gradeModal<?= $assignment['id']; ?>">
                                <i class="fas fa-star"></i> View Grade
                            </button>
                        </td>
                    </tr>

                    <!-- View Modal -->
                    <div class="modal fade" id="viewModal<?= $assignment['id']; ?>" tabindex="-1" aria-labelledby="viewModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-scrollable"> <!-- Use scrollable for long content -->
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="viewModalLabel">Assignment Details <i class="fas fa-book-open"></i></h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <div class="card">
                                        <div class="card-body">
                                            <h5 class="card-title"><?= htmlspecialchars($assignment['title']); ?></h5>
                                            <p class="card-text"><strong>Description:</strong> <?= htmlspecialchars($assignment['description']); ?></p>
                                            <p class="card-text"><strong>Total Marks:</strong> <?= htmlspecialchars($assignment['total_marks']); ?></p>
                                            <p class="card-text"><strong>Due Date:</strong> <?= htmlspecialchars($assignment['due_date']); ?></p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Submit Modal -->
                    <div class="modal fade" id="submitModal<?= $assignment['id']; ?>" tabindex="-1" aria-labelledby="submitModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-scrollable"> <!-- Use scrollable for long content -->
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="submitModalLabel">Submit Assignment <i class="fas fa-upload"></i></h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <div class="card">
                                        <div class="card-body">
                                            <?php if ($isOverdue): ?>
                                                <div class="alert alert-danger" role="alert">
                                                    Sorry, the due date has exceeded. You are not able to submit the assignment.
                                                </div>
                                            <?php elseif (isset($assignment['submission_id'])): ?>
                                                <div class="alert alert-danger" role="alert">
                                                    You have already submitted this assignment.
                                                </div>
                                            <?php else: ?>
                                                <form action="submit_assignment.php" method="post" enctype="multipart/form-data">
                                                    <input type="hidden" name="assignment_id" value="<?= $assignment['id']; ?>">
                                                    <div class="mb-3">
                                                        <label for="file" class="form-label">Upload Your Submission:</label>
                                                        <input type="file" name="file" id="file" class="form-control" required>
                                                        <p class="text-muted">Allowed file types: <strong>image, video, pdf, jpg, png, gif, bmp, mp4, avi, mov, mkv, mp3, wav, flac, doc, docx, ppt, pptx</strong></p>
                                                        <p class="text-muted">Allowed maximum size: <strong>10 Mb</strong></p>
                                                    </div>
                                                    <button type="submit" class="btn btn-primary">Submit Assignment</button>
                                                </form>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <!-- Grade Modal -->
                    <div class="modal fade" id="gradeModal<?= $assignment['id']; ?>" tabindex="-1" aria-labelledby="gradeModalLabel" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-scrollable"> <!-- Use scrollable for long content -->
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="gradeModalLabel">Grade for Assignment: <?= htmlspecialchars($assignment['title']); ?> <i class="fas fa-star"></i></h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <div class="card">
                                        <div class="card-body">
                                            <?php if (isset($assignment['grade'])): ?>
                                                <h5 class="card-title">Your Grade: <?= htmlspecialchars($assignment['grade']); ?> / <?= htmlspecialchars($assignment['total_marks']); ?></h5>
                                                <div class="progress">
                                                    <div class="progress-bar" role="progressbar" style="width: <?= ($assignment['grade'] / $assignment['total_marks']) * 100; ?>%;" aria-valuenow="<?= $assignment['grade']; ?>" aria-valuemin="0" aria-valuemax="<?= $assignment['total_marks']; ?>">
                                                        <?= round(($assignment['grade'] / $assignment['total_marks']) * 100); ?>%
                                                    </div>
                                                </div>
                                                <p class="card-text"><strong>Feedback:</strong> <?= htmlspecialchars($assignment['feedback']); ?></p>
                                            <?php else: ?>
                                                <p class="text-danger">You have not submitted this assignment yet or it has not been graded.</p>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                <?php endwhile; ?>
            <?php else: ?>
                <tr>
                    <td colspan="7" class="text-center">No assignments available.</td>
                </tr>
            <?php endif; ?>
            </tbody>
        </table>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
// Close the database connection
$conn->close();
?>