<?php
session_start();
// Check if the user is logged in and has the role of 'student'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Fetch departments and year levels
$departments = [];
$year_levels = [];

// Fetch departments
$dept_query = "SELECT id, department_name FROM departments ORDER BY department_name";
$dept_result = $conn->query($dept_query);
if ($dept_result->num_rows > 0) {
    while ($row = $dept_result->fetch_assoc()) {
        $departments[] = $row;
    }
}

// Fetch year levels
$year_query = "SELECT id, year_level FROM year_levels ORDER BY year_level";
$year_result = $conn->query($year_query);
if ($year_result->num_rows > 0) {
    while ($row = $year_result->fetch_assoc()) {
        $year_levels[] = $row;
    }
}

// Get the student ID from the session
$student_id = $_SESSION['user_id'];

// Fetch student's department and year level
$student_query = "SELECT department_id, year_level_id FROM users WHERE id = ?";
$student_stmt = $conn->prepare($student_query);
$student_stmt->bind_param("i", $student_id);
$student_stmt->execute();
$student_result = $student_stmt->get_result();
$student = $student_result->fetch_assoc();

$student_department_id = $student['department_id'];
$student_year_level_id = $student['year_level_id'];

// Pagination settings
$records_per_page_options = ['All', 10, 25, 50, 100, 150, 200];
$records_per_page = isset($_GET['records_per_page']) ? $_GET['records_per_page'] : 10; // Default to 10
$current_page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Default to page 1

// Fetch events based on student's department and year level
$filter_query = "SELECT cc.*, d.department_name, yl.year_level 
                 FROM class_calendar cc
                 JOIN departments d ON cc.department_id = d.id
                 LEFT JOIN year_levels yl ON cc.year_level_id = yl.id
                 WHERE cc.department_id = ? AND cc.year_level_id = ?"; // Filter by student's department and year level

$filter_stmt = $conn->prepare($filter_query);
$filter_stmt->bind_param("ii", $student_department_id, $student_year_level_id);
$filter_stmt->execute();
$events = $filter_stmt->get_result();

// Get total records for pagination
$total_records = $events->num_rows;
$total_pages = ceil($total_records / ($records_per_page === 'All' ? $total_records : $records_per_page));

// Calculate offset
$offset = ($current_page - 1) * ($records_per_page === 'All' ? $total_records : $records_per_page);

// Fetch events with pagination
$query = $filter_query . " LIMIT ?, ?";
$paginated_stmt = $conn->prepare($query);
$paginated_stmt->bind_param("iiii", $student_department_id, $student_year_level_id, $offset, $records_per_page);
$paginated_stmt->execute();
$events = $paginated_stmt->get_result();
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Calendar of Events</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }

        .card-header {
            background-color: #6e8efb;
            color: white;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/student_header.php'; ?>
    <?php include '../includes/student_sidebar.php'; ?>

    <div class="container">
        <h2>Calendar of Events</h2>

        <!-- Messages -->
        <div class="messages">
            <?php if (isset($success_message)): ?>
                <div class="alert alert-success" role="alert">
                    <?= htmlspecialchars($success_message); ?>
                </div>
            <?php endif; ?>

            <?php if (isset($error_message)): ?>
                <div class="alert alert-danger" role="alert">
                    <?= htmlspecialchars($error_message); ?>
                </div>
            <?php endif; ?>
        </div>
        
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>S.No.</th>
                    <th>Department</th>
                    <th>Year Level</th>
                    <th>Event Title</th>
                    <th>Event Description</th>
                    <th>Event Date</th>
                    <th>Created At</th>
                    <th>Updated At</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($events->num_rows > 0): ?>
                    <?php $serialNo = 1; ?>
                    <?php while ($event = $events->fetch_assoc()): ?>
                        <tr>
                            <td><?= $serialNo++ ?></td>
                            <td><?= htmlspecialchars($event['department_name']) ?></td>
                            <td><?= htmlspecialchars($event['year_level']) ?></td>
                            <td><?= htmlspecialchars($event['event_title']) ?></td>
                            <td><?= htmlspecialchars($event['event_description']) ?></td>
                            <td><?= htmlspecialchars($event['event_date']) ?></td>
                            <td><?= htmlspecialchars($event['created_at']) ?></td>
                            <td><?= htmlspecialchars($event['updated_at']) ?></td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="8">No events found for your department and year level.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>

        <!-- Pagination controls -->
        <nav aria-label="Page navigation">
            <ul class="pagination">
                <?php if ($current_page > 1): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page - 1; ?>&records_per_page=<?php echo $records_per_page; ?>">Previous</a>
                    </li>
                <?php endif; ?>

                <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                    <li class="page-item <?php echo $i == $current_page ? 'active' : ''; ?>">
                        <a class="page-link" href="?page=<?php echo $i; ?>&records_per_page=<?php echo $records_per_page; ?>"><?php echo $i; ?></a>
                    </li>
                <?php endfor; ?>

                <?php if ($current_page < $total_pages): ?>
                    <li class="page-item">
                        <a class="page-link" href="?page=<?php echo $current_page + 1; ?>&records_per_page=<?php echo $records_per_page; ?>">Next</a>
                    </li>
                <?php endif; ?>
            </ul>
        </nav>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>