<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit();
}

include '../includes/dbcon.php';

// Fetch student details using 'user_id' stored in the session
$user_id = $_SESSION['user_id'];
$sql = "SELECT * FROM users WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $user_id);
$stmt->execute();
$student = $stmt->get_result()->fetch_assoc();

if (!$student || $student['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Student Dashboard</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }

        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 75px;
            transition: width 0.3s ease;
        }

        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }

        .sidebar a:hover {
            background-color: #6e8efb;
        }

        .dashboard-content {
            margin-left: 250px;
            padding: 95px 30px;
            transition: margin-left 0.3s ease;
        }

        .card-header {
            background-color: #a777e3;
            color: white;
        }

        .btn-primary {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }

        .btn-primary:hover {
            background-color: #f39c12;
            border-color: #f39c12;
        }

        @media (max-width: 1200px) {
            .sidebar {
                width: 200px;
            }

            .dashboard-content {
                margin-left: 200px;
                padding-top: 95px;
            }
        }

        @media (max-width: 992px) {
            .sidebar {
                width: 180px;
            }

            .dashboard-content {
                margin-left: 180px;
                padding-top: 95px;
            }
        }

        @media (max-width: 768px) {
            .sidebar {
                width: 0;
                display: none;
            }

            .dashboard-content {
                margin-left: 0;
                padding-top: 95px;
            }

            .mobile-sidebar {
                display: block;
                padding: 10px 0;
            }

            .mobile-sidebar a {
                display: block;
                padding: 10px;
                margin: 5px 0;
                background-color: #f39c12;
                color: white;
                text-align: center;
                text-decoration: none;
                border-radius: 5px;
            }

            .mobile-sidebar a:hover {
                background-color: #6e8efb;
            }

            .sidebar-toggle {
                display: block;
                background-color: #f39c12;
                color: white;
                border: none;
                padding: 10px;
                font-size: 18px;
                position: fixed;
                top: 10px;
                left: 10px;
                z-index: 1000;
            }

            .sidebar-open .sidebar {
                width: 250px;
                display: block;
            }

            .sidebar-open .dashboard-content {
                margin-left: 250px;
            }
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>

<body>
    <!-- Include Header -->
    <?php include('../includes/student_header.php'); ?>

    <!-- Sidebar Toggle Button -->
    <button class="sidebar-toggle d-md-none" onclick="toggleSidebar()">☰</button>

    <!-- Desktop Sidebar -->
    <div id="sidebar" class="sidebar text-white position-fixed vh-100 d-none d-md-block">
        <h4 class="text-center py-3">Student Panel</h4>
        <nav class="d-flex flex-column">
            <a href="dashboard.php"><i class="fas fa-tachometer-alt"></i> Dashboard</a>
            <a href="my_classes.php"><i class="fas fa-school"></i> My Classes</a>
            <a href="my_lessons.php"><i class="fas fa-book"></i> My Lessons</a>
            <a href="backpack.php"><i class="fas fa-folder"></i> Backpack</a>
            <a href="view_attendance.php"><i class="fas fa-chart-pie"></i> Attendance</a>
            <a href="downloadable_materials.php"><i class="fas fa-download"></i> Downloadable Materials</a>
            <a href="assignments.php"><i class="fas fa-tasks"></i> Assignments</a>
            <a href="view_quizzes.php"><i class="fas fa-question-circle"></i> Quizzes</a>
            <a href="calendar.php"><i class="fas fa-calendar-alt"></i> Calendar</a>
        </nav>
    </div>

    <!-- Dashboard Content -->
    <div class="dashboard-content">
        <div class="dashboard-header">
            <h1>Welcome to Student Dashboard</h1>
            <p class="welcome-message">Hello, <?php echo htmlspecialchars($student['first_name']) . ' ' . htmlspecialchars($student['last_name']); ?>! You're logged in as a Student.</p>
        </div>

        <!-- Mobile Sidebar -->
        <div class="mobile-sidebar d-md-none">
            <a href="dashboard.php"><i class="fas fa-tachometer-alt"></i> Dashboard</a>
            <a href="backpack.php"><i class="fas fa-folder"></i> Backpack</a>
            <a href="view_attendance.php"><i class="fas fa-chart-pie"></i> Attendance</a>
            <a href="downloadable_materials.php"><i class="fas fa-download"></i> Downloadable Materials</a>
            <a href="my_classes.php"><i class="fas fa-school"></i> My Classes</a>
            <a href="my_lessons.php"><i class="fas fa-book"></i> My Lessons</a>
            <a href="assignments.php"><i class="fas fa-tasks"></i> Assignments</a>
            <a href="view_quizzes.php"><i class="fas fa-question-circle"></i> Quizzes</a>
            <a href="calendar.php"><i class="fas fa-calendar-alt"></i> Calendar</a>
        </div>


        <!-- Example Dashboard Cards -->
        <div class="row">
            <!-- Backpack Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>My Backpack</h4>
                    </div>
                    <div class="card-body">
                        <p>View your saved lessons in your backpack.</p>
                        <a href="backpack.php" class="btn btn-primary btn-block"><i class="fas fa-folder"></i> Go to Backpack</a>
                    </div>
                </div>
            </div>
            <!-- My Subjects Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>My Lessons</h4>
                    </div>
                    <div class="card-body">
                        <p>View your Lessons based on your assigned classes.</p>
                        <a href="my_lessons.php" class="btn btn-primary btn-block"><i class="fas fa-book"></i> Go to Lessons</a>
                    </div>
                </div>
            </div>

            <!-- Assignments Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>My Assignments</h4>
                    </div>
                    <div class="card-body">
                        <p>View and submit assignments.</p>
                        <a href="assignments.php" class="btn btn-primary btn-block"><i class="fas fa-tasks"></i> Go to Assignments</a>
                    </div>
                </div>
            </div>

            <!-- Quizzes Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>My Quizzes</h4>
                    </div>
                    <div class="card-body">
                        <p>Take quizzes and view results.</p>
                        <a href="view_quizzes.php" class="btn btn-primary btn-block"><i class="fas fa-question-circle"></i> Go to Quizzes</a>
                    </div>
                </div>
            </div>
            <!-- Calendar of events Card -->
            <div class="col-md-4 mt-3">
                <div class="card">
                    <div class="card-header">
                        <h4>My Calendar</h4>
                    </div>
                    <div class="card-body">
                        <p>View your calender of events based on your department and year level.</p>
                        <a href="calendar.php" class="btn btn-primary btn-block"><i class="fas fa-calendar-alt"></i> Go to Calendar</a>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        // Toggle sidebar on mobile
        function toggleSidebar() {
            document.body.classList.toggle('sidebar-open');
        }
    </script>
</body>

</html>
