<?php
// Start output buffering at the beginning of the script
ob_start();
session_start();
include '../includes/dbcon.php'; // Include database connection

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    $_SESSION['error_message'] = "You must be logged in to download files.";
    header("Location: login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Function to get MIME type based on file extension
function getMimeType($filePath) {
    $extension = strtolower(pathinfo($filePath, PATHINFO_EXTENSION));
    switch ($extension) {
        case 'jpg':
        case 'jpeg':
            return 'image/jpeg';
        case 'png':
            return 'image/png';
        case 'gif':
            return 'image/gif';
        case 'bmp':
            return 'image/bmp';
        case 'pdf':
            return 'application/pdf';
        case 'mp4':
            return 'video/mp4';
        case 'avi':
            return 'video/x-msvideo';
        case 'mov':
            return 'video/quicktime';
        case 'mkv':
            return 'video/x-matroska';
        case 'mp3':
            return 'audio/mpeg';
        case 'wav':
            return 'audio/wav';
        case 'flac':
            return 'audio/flac';
        case 'doc':
            return 'application/msword';
        case 'docx':
            return 'application/vnd.openxmlformats-officedocument.wordprocessingml.document';
        case 'ppt':
            return 'application/vnd.ms-powerpoint';
        case 'pptx':
            return 'application/vnd.openxmlformats-officedocument.presentationml.presentation';
        default:
            return 'application/octet-stream'; // Fallback for unknown types
    }
}

// Check if the file ID is provided
if (isset($_GET['id']) && is_numeric($_GET['id'])) {
    $id = intval($_GET['id']);

    // Fetch the file information from the database
    $stmt = $conn->prepare("SELECT file_path FROM materials WHERE id = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $file = $result->fetch_assoc();
        $filePath = $file['file_path'];

        // Check if the file exists on the server
        if (file_exists($filePath)) {
            // Get the MIME type
            $fileType = getMimeType($filePath);

            // Clear output buffer
            ob_clean();

            // Set headers to initiate the download
            header('Content-Description: File Transfer');
            header('Content-Type: ' . $fileType);
            header('Content-Disposition: attachment; filename="' . basename($filePath) . '"');
            header('Expires: 0');
            header('Cache-Control: must-revalidate');
            header('Pragma: public');
            header('Content-Length: ' . filesize($filePath));
            flush(); // Flush system output buffer
            readfile($filePath); // Read the file and send it to the output buffer
            exit();
        } else {
            $_SESSION['error_message'] = "File does not exist on the server.";
        }
    } else {
        $_SESSION['error_message'] = "File not found in the database.";
    }

    $stmt->close();
} else {
    $_SESSION['error_message'] = "Invalid file ID.";
}

// Redirect back to the previous page with an error message
header("Location: downloadable_materials.php");
exit();
?>