<?php
session_start();
include '../includes/dbcon.php'; // Include database connection

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    echo json_encode(['error' => 'User  not logged in']);
    exit();
}

// Get the quiz ID from the request
$quiz_id = isset($_GET['quiz_id']) ? intval($_GET['quiz_id']) : 0;

// Check if quiz_id is valid
if ($quiz_id <= 0) {
    echo json_encode(['error' => 'Invalid quiz ID']);
    exit();
}

// Get the logged-in student ID
$student_id = $_SESSION['user_id'];

// Fetch the score for the specific quiz
$query = "
    SELECT score, total_questions, correct_answers, incorrect_answers 
    FROM quiz_results 
    WHERE student_id = ? AND quiz_id = ?
";

$stmt = $conn->prepare($query);
if (!$stmt) {
    echo json_encode(['error' => 'Database query preparation failed']);
    exit();
}

$stmt->bind_param("ii", $student_id, $quiz_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows > 0) {
    $row = $result->fetch_assoc();
    $response = [
        'score' => $row['score'],
        'total_questions' => $row['total_questions'],
        'correct_answers' => $row['correct_answers'],
        'incorrect_answers' => $row['incorrect_answers'],
        'percentage' => ($row['score'] / $row['total_questions']) * 100 // Calculate percentage
    ];
    echo json_encode($response);
} else {
    echo json_encode(['score' => null]); // No score available
}

$stmt->close();
$conn->close();
?>