<?php
include('../includes/dbcon.php');
include('../includes/session.php');

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

// Ensure the student is logged in
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');  // Redirect to login if not logged in
    exit();
}

// Get the quiz ID from the URL
$quiz_id = isset($_GET['quiz_id']) ? intval($_GET['quiz_id']) : 0;

// Check if quiz_id is valid
if ($quiz_id <= 0) {
    die("Invalid quiz ID.");
}

// Fetch the leaderboard results for the specific quiz along with the quiz title
$results_query = "
    SELECT q.title AS quiz_title, u.first_name, u.last_name, c.class_name, d.department_name, yl.year_level, 
           r.total_questions, r.correct_answers, r.incorrect_answers, r.score
    FROM quiz_results r
    JOIN users u ON r.student_id = u.id
    JOIN classes c ON r.class_id = c.id
    JOIN departments d ON c.department_id = d.id 
    JOIN year_levels yl ON c.year_level_id = yl.id 
    JOIN quizzes q ON r.quiz_id = q.id  -- Join to get the quiz title
    WHERE r.quiz_id = ?
    ORDER BY r.score DESC
";

$results_stmt = $conn->prepare($results_query);
if (!$results_stmt) {
    die("Query preparation failed: " . $conn->error);
}

$results_stmt->bind_param("i", $quiz_id);
$results_stmt->execute();
$results_result = $results_stmt->get_result();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>View Results - Leaderboard</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>

<!-- Header and Sidebar -->
<?php include '../includes/student_header.php'; ?>
<?php include '../includes/student_sidebar.php'; ?>

<div class="container mt-5">
    <?php if ($results_result->num_rows > 0): ?>
        <?php 
        // Fetch the first result to get the quiz title
        $first_result = $results_result->fetch_assoc();
        $quiz_title = htmlspecialchars($first_result['quiz_title']); // Get the quiz title
        ?>
        <h2>Leaderboard for Quiz: <?php echo $quiz_title; ?></h2>  <!-- Display the quiz title -->
        
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>Rank</th>
                    <th>Student Name</th>
                    <th>Class</th>
                    <th>Total Questions</th>
                    <th>Correct Answers</th>
                    <th>Incorrect Answers</th>
                    <th>Score</th>
                </tr>
            </thead>
            <tbody>
                <?php 
                $s_no = 1; // Initialize serial number
                // Display the first result
                echo '<tr>';
                echo '<td><b>' . $s_no . '</b></td>'; // Display rank as a number
                echo '<td>';
                if ($s_no == 1) {
                    echo '<img src="../assets/badges/1st-prize.png" alt="Gold Badge" style="width:30px;height:30px;vertical-align: middle;">'; // Gold Badge
                } elseif ($s_no == 2) {
                    echo '<img src="../assets/badges/2nd-place.png" alt="Silver Badge" style="width:30px;height:30px;vertical-align: middle;">'; // Silver Badge
                } elseif ($s_no == 3) {
                    echo '<img src="../assets/badges/3rd-place.png" alt="Bronze Badge" style="width:30px;height:30px;vertical-align: middle;">'; // Bronze Badge
                }
                echo htmlspecialchars($first_result['first_name'] . ' ' . $first_result['last_name']);
                echo '</td>';
                echo '<td>' . htmlspecialchars($first_result['class_name']) . " (" . htmlspecialchars($first_result['department_name']) . " - " . htmlspecialchars($first_result['year_level']) . ")" . '</td>';
                echo '<td>' . htmlspecialchars($first_result['total_questions']) . '</td>';
                echo '<td>' . htmlspecialchars($first_result['correct_answers']) . '</td>';
                echo '<td>' . htmlspecialchars($first_result['incorrect_answers']) . '</td>';
                echo '<td><b>' . htmlspecialchars($first_result['score']) . '</b></td>';
                echo '</tr>';

                // Continue displaying the rest of the results
                while ($results = $results_result->fetch_assoc()): 
                    $s_no++;
                ?>
                    <tr>
                        <td><?php echo $s_no; ?></td> <!-- Display rank as a number -->
                        <td>
                            <?php 
                            if ($s_no == 1) {
                                echo '<img src="../assets/badges/1st-prize.png" alt="Gold Badge" style="width:30px;height:30px;vertical-align: middle;">';
                            } elseif ($s_no == 2) {
                                echo '<img src="../assets/badges/2nd-place.png" alt="Silver Badge" style="width:30px;height:30px;vertical-align: middle;">';
                            } elseif ($s_no == 3) {
                                echo '<img src="../assets/badges/3rd-place.png" alt="Bronze Badge" style="width:30px;height:30px;vertical-align: middle;">';
                            }
                            echo htmlspecialchars($results['first_name'] . ' ' . $results['last_name']);
                            ?>
                        </td>
                        <td><?php echo htmlspecialchars($results['class_name']) . " (" . htmlspecialchars($results['department_name']) . " - " . htmlspecialchars($results['year_level']) . ")"; ?></td>
                        <td><?php echo htmlspecialchars($results['total_questions']); ?></td>
                        <td><?php echo htmlspecialchars($results['correct_answers']); ?></td>
                        <td><?php echo htmlspecialchars($results['incorrect_answers']); ?></td>
                        <td><?php echo htmlspecialchars($results['score']); ?></td>
                    </tr>
                <?php endwhile; ?>
            </tbody>
        </table>
    <?php else: ?>
        <p>No quiz results found for this quiz.</p>
    <?php endif; ?>
</div>

    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min .js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$results_stmt->close();
$conn->close();
?>