<?php
session_start();
include '../includes/dbcon.php'; // Include your database connection file

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php"); // Redirect to login if not logged in
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

$user_id = $_SESSION['user_id'];

// Fetch classes for the logged-in student
$query = "SELECT c.id, c.class_name, d.department_name, yl.year_level, c.description
          FROM student_classes sc
          JOIN classes c ON sc.class_id = c.id
          JOIN departments d ON c.department_id = d.id
          JOIN year_levels yl ON c.year_level_id = yl.id
          WHERE sc.student_id = ?";
$stmt = $conn->prepare($query);

if (!$stmt) {
    die("Database query preparation failed: " . $conn->error);
}

$stmt->bind_param("i", $user_id);
$stmt->execute();
$results = $stmt->get_result();

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Classes</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 75px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Include Header -->
    <?php include('../includes/student_header.php'); ?>
    <?php include('../includes/student_sidebar.php'); ?>

    <div class="container">
        <h1>My Classes</h1>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th>Class Name</th>
                    <th>Department</th>
                    <th>Year Level</th>
                    <th>Handled By</th>
                </tr>
            </thead>
            <tbody>
                <?php if ($results->num_rows > 0): ?>
                    <?php while ($row = $results->fetch_assoc()): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($row['class_name']); ?></td>
                            <td><?php echo htmlspecialchars($row['department_name']); ?></td>
                            <td><?php echo htmlspecialchars($row['year_level']); ?></td>
                            <td><?php echo htmlspecialchars($row['description']); ?></td>
                        </tr>
                    <?php endwhile; ?>
                <?php else: ?>
                    <tr>
                        <td colspan="4">No classes found.</td>
                    </tr>
                <?php endif; ?>
            </tbody>
        </table>
        <a href="dashboard.php" class="btn btn-primary mb-4">Back to Dashboard</a>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$stmt->close();
$conn->close();
?>