<?php
session_start();
// Check if the user is logged in and has the role of 'student'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Handle file upload
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['assignment_id'])) {
    $assignmentId = $_POST['assignment_id'];
    $studentId = $_SESSION['user_id']; // Get the logged-in student ID

    // Check if a file was uploaded
    if (isset($_FILES['file']) && $_FILES['file']['error'] == UPLOAD_ERR_OK) {
        $fileTmpPath = $_FILES['file']['tmp_name'];
        $fileName = $_FILES['file']['name'];
        $fileSize = $_FILES['file']['size'];
        $fileType = $_FILES['file']['type'];
        $fileNameCmps = explode(".", $fileName);
        $fileExtension = strtolower(end($fileNameCmps));

        // Define allowed file types and size limit (e.g., 10MB)
        $allowedfileExtensions = ['jpg', 'jpeg', 'png', 'gif', 'pdf', 'mp4', 'avi', 'mov', 'mkv', 'mp3', 'wav', 'flac', 'doc', 'docx', 'ppt', 'pptx'];
        $maxFileSize = 10 * 1024 * 1024; // 10MB

        // Validate file type and size
        if (in_array($fileExtension, $allowedfileExtensions) && $fileSize <= $maxFileSize) {
            // Set the upload directory
            $uploadFileDir = '../uploads/assignments/';
            $dest_path = $uploadFileDir . uniqid() . '_' . basename($fileName); // Rename file to avoid conflicts

            // Move the file to the upload directory
            if (move_uploaded_file($fileTmpPath, $dest_path)) {
                // Insert submission details into the database
                $stmt = $conn->prepare("INSERT INTO submissions (assignment_id, student_id, file_path, submitted_at) VALUES (?, ?, ?, NOW())");
                $stmt->bind_param("iis", $assignmentId, $studentId, $dest_path);

                if ($stmt->execute()) {
                    $_SESSION['success_message'] = "Assignment submitted successfully!";
                } else {
                    $_SESSION['error_message'] = "Database error: " . $stmt->error;
                }

                $stmt->close();
            } else {
                $_SESSION['error_message'] = "There was an error moving the uploaded file.";
            }
        } else {
            $_SESSION['error_message'] = "Invalid file type or file size exceeds the limit of 10 MB.";
        }
    } else {
        // Handle file upload errors
        $uploadError = $_FILES['file']['error'];
        $_SESSION['error_message'] = "No file uploaded or there was an upload error. Error code: " . $uploadError;
    }
}

// Redirect back to the assignments page
header("Location: assignments.php");
exit();
?>