<?php
session_start();
include '../includes/dbcon.php'; // Include your database connection file

// Check if the user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php"); // Redirect to login if not logged in
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

$user_id = $_SESSION['user_id'];

// Get the lesson ID from the URL
if (isset($_GET['id'])) {
    $lesson_id = intval($_GET['id']); // Ensure it's an integer

    // Fetch lesson details
    $query = "SELECT l.title, l.description, c.class_name, d.department_name, yl.year_level
              FROM lessons l
              JOIN classes c ON l.class_id = c.id
              JOIN departments d ON c.department_id = d.id
              JOIN year_levels yl ON c.year_level_id = yl.id
              WHERE l.id = ?";
    $stmt = $conn->prepare($query);

    if (!$stmt) {
        die("Database query preparation failed: " . $conn->error);
    }

    $stmt->bind_param("i", $lesson_id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows === 0) {
        die("No lesson found with the specified ID.");
    }

    $lesson = $result->fetch_assoc();
} else {
    die("No lesson ID specified.");
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>View Lesson</title>
    <link rel="icon" href="../assets/images/logo.ico" type="image/x-icon"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 75px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Include Header -->
    <?php include('../includes/student_header.php'); ?>
    <?php include('../includes/student_sidebar.php'); ?>

    <div class="container">
        <h1><?php echo htmlspecialchars($lesson['title']); ?></h1>
        <hr>
        <h3>Description:</h3>
        <div><?php echo $lesson['description']; ?></div> <!-- Output HTML description directly -->
        
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>

<?php
$stmt-> close();
$conn->close();
?>