<?php
session_start();
// Check if the user is logged in and has the role of 'student'
if (!isset($_SESSION['user_id']) || $_SESSION['role'] !== 'student') {
    header("Location: ../login.php");
    exit();
}

// Enable all error reporting
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('log_errors', 1);

include '../includes/dbcon.php'; // Include database connection

// Check connection
if ($conn->connect_error) {
    die("Connection failed: " . $conn->connect_error);
}

// Get the logged-in student ID
$student_id = $_SESSION['user_id'];

// Fetch available quizzes for the student
$quizzes_stmt = $conn->prepare("
    SELECT q.id, q.title, q.description, q.due_date, 
           c.class_name, d.department_name, yl.year_level, 
           q.num_questions, q.duration, u.username AS created_by 
    FROM quizzes q 
    JOIN classes c ON q.class_id = c.id 
    JOIN departments d ON c.department_id = d.id 
    JOIN year_levels yl ON c.year_level_id = yl.id
    JOIN student_classes sc ON c.id = sc.class_id  
    JOIN users u ON q.created_by = u.id 
    WHERE sc.student_id = ?  -- Filter by the logged-in student ID
    ORDER BY q.due_date DESC
"); 

$quizzes_stmt->bind_param("i", $student_id); // Bind the student ID parameter
$quizzes_stmt->execute();
$quizzes_result = $quizzes_stmt->get_result();
$quizzes_stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Available Quizzes</title>
    <link rel="icon" href="../assets/images/logo.ico"> <!-- Favicon -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
        body {
            background-color: #f4f6f9;
        }
        .container {
            margin-left: 250px;
            padding: 80px 30px;
            transition: margin-left 0.3s ease;
        }
        .sidebar {
            height: 100%;
            background-color: #f39c12;
            position: fixed;
            top: 0;
            left: 0;
            width: 250px;
            padding-top: 65px !important;
            transition: width 0.3s ease;
        }
        .sidebar a {
            color: white;
            padding: 15px;
            text-decoration: none;
            display: block;
        }
        .sidebar a:hover {
            background-color: #6e8efb;
        }
        .btn-primary {
            background-color: #f39c12;
            border-color: #f39c12;
        }
        .btn-primary:hover {
            background-color: #6e8efb;
            border-color: #6e8efb;
        }
        .overdue {
            background-color: #f8d7da; /* Light red for overdue */
        }
        .due-soon {
            background-color: #fff3cd; /* Light yellow for due today or tomorrow */
        }
        .future {
            background-color: #d4edda; /* Light green for due in 2 or more days */
        }
        .modal-content {
            border-radius: 10px; /* Rounded corners for the modal */
        }
        .score-card {
            border-radius: 5px; /* Rounded corners for the score card */
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1); /* Subtle shadow for depth */
        }
        .modal-header .close {
            color: white; /* Close button color */
        }
        .btn[disabled] {
            background-color: #ccc; /* Gray background */
            color: #666; /* Gray text */
            cursor: not-allowed; /* Change cursor to indicate it's not clickable */
        }
        /* Dropdown Styles */
        .dropdown-menu {
            background-color: #f39c12; /* Match sidebar background */
            border: none; /* Remove border */
            padding: 0; /* Remove padding */
        }

        .dropdown-item {
            color: white; /* Text color for dropdown items */
            padding: 10px 15px; /* Padding for dropdown items */
        }

        .dropdown-item:hover {
            background-color: #6e8efb; /* Hover effect for dropdown items */
        }
    </style>
</head>
<body>
    <!-- Header and Sidebar -->
    <?php include '../includes/student_header.php'; ?>
    <?php include '../includes/student_sidebar.php'; ?>
    <div class="container">
        <h1>Available Quizzes</h1>

        <?php if ($quizzes_result->num_rows > 0): ?>
            <table class="table">
                <thead>
                    <tr>
                        <th>S.No.</th>
                        <th>Quiz Title</th>
                        <th>Description</th>
                        <th>No. of Questions</th>
                        <th>Duration</th>
                        <th>Due Date</th>
                        <th>Class</th>
                        <th>Created By</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php 
                    $s_no = 1; // Initialize serial number
                    while ($row = $quizzes_result->fetch_assoc()): 
                        $dueDate = new DateTime($row['due_date']);
                        $currentDate = new DateTime();
                        $interval = $currentDate->diff($dueDate);
                        $class = '';

                        // Determine the class based on the due date
                        if ($dueDate < $currentDate) {
                            $class = 'overdue'; // Overdue
                        } elseif ($interval->days == 0 || $interval->days == 1) {
                            $class = 'due-soon'; // Due today or tomorrow
                        } else {
                            $class = 'future'; // Due in 2 or more days
                        }

                        // Check if the quiz is overdue
                        $isOverdue = $dueDate < $currentDate;
                    ?>
                    <tr class="<?php echo $class; ?>">
                        <td><?php echo $s_no++; ?></td> <!-- Serial number -->
                        <td><?php echo htmlspecialchars($row['title']); ?></td> <!-- Quiz title -->
                        <td><?php echo htmlspecialchars($row['description']); ?></td>
                        <td><?php echo htmlspecialchars($row['num_questions'] ?? 'N/A'); ?></td> <!-- Number of questions with default -->
                        <td><?php echo htmlspecialchars($row['duration'] ?? 'N/A'); ?> mins</td> <!-- Duration with default -->
                        <td><?php echo htmlspecialchars(date('Y-m-d H:i', strtotime($row['due_date']))); ?> UTC</td>
                        <td>
                            <?php 
                            // Display class name in the specified format
                            echo htmlspecialchars($row['class_name']) . " (" . htmlspecialchars($row['department_name']) . " - " . htmlspecialchars($row['year_level']) . ")"; 
                            ?>
                        </td>
                        <td><?php echo htmlspecialchars($row['created_by']); ?></td> <!-- Created By -->
                        <td>
                        <?php if ($isOverdue): ?>
                            <button class="btn btn-primary" disabled aria-label="Quiz Overdue">
                                <i class="fas fa-play"></i> Take Quiz
                            </button>
                        <?php else: ?>
                            <a href="take_quiz.php?quiz_id=<?php echo $row['id']; ?>" class="btn btn-primary" aria-label="Take Quiz">
                                <i class="fas fa-play"></i> Take Quiz
                            </a>
                        <?php endif; ?>
                            <a href="leaderboard.php?quiz_id=<?php echo $row['id']; ?>" class="btn btn-success" aria-label="View Results">
                                <i class="fas fa-eye"></i> View Leaderboard
                            </a>
                            <button class="btn btn-info view-score" data-quiz-id="<?php echo $row['id']; ?>" aria-label="View Score">
                                <i class="fas fa-chart-bar"></i> View Score
                            </button>
                        </td>
                    </tr>
                    <?php endwhile; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>No quizzes available at the moment.</p>
        <?php endif; ?>
        <!-- Modal Structure -->
        <div class="modal fade" id="scoreModal" tabindex="-1" aria-labelledby="scoreModalLabel" aria-hidden="true">
            <div class="modal-dialog modal-lg" role="document">
                <div class="modal-content">
                    <div class="modal-header" style="background-color: #007bff; color: white;">
                        <h5 class="modal-title" id="scoreModalLabel">
                            <i class="fas fa-trophy"></i> Quiz Score
                        </h5>
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                    </div>
                    <div class="modal-body">
                        <div id="loading" style="display: none; text-align: center;">
                            <div class="spinner-border" role="status">
                                <span class="sr-only">Loading...</span>
                            </div>
                        </div>
                        <div id="scoreDetails" style="display: none;">
                            <div class="score-card" style="padding: 20px; border: 1px solid #007bff; border-radius: 5px; background-color: #f8f9fa;">
                                <p><strong><i class="fas fa-star"></i> Your Score:</strong> <span id="quizScore"></span></p>
                                <p><strong><i class="fas fa-question-circle"></i> Total Questions:</strong> <span id="totalQuestions"></span></p>
                                <p><strong><i class="fas fa-check-circle"></i> Correct Answers:</strong> <span id="correctAnswers"></span></p>
                                <p><strong><i class="fas fa-times-circle"></i> Incorrect Answers:</strong> <span id="incorrectAnswers"></span></p>
                                
                                <div>
                                    <strong><i class="fas fa-percent"></i> Percentage:</strong>
                                    <div class="progress" style="height: 20px;">
                                        <div id="percentageBar" class="progress-bar" role="progressbar" style="width: 0%;" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100"></div>
                                    </div>
                                    <span id="percentageScore" style="font-weight: bold;">0%</span>
                                </div>
                            </div>
                        </div>
                        <div id="noScoreMessage" style="display: none; text-align: center; color: #dc3545;">
                            <strong>No score available for this quiz.</strong>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">
                            <i class="fas fa-times"></i> Close
                        </button>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0-alpha3/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.view-score').on('click', function() {
                var quizId = $(this).data('quiz-id'); // Get quiz ID from data attribute
                $('#loading').show();
                $('#scoreDetails').hide();
                $('#noScoreMessage').hide();

                $.ajax({
                    url: 'fetch_score.php', // PHP file to fetch the score
                    type: 'GET',
                    data: { quiz_id: quizId },
                    success: function(response) {
                        $('#loading').hide();
                        var data = JSON.parse(response);

                        if (data.score !== null) {
                            $('#quizScore').text(data.score);
                            $('#totalQuestions').text(data.total_questions);
                            $('#correctAnswers').text(data.correct_answers);
                            $('#incorrectAnswers').text(data.incorrect_answers);
                            $('#percentageScore').text(data.percentage.toFixed(2) + '%'); // Format to two decimal places
                            $('#percentageBar').css('width', data.percentage.toFixed(2) + '%'); // Set progress bar width
                            $('#percentageBar').attr('aria-valuenow', data.percentage.toFixed(2)); // Update aria value
                            $('#scoreDetails').show(); // Show score details
                        } else {
                            $('#noScoreMessage').show(); // Show no score message
                        }
                        
                        $('#scoreModal').modal('show'); // Show the modal
                    },
                    error: function() {
                        $('#loading').hide();
                        $('#noScoreMessage').show();
                    }
                });
            });
        });
    </script>
</body>
</html>